import { ProgrammaticCellUpdateT, ProgrammaticStructureUpdateT } from './types/programmaticCellUpdateT';
import { ColumnUpdateDetails, OnCellUpdate, OnColumnsUpdate, OnContentUpdate } from './types/onUpdate';
import { CustomColumnsSettings, DimensionalCSSStyle } from './types/columnsSettings';
import { ColumnDropdownSettingsDefault } from './types/columnDropdownSettings';
import { FrameComponentsStyles, IndexColumnT } from './types/frameComponents';
import { FrameComponentsInternal } from './types/frameComponentsInternal';
import { RowDropdownCellOverlays } from './types/rowDropdownCellOverlays';
import { DefaultColumnsSettings } from './types/columnsSettingsDefault';
import { Files } from './types/files';
import { ActiveOverlayElements } from './types/activeOverlayElements';
import { DEFAULT_COLUMN_TYPES_STR } from './enums/defaultColumnTypes';
import { ColumnsSettingsMap } from './types/columnsSettingsInternal';
import { ExportFile, ImportFile } from './types/fileTriggerMethods';
import { RowDropdownSettings } from './types/rowDropdownSettings';
import { StripedRowsInternal } from './types/stripedRowsInternal';
import { DefaultCellHoverColors } from './types/cellStateColors';
import { UserKeyEventsState } from './types/userKeyEventsState';
import { PaginationInternal } from './types/paginationInternal';
import { VisibilityInternal } from './types/visibilityInternal';
import { OverflowInternal } from './types/overflowInternal';
import { ColumnResizerColors } from './types/columnSizer';
import { TableDimensions } from './types/tableDimensions';
import { FocusedElements } from './types/focusedElements';
import { HoveredElements } from './types/hoveredElements';
import { HeaderIconStyle } from './types/headerIconStyle';
import { HoverableStyles } from './types/hoverableStyles';
import { EventFunctions } from './types/eventFunctions';
import { ColumnsDetailsT } from './types/columnDetails';
import { RowHoverStyles } from './types/rowHoverStyles';
import { GlobalItemColors } from './types/itemToColor';
import { FilesInternal } from './types/filesInternal';
import { StripedRowsT } from './types/stripedRows';
import { StickyProps } from './types/stickyProps';
import { ColumnTypes } from './types/columnType';
import { LitElement, PropertyValues } from 'lit';
import { CellText } from './types/tableContent';
import { TableStyle } from './types/tableStyle';
import { Pagination } from './types/pagination';
import { Overflow } from './types/overflow';
import { RootCell } from './types/rootCell';
import { Filter } from './types/filter';
export declare class ActiveTable extends LitElement {
    constructor();
    getContent: () => (number | string)[][];
    getColumnsDetails: () => ColumnUpdateDetails[];
    updateCell: (update: ProgrammaticCellUpdateT) => void;
    updateStructure: (update: ProgrammaticStructureUpdateT) => void;
    updateContent: (content: (number | string)[][]) => void;
    importFile: ImportFile;
    exportFile: ExportFile;
    onCellUpdate: OnCellUpdate;
    onContentUpdate: OnContentUpdate;
    onColumnsUpdate: OnColumnsUpdate;
    onRender: () => void;
    content: (number | string)[][];
    tableStyle: TableStyle;
    allowDuplicateHeaders: boolean;
    displayHeaderIcons: boolean;
    spellCheck: boolean;
    stickyHeader?: boolean;
    customColumnsSettings: CustomColumnsSettings;
    rowHoverStyles?: RowHoverStyles;
    preserveNarrowColumns: boolean;
    maxColumns?: number;
    maxRows?: number;
    displayAddNewRow: boolean;
    displayAddNewColumn: boolean;
    displayIndexColumn: IndexColumnT;
    frameComponentsStyles: FrameComponentsStyles;
    dataStartsAtHeader: boolean;
    columnResizerColors: ColumnResizerColors;
    rowDropdown: RowDropdownSettings;
    stripedRows?: boolean | StripedRowsT;
    overflow?: Overflow;
    defaultText?: CellText;
    isDefaultTextRemovable?: boolean;
    cellStyle?: DimensionalCSSStyle;
    rootCell?: RootCell;
    isCellTextEditable?: boolean;
    headerStyles?: HoverableStyles;
    isHeaderTextEditable?: boolean;
    headerIconStyle?: HeaderIconStyle;
    isColumnResizable?: boolean;
    availableDefaultColumnTypes?: DEFAULT_COLUMN_TYPES_STR[];
    customColumnTypes?: ColumnTypes;
    defaultColumnTypeName?: string;
    columnDropdown?: ColumnDropdownSettingsDefault;
    pagination?: boolean | Pagination;
    files?: Files;
    filter?: boolean | Filter | Filter[];
    auxiliaryStyle?: string;
    _stickyProps: StickyProps;
    _defaultColumnsSettings: DefaultColumnsSettings;
    _customColumnsSettings: ColumnsSettingsMap;
    _columnsDetails: ColumnsDetailsT;
    _tableElementRef?: HTMLElement;
    _tableBodyElementRef?: HTMLElement;
    _addRowCellElementRef?: HTMLElement;
    _addColumnCellsElementsRef: HTMLElement[];
    _focusedElements: FocusedElements;
    _hoveredElements: HoveredElements;
    _activeOverlayElements: ActiveOverlayElements;
    _eventFunctions: EventFunctions;
    _userKeyEventsState: UserKeyEventsState;
    _tableDimensions: TableDimensions;
    _cellDropdownContainer?: HTMLElement;
    _globalItemColors: GlobalItemColors;
    _defaultCellHoverColors: DefaultCellHoverColors;
    _frameComponents: FrameComponentsInternal;
    _rowDropdownCellOverlays: RowDropdownCellOverlays;
    _stripedRows?: StripedRowsInternal;
    _overflow?: OverflowInternal;
    _pagination: PaginationInternal;
    _files: FilesInternal;
    _visiblityInternal: VisibilityInternal;
    _isRendering: boolean;
    _isPopulatingTable: boolean;
    static _ELEMENT_TAG: string;
    static styles: import("lit").CSSResult[];
    protected render(): void;
    protected update(changedProperties: PropertyValues): void;
    connectedCallback(): void;
    shouldUpdate(): boolean;
}
declare global {
    interface HTMLElementTagNameMap {
        'active-table': ActiveTable;
    }
}
//# sourceMappingURL=activeTable.d.ts.map