var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { PaginationInternalUtils } from './utils/outerTableComponents/pagination/paginationInternalUtils';
import { ActiveOverlayElementsUtils } from './utils/activeOverlayElements/activeOverlayElementsUtils';
import { FileImportButtonEvents } from './elements/files/buttons/importButton/fileImportButtonEvents';
import { ProgrammaticStructureUpdate } from './utils/programmaticUpdates/programmaticStructureUpdate';
import { FrameComponentsInternalUtils } from './utils/frameComponents/frameComponentsInternalUtils';
import { RowDropdownSettingsUtil } from './elements/dropdown/rowDropdown/rowDropdownSettingsUtil';
import { ProgrammaticCellUpdate } from './utils/programmaticUpdates/programmaticCellUpdate';
import { FileExportEvents } from './elements/files/buttons/exportButton/fileExportEvents';
import { OuterTableComponents } from './utils/outerTableComponents/outerTableComponents';
import { LITElementTypeConverters } from './utils/webComponent/LITElementTypeConverters';
import { UserKeyEventsStateUtils } from './utils/userEventsState/userEventsStateUtils';
import { WebComponentStyleUtils } from './utils/webComponent/webComponentStyleUtils';
import { InitialContentProcessing } from './utils/content/initialContentProcessing';
import { FocusedElementsUtils } from './utils/focusedElements/focusedElementsUtils';
import { TableDimensionsUtils } from './utils/tableDimensions/tableDimensionsUtils';
import { UpdateAllTableData } from './utils/programmaticUpdates/updateAllTableData';
import { FilesUtils } from './utils/outerTableComponents/files/filesInternalUtils';
import { ColumnSettingsUtils } from './utils/columnSettings/columnSettingsUtils';
import { ColumnDetailsUtils } from './utils/columnDetails/columnDetailsUtils';
import { DefaultColumnTypes } from './utils/columnType/defaultColumnTypes';
import { StickyPropsUtils } from './utils/stickyProps/stickyPropsUtils';
import { CellHighlightUtils } from './utils/color/cellHighlightUtils';
import { customElement, property, state } from 'lit/decorators.js';
import { WindowElement } from './elements/window/windowElement';
import { LabelColorUtils } from './utils/color/labelColorUtils';
import { OverflowUtils } from './utils/overflow/overflowUtils';
import { ElementEvents } from './utils/elements/elementEvents';
import { RowHoverEvents } from './utils/rows/rowHoverEvents';
import { TableElement } from './elements/table/tableElement';
import { GoogleFont } from './utils/webComponent/googleFont';
import { ParentResize } from './utils/render/parentResize';
import { StripedRows } from './utils/rows/stripedRows';
import { FireEvents } from './utils/events/fireEvents';
import { activeTableStyle } from './activeTableStyle';
import { Browser } from './utils/browser/browser';
import { LitElement } from 'lit';
import { Render } from './utils/render/render';
// TO-DO - dropdown for export button
let ActiveTable = class ActiveTable extends LitElement {
    constructor() {
        super();
        this.getContent = () => JSON.parse(JSON.stringify(this.content));
        this.getColumnsDetails = () => ColumnDetailsUtils.getAllColumnsDetails(this._columnsDetails);
        this.updateCell = (update) => {
            ProgrammaticCellUpdate.updateText(this, update);
        };
        this.updateStructure = (update) => {
            ProgrammaticStructureUpdate.update(this, update);
        };
        this.updateContent = (content) => {
            UpdateAllTableData.update(this, content, 0);
        };
        // can only be activated by a user action - such as a button click
        this.importFile = (options) => FileImportButtonEvents.triggerImportPrompt(this, options);
        this.exportFile = (options) => FileExportEvents.export(this, options);
        // REF-20
        this.onCellUpdate = () => { };
        this.onContentUpdate = () => { };
        this.onColumnsUpdate = () => { };
        this.onRender = () => { };
        this.content = [
        // ['Planet', 'Diameter', 'Mass', 'Moons', 'Density'],
        // ['Earth', 12756, 5.97, 1, 5514],
        // ['Mars', 6792, 0.642, 2, 3934],
        // ['Jupiter', 142984, 1898, 79, 1326],
        // ['Saturn', 120536, 568, 82, 687],
        // ['Neptune', 49528, 102, 14, 1638],
        ];
        this.tableStyle = {};
        this.allowDuplicateHeaders = true;
        this.displayHeaderIcons = true;
        this.spellCheck = false;
        this.customColumnsSettings = [];
        // when true - the table automatically holds an unlimited size via table-controlled-width class (dynamic table)
        // this property is not used internally and is being set/used in tableDimensions as it is overriden when resizing
        this.preserveNarrowColumns = true;
        this.displayAddNewRow = true;
        this.displayAddNewColumn = true;
        this.displayIndexColumn = { wrapIndexCellText: false };
        // REF-22 - to be used by the client
        // frame components are comprised of index column, add new column column and add new row row
        this.frameComponentsStyles = {};
        // this affects the column index and pagination
        this.dataStartsAtHeader = false;
        // called columnResizer for the client - columnSizer in the code
        this.columnResizerColors = {};
        this.rowDropdown = { displaySettings: { isAvailable: true, openMethod: { cellClick: true } } };
        // setting header to true if above is undefined and vertical overflow is present
        // (using object to be able to set values without re-rendering the component)
        this._stickyProps = { header: false };
        // REF-21
        this._defaultColumnsSettings = {}; // populated in setDefaultColumnsSettings
        this._customColumnsSettings = {};
        // this contains all cell elements, if there is a need to access cell elements outside the context of columns
        // create an entirely new state object and access elements from there as we don't want to store all elements
        // multiple times, and use this instead for data exclusively on columns, such as width at.
        this._columnsDetails = [];
        // the reason why keeping ref of all the add column cells and not column index cells is because this can be toggled
        this._addColumnCellsElementsRef = [];
        this._focusedElements = FocusedElementsUtils.createEmpty();
        this._hoveredElements = {};
        this._activeOverlayElements = ActiveOverlayElementsUtils.createNew();
        this._eventFunctions = ElementEvents.getDefault();
        this._userKeyEventsState = UserKeyEventsStateUtils.createNew();
        this._tableDimensions = TableDimensionsUtils.getDefault();
        this._globalItemColors = LabelColorUtils.generateGlobalItemColors();
        this._defaultCellHoverColors = CellHighlightUtils.getDefaultHoverProperties();
        // REF-22 - to be used internally
        this._frameComponents = FrameComponentsInternalUtils.getDefault();
        // column dropdown overlays are stored inside ColumnDetailsT columnDropdownCellOverlay
        this._rowDropdownCellOverlays = [];
        // cannot be used as an indicator for pagination as this is always defined
        this._pagination = PaginationInternalUtils.getDefault();
        this._files = FilesUtils.createDefault(this);
        this._visiblityInternal = {};
        this._isRendering = false;
        // REF-43
        this._isPopulatingTable = false;
        GoogleFont.appendStyleSheetToHead();
    }
    // CAUTION-4
    render() {
        Render.renderTable(this);
        this.onContentUpdate(this.content);
        new ResizeObserver(ParentResize.resizeCallback.bind(this)).observe(this.parentElement);
        FireEvents.onRender(this);
    }
    update(changedProperties) {
        var _a, _b;
        this._isPopulatingTable = true;
        StickyPropsUtils.process(this);
        ColumnSettingsUtils.setUpInternalSettings(this);
        FrameComponentsInternalUtils.set(this);
        DefaultColumnTypes.createDropdownItemsForDefaultTypes();
        RowDropdownSettingsUtil.process(this);
        if (this.pagination)
            PaginationInternalUtils.process(this);
        if (this.stripedRows)
            StripedRows.process(this);
        if (this.rowHoverStyles)
            RowHoverEvents.process(this.rowHoverStyles, this._defaultCellHoverColors);
        const tableElement = TableElement.createInfrastructureElements(this);
        if (this.overflow)
            OverflowUtils.setupContainer(this, tableElement); // must not be after BORDER_DIMENSIONS is set
        TableElement.addOverlayElements(this, tableElement, this._activeOverlayElements);
        (_a = this.shadowRoot) === null || _a === void 0 ? void 0 : _a.appendChild(((_b = this._overflow) === null || _b === void 0 ? void 0 : _b.overflowContainer) || tableElement);
        OuterTableComponents.create(this);
        InitialContentProcessing.preProcess(this, this.content);
        WindowElement.setEvents(this);
        this.spellcheck = this.spellCheck;
        if (this.auxiliaryStyle && this.shadowRoot)
            WebComponentStyleUtils.add(this.auxiliaryStyle, this.shadowRoot);
        setTimeout(() => (this._isPopulatingTable = false), 1);
        super.update(changedProperties);
    }
    connectedCallback() {
        // REF-14
        if (Browser.IS_FIREFOX) {
            setTimeout(() => super.connectedCallback());
        }
        else {
            super.connectedCallback();
        }
    }
    // this is used to prevent a bug where the update method is called again (and adds another table) when a new property is
    // added - e.g. an event listener method
    shouldUpdate() {
        return !this._tableElementRef;
    }
};
ActiveTable._ELEMENT_TAG = 'ACTIVE-TABLE';
ActiveTable.styles = [activeTableStyle];
__decorate([
    property({ attribute: false })
], ActiveTable.prototype, "getContent", void 0);
__decorate([
    property({ attribute: false })
], ActiveTable.prototype, "getColumnsDetails", void 0);
__decorate([
    property({ attribute: false })
], ActiveTable.prototype, "updateCell", void 0);
__decorate([
    property({ attribute: false })
], ActiveTable.prototype, "updateStructure", void 0);
__decorate([
    property({ attribute: false })
], ActiveTable.prototype, "updateContent", void 0);
__decorate([
    property({ attribute: false })
], ActiveTable.prototype, "importFile", void 0);
__decorate([
    property({ attribute: false })
], ActiveTable.prototype, "exportFile", void 0);
__decorate([
    property({ converter: LITElementTypeConverters.convertToFunction })
], ActiveTable.prototype, "onCellUpdate", void 0);
__decorate([
    property({ converter: LITElementTypeConverters.convertToFunction })
], ActiveTable.prototype, "onContentUpdate", void 0);
__decorate([
    property({ converter: LITElementTypeConverters.convertToFunction })
], ActiveTable.prototype, "onColumnsUpdate", void 0);
__decorate([
    property({ converter: LITElementTypeConverters.convertToFunction })
], ActiveTable.prototype, "onRender", void 0);
__decorate([
    property({ type: Array })
], ActiveTable.prototype, "content", void 0);
__decorate([
    property({ type: Object })
], ActiveTable.prototype, "tableStyle", void 0);
__decorate([
    property({
        type: Boolean,
        converter: LITElementTypeConverters.convertToBoolean,
    })
], ActiveTable.prototype, "allowDuplicateHeaders", void 0);
__decorate([
    property({
        type: Boolean,
        converter: LITElementTypeConverters.convertToBoolean,
    })
], ActiveTable.prototype, "displayHeaderIcons", void 0);
__decorate([
    property({
        type: Boolean,
        converter: LITElementTypeConverters.convertToBoolean,
    })
], ActiveTable.prototype, "spellCheck", void 0);
__decorate([
    property({
        type: Boolean,
        converter: LITElementTypeConverters.convertToBoolean,
    })
], ActiveTable.prototype, "stickyHeader", void 0);
__decorate([
    property({ type: Array })
], ActiveTable.prototype, "customColumnsSettings", void 0);
__decorate([
    property({ type: Object })
], ActiveTable.prototype, "rowHoverStyles", void 0);
__decorate([
    property({
        type: Boolean,
        converter: LITElementTypeConverters.convertToBoolean,
    })
], ActiveTable.prototype, "preserveNarrowColumns", void 0);
__decorate([
    property({ type: Number })
], ActiveTable.prototype, "maxColumns", void 0);
__decorate([
    property({ type: Number })
], ActiveTable.prototype, "maxRows", void 0);
__decorate([
    property({
        type: Boolean,
        converter: LITElementTypeConverters.convertToBoolean,
    })
], ActiveTable.prototype, "displayAddNewRow", void 0);
__decorate([
    property({
        type: Boolean,
        converter: LITElementTypeConverters.convertToBoolean,
    })
], ActiveTable.prototype, "displayAddNewColumn", void 0);
__decorate([
    property({ type: Object })
], ActiveTable.prototype, "displayIndexColumn", void 0);
__decorate([
    property({ type: Object })
], ActiveTable.prototype, "frameComponentsStyles", void 0);
__decorate([
    property({
        type: Boolean,
        converter: LITElementTypeConverters.convertToBoolean,
    })
], ActiveTable.prototype, "dataStartsAtHeader", void 0);
__decorate([
    property({ type: Object })
], ActiveTable.prototype, "columnResizerColors", void 0);
__decorate([
    property({ type: Object })
], ActiveTable.prototype, "rowDropdown", void 0);
__decorate([
    property({ type: Object })
], ActiveTable.prototype, "stripedRows", void 0);
__decorate([
    property({ type: Object })
], ActiveTable.prototype, "overflow", void 0);
__decorate([
    property({ type: String })
], ActiveTable.prototype, "defaultText", void 0);
__decorate([
    property({
        type: Boolean,
        converter: LITElementTypeConverters.convertToBoolean,
    })
], ActiveTable.prototype, "isDefaultTextRemovable", void 0);
__decorate([
    property({ type: Object })
], ActiveTable.prototype, "cellStyle", void 0);
__decorate([
    property({ type: Object })
], ActiveTable.prototype, "rootCell", void 0);
__decorate([
    property({
        type: Boolean,
        converter: LITElementTypeConverters.convertToBoolean,
    })
], ActiveTable.prototype, "isCellTextEditable", void 0);
__decorate([
    property({ type: Object })
], ActiveTable.prototype, "headerStyles", void 0);
__decorate([
    property({
        type: Boolean,
        converter: LITElementTypeConverters.convertToBoolean,
    })
], ActiveTable.prototype, "isHeaderTextEditable", void 0);
__decorate([
    property({ type: Object })
], ActiveTable.prototype, "headerIconStyle", void 0);
__decorate([
    property({
        type: Boolean,
        converter: LITElementTypeConverters.convertToBoolean,
    })
], ActiveTable.prototype, "isColumnResizable", void 0);
__decorate([
    property({ type: Array })
], ActiveTable.prototype, "availableDefaultColumnTypes", void 0);
__decorate([
    property({ type: Array })
], ActiveTable.prototype, "customColumnTypes", void 0);
__decorate([
    property({ type: String })
], ActiveTable.prototype, "defaultColumnTypeName", void 0);
__decorate([
    property({ type: Object })
], ActiveTable.prototype, "columnDropdown", void 0);
__decorate([
    property({ type: Object })
], ActiveTable.prototype, "pagination", void 0);
__decorate([
    property({ type: Object })
], ActiveTable.prototype, "files", void 0);
__decorate([
    property({ type: Object })
], ActiveTable.prototype, "filter", void 0);
__decorate([
    property({ type: String })
], ActiveTable.prototype, "auxiliaryStyle", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_stickyProps", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_defaultColumnsSettings", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_customColumnsSettings", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_columnsDetails", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_tableElementRef", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_tableBodyElementRef", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_addRowCellElementRef", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_addColumnCellsElementsRef", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_focusedElements", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_hoveredElements", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_activeOverlayElements", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_eventFunctions", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_userKeyEventsState", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_tableDimensions", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_cellDropdownContainer", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_globalItemColors", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_defaultCellHoverColors", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_frameComponents", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_rowDropdownCellOverlays", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_stripedRows", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_overflow", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_pagination", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_files", void 0);
__decorate([
    state()
], ActiveTable.prototype, "_visiblityInternal", void 0);
__decorate([
    state({
        hasChanged() {
            return false;
        },
    })
], ActiveTable.prototype, "_isRendering", void 0);
__decorate([
    state({
        hasChanged() {
            return false;
        },
    })
], ActiveTable.prototype, "_isPopulatingTable", void 0);
ActiveTable = __decorate([
    customElement('active-table')
], ActiveTable);
export { ActiveTable };
// if using raw javascript, this is a direction to help move away from using render
// the initial values should be fetched in connectedCallBack (or set to default) and their changes can be observed in
// MutationObserver, this would also save callback and boolean changes from having to re-render the screen
// @state()
// observer = new MutationObserver(function (mutations) {
//   mutations.forEach(function (mutation) {
//     if (mutation.attributeName === 'content') {
//       console.log(mutation);
//       console.log('attributes changed');
//     }
//   });
// });
// override connectedCallback() {
//   super.connectedCallback();
//   this.observer.observe(this, {
//     attributes: true, //configure it to listen to attribute changes
//   });
//# sourceMappingURL=activeTable.js.map