import { ProcessedDataTextStyle } from '../../utils/columnType/processedDataTextStyle';
import { DataUtils } from '../../utils/insertRemoveStructure/shared/dataUtils';
import { CELL_UPDATE_TYPE } from '../../enums/onUpdateCellType';
import { FireEvents } from '../../utils/events/fireEvents';
import { EMPTY_STRING } from '../../consts/text';
import { CellElement } from './cellElement';
export class CellEvents {
    static executeUpdateOperation(operation, options) {
        return (options === null || options === void 0 ? void 0 : options[operation]) === undefined || options[operation] === true;
    }
    // this is directly handled by operations that do not insert new cells as those handle the instructions below
    // in a different order asynchronously for maximum efficiency
    // prettier-ignore
    static updateCell(at, cellText, rowIndex, columnIndex, options) {
        if (CellEvents.executeUpdateOperation('processText', options)) {
            cellText = DataUtils.processCellText(at, rowIndex, columnIndex, cellText);
        }
        if (CellEvents.executeUpdateOperation('updateContent', options))
            at.content[rowIndex][columnIndex] = cellText;
        if (options === null || options === void 0 ? void 0 : options.element)
            CellElement.setNewText(at, options.element, cellText, false, false); // CAUTION-1
        if (CellEvents.executeUpdateOperation('updateTableEvent', options))
            at.onContentUpdate(at.content);
        // slight inefficiency using this here as setCellToDefaultIfNeeded and removeTextIfDefault have already validated text,
        // however having it here minimizes complexity
        if (rowIndex > 0)
            ProcessedDataTextStyle.setCellStyle(at, rowIndex, columnIndex);
        // not in timeout as functionality that calls updateCell calls at.onContentUpdate after - should remain that way
        FireEvents.onCellUpdate(at, cellText, rowIndex, columnIndex, CELL_UPDATE_TYPE.UPDATE);
        return cellText;
    }
    // this is used for cases where updateCell should only be called if it has to be set to default
    // prettier-ignore
    static setCellToDefaultIfNeeded(at, rowIndex, columnIndex, textContainerElement, updateTableEvent = true) {
        const cellText = CellElement.getText(textContainerElement);
        const processedCellText = DataUtils.processCellText(at, rowIndex, columnIndex, cellText);
        if (processedCellText !== cellText) {
            // if pointer problems start occuring, .getText() and processCellText are trimming the <br> element
            CellEvents.updateCell(at, processedCellText, rowIndex, columnIndex, { element: textContainerElement, processText: false, updateTableEvent });
            return true;
        }
        return false;
    }
    // prettier-ignore
    static removeTextIfDefault(at, rowIndex, columnIndex, textContainerElement) {
        const { isDefaultTextRemovable, defaultText } = at._columnsDetails[columnIndex].settings;
        if (!isDefaultTextRemovable)
            return;
        if (defaultText !== EMPTY_STRING && defaultText === CellElement.getText(textContainerElement)) {
            CellEvents.updateCell(at, EMPTY_STRING, rowIndex, columnIndex, { element: textContainerElement, processText: false });
        }
    }
}
//# sourceMappingURL=cellEvents.js.map