import { SelectCellTextBaseEvents } from './selectCell/baseEvents/selectCellTextBaseEvents';
import { FocusedCellUtils } from '../../../utils/focusedElements/focusedCellUtils';
import { CaretPosition } from '../../../utils/focusedElements/caretPosition';
import { CaretDisplayFix } from '../../../utils/browser/caretDisplayFix';
import { KEYBOARD_KEY } from '../../../consts/keyboardKeys';
import { DataCellEvents } from '../dataCell/dataCellEvents';
import { CellElement } from '../cellElement';
export class CellWithTextEvents {
    // prettier-ignore
    static focusText(rowIndex, columnIndex, focusCallback, event) {
        const textElement = event.target;
        const cellElement = CellElement.getCellElement(textElement);
        DataCellEvents.prepareText(this, rowIndex, columnIndex, textElement);
        focusCallback === null || focusCallback === void 0 ? void 0 : focusCallback(this, columnIndex, cellElement);
        FocusedCellUtils.set(this._focusedElements.cell, cellElement, rowIndex, columnIndex);
        if (this._userKeyEventsState[KEYBOARD_KEY.TAB]) {
            // contrary to this being called on mouseDownCell - this does not retrigger focus event
            CaretPosition.setToEndOfText(this, textElement);
        }
    }
    static programmaticBlur(at) {
        const { rowIndex, columnIndex, element } = at._focusedElements.cell;
        const textElement = CellElement.getTextElement(element);
        textElement.blur();
        // the above will not trigger the SelectCellEvents.blur functionality if dropdown has been focused, but will blur
        // the element in the dom, the following will trigger the required programmatic functionality
        if (at._focusedElements.cellDropdown) {
            SelectCellTextBaseEvents.blurring(at, rowIndex, columnIndex, textElement);
            delete at._focusedElements.cellDropdown;
        }
    }
    // prettier-ignore
    static mouseDownCell(at, blurCallback, cellElement, event) {
        if (at._focusedElements.cellDropdown)
            CellWithTextEvents.programmaticBlur(at); // REF-44
        const textElement = CellElement.getTextElement(cellElement);
        // needed to set cursor at the end
        event.preventDefault();
        blurCallback === null || blurCallback === void 0 ? void 0 : blurCallback(at);
        // Firefox and Safari do not fire the focus event for CaretPosition.setToEndOfText
        if (CaretDisplayFix.isIssueBrowser())
            textElement.focus();
        // in non firefox browsers this focuses
        CaretPosition.setToEndOfText(at, textElement);
    }
    static mouseDown(blurCallback, event) {
        const targetElement = event.target;
        // this is also triggered by text, but we only want on cell focus
        if (targetElement.classList.contains(CellElement.CELL_CLASS)) {
            const cellElement = event.target;
            CellWithTextEvents.mouseDownCell(this, blurCallback, cellElement, event);
        }
    }
}
//# sourceMappingURL=cellWithTextEvents.js.map