import { FocusedCellUtils } from '../../../../utils/focusedElements/focusedCellUtils';
import { Browser } from '../../../../utils/browser/browser';
import { CellElement } from '../../cellElement';
// the actual calendar and date pocker are on the input element and this is a standin replacement icon to standardize
// how the calendars look across browsers as the date input tends to vary their look
export class DateCellCalendarIconEvents {
    static mouseDownIcon(rowIndex, columnIndex, event) {
        const { _focusedElements, _activeOverlayElements } = this;
        const svgImage = event.target;
        const inputElement = svgImage.previousSibling;
        const cellElement = CellElement.getCellElement(inputElement);
        setTimeout(() => {
            // this is in a timeout as upon selecting text, then clicking on the icon causes the text blur to activate
            // which purges the selected cell ref
            FocusedCellUtils.set(_focusedElements.cell, cellElement, rowIndex, columnIndex);
            // this is in a timeout because mouseDownIcon is triggered before window mouse down event which calls
            // delete activeOverlayElements.datePickerCell, thus this setter needs to be called after
            _activeOverlayElements.datePickerCell = cellElement;
            // displaying the picker on mouse down in order to keep it consistent with mouse down display for cell dropdown,
            // however if it feels more natural to do it on mouse up, can move it to that, but keep in mind that it
            // does not feel right for firefox as there is an additional timeout - hence may need to keep it here
            // for this particular browser
            // firefox date picker has a fade out animation which does not allow the user to open up another date picker
            // while the current one is open, hence need to wait for animation to finish
            if (Browser.IS_SAFARI) {
                inputElement.dispatchEvent(new MouseEvent('click'));
            }
            else {
                inputElement.showPicker();
            }
        }, DateCellCalendarIconEvents.PICKER_DISPLAY_DELAY_ML);
    }
    static setEvents(at, calendarElement, rowIndex, columnIndex) {
        calendarElement.onmousedown = DateCellCalendarIconEvents.mouseDownIcon.bind(at, rowIndex, columnIndex);
    }
}
// firefox date picker has a fade out animation which does not allow the user to open up another date picker
// while the current one is open, hence need to wait for animation to finish
DateCellCalendarIconEvents.PICKER_DISPLAY_DELAY_ML = Browser.IS_FIREFOX ? 190 : 0;
//# sourceMappingURL=dateCellCalendarIconEvents.js.map