import { DateCellCalendarIconEvents } from './dateCellCalendarIconEvents';
import { DateCellInputElement } from './dateCellInputElement';
import { Browser } from '../../../../utils/browser/browser';
import { DateCellInputEvents } from './dateCellInputEvents';
import { CellWithTextEvents } from '../cellWithTextEvents';
import { DateCellTextEvents } from './dateCellTextEvents';
export class DateCellEvents {
    static mouseLeaveCell(event) {
        // this needs to be here as otherwise it would not be called due to the return statement below
        delete this._hoveredElements.dateCell;
        if (Browser.IS_INPUT_DATE_SUPPORTED) {
            const cellElement = event.target;
            // if the date picker is opened, do not hide container
            if (this._activeOverlayElements.datePickerCell === cellElement)
                return;
            DateCellInputElement.toggle(cellElement, false);
        }
    }
    static mouseEnterCell(event) {
        this._hoveredElements.dateCell = event.target;
        if (Browser.IS_INPUT_DATE_SUPPORTED) {
            DateCellInputElement.toggle(this._hoveredElements.dateCell, true);
        }
    }
    static setEvents(at, cellElement, rowIndex, columnIndex) {
        if (!at._columnsDetails[columnIndex].settings.isCellTextEditable)
            return;
        // important to note that this is still using data events that have not be overwritten here
        // onblur/onfocus do not work for firefox, hence using them on text element to keep it consistent across browsers
        cellElement.onblur = () => { };
        cellElement.onfocus = () => { };
        cellElement.onmouseenter = DateCellEvents.mouseEnterCell.bind(at);
        cellElement.onmouseleave = DateCellEvents.mouseLeaveCell.bind(at);
        cellElement.onmousedown = CellWithTextEvents.mouseDown.bind(at, null);
        const textElement = cellElement.children[0];
        DateCellTextEvents.setEvents(at, textElement, rowIndex, columnIndex);
        if (Browser.IS_INPUT_DATE_SUPPORTED) {
            const inputContainer = cellElement.children[1];
            DateCellInputEvents.setEvents(at, inputContainer, rowIndex, columnIndex);
            const calendarElement = inputContainer.children[1];
            DateCellCalendarIconEvents.setEvents(at, calendarElement, rowIndex, columnIndex);
        }
    }
}
//# sourceMappingURL=dateCellEvents.js.map