import { DateCellCalendarIconElement } from './dateCellCalendarIconElement';
import { CellElement } from '../../cellElement';
// the user does not use the actual input element and the events are triggered via the date picker (calendar)
export class DateCellInputElement {
    static isInputElement(element) {
        return (element === null || element === void 0 ? void 0 : element.type) === DateCellInputElement.ELEMENT_TYPE;
    }
    static toggle(cellElement, isDisplay) {
        if (!cellElement)
            return;
        const inputContainer = cellElement.children[1];
        inputContainer.style.display = isDisplay ? 'block' : 'none';
    }
    static extractInputElementFromCell(cellElement) {
        return cellElement.children[1].children[0];
    }
    static convertTextToInputValue(textDate, type) {
        if (type.calendar) {
            const isValid = type.textValidation.func === undefined || type.textValidation.func(textDate);
            if (isValid) {
                const ymd = type.calendar.toYMDFunc(textDate);
                return [ymd[0], ymd[1].padStart(2, '0'), ymd[2].padStart(2, '0')].join('-');
            }
        }
        return '-';
    }
    static updateInputBasedOnTextDiv(cellElement, type) {
        const dateValue = DateCellInputElement.convertTextToInputValue(CellElement.getText(cellElement), type);
        DateCellInputElement.extractInputElementFromCell(cellElement).value = dateValue;
    }
    static createInputElement(text, type) {
        const inputElement = document.createElement('input');
        inputElement.type = DateCellInputElement.ELEMENT_TYPE;
        inputElement.classList.add(DateCellInputElement.DATE_INPUT_CLASS);
        inputElement.value = DateCellInputElement.convertTextToInputValue(text, type);
        return inputElement;
    }
    static createInputElementContainer() {
        const inputContainer = document.createElement('div');
        inputContainer.classList.add(DateCellInputElement.DATE_INPUT_CONTAINER_CLASS);
        inputContainer.style.display = 'none';
        return inputContainer;
    }
    static addDateInputElement(cellElement, textElement, type) {
        const inputContainer = DateCellInputElement.createInputElementContainer();
        const inputElement = DateCellInputElement.createInputElement(CellElement.getText(textElement), type);
        inputContainer.appendChild(inputElement);
        const svgImage = DateCellCalendarIconElement.get();
        inputContainer.appendChild(svgImage);
        cellElement.appendChild(inputContainer);
    }
}
DateCellInputElement.ELEMENT_TYPE = 'date';
DateCellInputElement.DATE_INPUT_CLASS = 'date-input';
DateCellInputElement.DATE_INPUT_CONTAINER_CLASS = 'date-input-container';
//# sourceMappingURL=dateCellInputElement.js.map