import { SVGIconUtils } from '../../../../utils/svgIcons/svgIconUtils';
import { CellTextElement } from '../text/cellTextElement';
export class HeaderIconCellElement {
    static createTextElement(cellElement, isHeaderTextEditable) {
        const textElement = CellTextElement.setCellTextAsAnElement(cellElement, isHeaderTextEditable);
        textElement.classList.add(HeaderIconCellElement.TEXT_CLASS);
        textElement.style.pointerEvents = isHeaderTextEditable ? '' : 'none';
        return textElement;
    }
    static setScale(svgIconElement, scale) {
        const x = (scale === null || scale === void 0 ? void 0 : scale.x) || 1.2;
        const y = (scale === null || scale === void 0 ? void 0 : scale.y) || 1.2;
        const scaleString = `scale(${x}, ${y})`;
        svgIconElement.style.transform = scaleString;
        svgIconElement.style.webkitTransform = scaleString; // for safari
    }
    static createSvgIcon(iconSettings, columnSettings) {
        var _a, _b;
        const svgIconElement = SVGIconUtils.createSVGElement(iconSettings.svgString);
        HeaderIconCellElement.setScale(svgIconElement, (_a = columnSettings.headerIconStyle) === null || _a === void 0 ? void 0 : _a.scale);
        svgIconElement.style.filter = ((_b = columnSettings.headerIconStyle) === null || _b === void 0 ? void 0 : _b.filterColor) || SVGIconUtils.HEADER_FILTER;
        return svgIconElement;
    }
    static createSVGContainer(iconSettings) {
        const container = document.createElement('div');
        const { containerStyles } = iconSettings;
        if (containerStyles === null || containerStyles === void 0 ? void 0 : containerStyles.dropdown)
            Object.assign(container.style, containerStyles === null || containerStyles === void 0 ? void 0 : containerStyles.dropdown);
        if (containerStyles === null || containerStyles === void 0 ? void 0 : containerStyles.headerCorrections)
            Object.assign(container.style, containerStyles === null || containerStyles === void 0 ? void 0 : containerStyles.headerCorrections);
        container.classList.add(HeaderIconCellElement.ICON_CONTAINER_CLASS);
        return container;
    }
    static createSVG(iconSettings, columnSettings) {
        const svgContainer = HeaderIconCellElement.createSVGContainer(iconSettings);
        const svgIconElement = HeaderIconCellElement.createSvgIcon(iconSettings, columnSettings);
        svgContainer.appendChild(svgIconElement);
        return svgContainer;
    }
    static changeHeaderIcon(columnDetails) {
        const { elements, activeType, settings } = columnDetails;
        const svgIconElement = HeaderIconCellElement.createSVG(activeType.dropdownItem.settings.iconSettings, settings);
        const headerElement = elements[0];
        headerElement.replaceChild(svgIconElement, headerElement.children[0]);
    }
    static setHeaderIconStructure(at, cellElement, columnIndex) {
        var _a, _b, _c;
        const { activeType, settings } = at._columnsDetails[columnIndex];
        const svgIconElement = HeaderIconCellElement.createSVG(activeType.dropdownItem.settings.iconSettings, settings);
        const openViaCellClick = (_c = (_b = (_a = at._defaultColumnsSettings.columnDropdown) === null || _a === void 0 ? void 0 : _a.displaySettings) === null || _b === void 0 ? void 0 : _b.openMethod) === null || _c === void 0 ? void 0 : _c.cellClick;
        const isHeaderTextEditable = settings.isHeaderTextEditable && !openViaCellClick;
        const textElement = HeaderIconCellElement.createTextElement(cellElement, isHeaderTextEditable);
        cellElement.insertBefore(svgIconElement, textElement);
    }
}
HeaderIconCellElement.TEXT_CLASS = 'header-icon-side-text';
HeaderIconCellElement.ICON_CONTAINER_CLASS = 'header-icon-container';
//# sourceMappingURL=headerIconCellElement.js.map