import { ConvertCellTypeUtils } from '../../../utils/columnType/convertCellTypeUtils';
import { CellStructureUtils } from '../../../utils/columnType/cellStructureUtils';
import { CheckboxCellEvents } from './checkboxCellEvents';
import { CheckboxElement } from './checkboxElement';
import { CellElement } from '../cellElement';
import { CellEvents } from '../cellEvents';
export class CheckboxCellElement {
    static isCheckbox(element) {
        return (element === null || element === void 0 ? void 0 : element.type) === 'checkbox';
    }
    static isCheckboxCell(cellElement) {
        return CheckboxCellElement.isCheckbox(cellElement.children[0]);
    }
    static getCheckboxElement(element) {
        if (CheckboxCellElement.isCheckboxCell(element)) {
            return element.children[0];
        }
        if (CheckboxCellElement.isCheckbox(element)) {
            return element;
        }
        return undefined;
    }
    static getValue(element) {
        const checkbox = CheckboxCellElement.getCheckboxElement(element);
        if (checkbox)
            return String(checkbox.checked);
        return undefined;
    }
    static setValue(element, text) {
        const checkbox = CheckboxCellElement.getCheckboxElement(element);
        if (checkbox) {
            checkbox.checked = 'true' === text;
            return true;
        }
        return false;
    }
    // prettier-ignore
    static setCellTextAsAnElement(at, cellElement, rowIndex, columnIndex) {
        const { settings: { isCellTextEditable } } = at._columnsDetails[columnIndex];
        const text = CellElement.getText(cellElement);
        CheckboxElement.setCellTextAsCheckbox(cellElement, isCellTextEditable);
        cellElement.contentEditable = 'false';
        cellElement.style.cursor = isCellTextEditable ? 'pointer' : 'default';
        CellEvents.updateCell(at, text, rowIndex, columnIndex, { element: cellElement });
    }
    // prettier-ignore
    static setCellCheckboxStructure(at, cellElement, columnIndex, rowIndex) {
        ConvertCellTypeUtils.preprocessCell(cellElement);
        CheckboxCellElement.setCellTextAsAnElement(at, cellElement, rowIndex, columnIndex);
    }
    // prettier-ignore
    static setColumnCheckboxStructure(at, columnIndex) {
        CellStructureUtils.setColumn(at, columnIndex, CheckboxCellElement.setCellCheckboxStructure, CheckboxCellEvents.setEvents);
    }
}
//# sourceMappingURL=checkboxCellElement.js.map