import { OverwriteCellsViaCSVOnPaste } from '../../../utils/paste/CSV/overwriteCellsViaCSVOnPaste';
import { UserKeyEventsStateUtils } from '../../../utils/userEventsState/userEventsStateUtils';
import { DateCellInputElement } from '../cellsWithTextDiv/dateCell/dateCellInputElement';
import { FocusedCellUtils } from '../../../utils/focusedElements/focusedCellUtils';
import { CaretPosition } from '../../../utils/focusedElements/caretPosition';
import { CaretDisplayFix } from '../../../utils/browser/caretDisplayFix';
import { CellDropdown } from '../../dropdown/cellDropdown/cellDropdown';
import { HeaderText } from '../../../utils/columnDetails/headerText';
import { KEYBOARD_EVENT } from '../../../consts/keyboardEvents';
import { PasteUtils } from '../../../utils/paste/pasteUtils';
import { KEYBOARD_KEY } from '../../../consts/keyboardKeys';
import { UNDO_INPUT_TYPE } from '../../../consts/domEvents';
import { CellElement } from '../cellElement';
import { CellEvents } from '../cellEvents';
export class DataCellEvents {
    static keyDownCell(event) {
        // REF-7
        if (event.key === KEYBOARD_KEY.TAB) {
            UserKeyEventsStateUtils.temporarilyIndicateEvent(this._userKeyEventsState, KEYBOARD_KEY.TAB);
        }
    }
    // using this instead of keydown because when this is fired the new cell text is available
    // prettier-ignore
    static inputCell(rowIndex, columnIndex, event) {
        const inputEvent = event;
        // can be cell element for data cell, text element for cell dropdown and date cells, or even input element from date
        // picker which is not processed here as its textContent property value is empty and date value needs to be processed
        const textContainerElement = inputEvent.target;
        if (DateCellInputElement.isInputElement(textContainerElement))
            return;
        const text = CellElement.getText(textContainerElement);
        // sanitizePastedTextContent causes inputType to no longer be insertFromPaste, hence using this instead
        if (!this._userKeyEventsState[KEYBOARD_EVENT.PASTE]) {
            const isUndo = inputEvent.inputType === UNDO_INPUT_TYPE;
            CellElement.setNewText(this, textContainerElement, text, false, isUndo, false);
            const columnDetails = this._columnsDetails[columnIndex];
            if (columnDetails.activeType.cellDropdownProps && rowIndex > 0) {
                CellDropdown.updateCellDropdown(textContainerElement, columnDetails.cellDropdown, this._tableDimensions.border, columnDetails.settings.defaultText, true);
            }
            CellEvents.updateCell(this, text, rowIndex, columnIndex, { processText: false });
        }
    }
    // prettier-ignore
    static pasteCell(rowIndex, columnIndex, event) {
        UserKeyEventsStateUtils.temporarilyIndicateEvent(this._userKeyEventsState, KEYBOARD_EVENT.PASTE);
        PasteUtils.sanitizePastedTextContent(event);
        const clipboardText = PasteUtils.extractClipboardText(event);
        if (OverwriteCellsViaCSVOnPaste.isCSVData(clipboardText)) {
            OverwriteCellsViaCSVOnPaste.overwrite(this, clipboardText, event, rowIndex, columnIndex);
        }
        else {
            const targetElement = event.target;
            const { cellDropdown, settings: { defaultText }, activeType } = this._columnsDetails[columnIndex];
            const { calendar, cellDropdownProps } = activeType;
            // if the user has deleted all text in calendar/select/label cell - targetElement can be the <br> tag
            const containerElement = calendar || cellDropdownProps
                ? targetElement.parentElement : targetElement;
            setTimeout(() => {
                if (cellDropdownProps)
                    CellDropdown.updateCellDropdown(containerElement, cellDropdown, this._tableDimensions.border, defaultText, true);
                CellEvents.updateCell(this, CellElement.getText(containerElement), rowIndex, columnIndex, { processText: false });
            });
        }
    }
    // prettier-ignore
    // textContainerElement can be cell element for data cell, text element for select/label and date cells
    static blur(at, rowIndex, columnIndex, textContainerElement) {
        if (CaretDisplayFix.isIssueBrowser())
            CaretDisplayFix.removeContentEditable(textContainerElement);
        CellEvents.setCellToDefaultIfNeeded(at, rowIndex, columnIndex, textContainerElement);
        FocusedCellUtils.purge(at._focusedElements.cell);
    }
    static blurCell(rowIndex, columnIndex, event) {
        var _a, _b, _c;
        if (rowIndex === 0 && !((_c = (_b = (_a = this._defaultColumnsSettings.columnDropdown) === null || _a === void 0 ? void 0 : _a.displaySettings) === null || _b === void 0 ? void 0 : _b.openMethod) === null || _c === void 0 ? void 0 : _c.cellClick)) {
            HeaderText.onAttemptChange(this, event.target, columnIndex);
        }
        DataCellEvents.blur(this, rowIndex, columnIndex, event.target);
    }
    // textContainerElement can be cell element for data cell, text element for select/label and date cells
    static prepareText(at, rowIndex, columnIndex, textContainerElement) {
        var _a, _b, _c;
        const openViaCellClick = (_c = (_b = (_a = at._defaultColumnsSettings.columnDropdown) === null || _a === void 0 ? void 0 : _a.displaySettings) === null || _b === void 0 ? void 0 : _b.openMethod) === null || _c === void 0 ? void 0 : _c.cellClick;
        if (CaretDisplayFix.isIssueBrowser() && (rowIndex > 0 || !openViaCellClick)) {
            // THIS HAS TO BE CALLED IN A FOCUS EVENT!!!!!!!!!!!!!!!!!
            CaretDisplayFix.setContentEditable(textContainerElement);
        }
        // placed here and not in timeout because we need cells with a default value to be recorded before modification
        CellEvents.removeTextIfDefault(at, rowIndex, columnIndex, textContainerElement);
    }
    static focusCell(rowIndex, columnIndex, event) {
        const cellElement = event.target;
        DataCellEvents.prepareText(this, rowIndex, columnIndex, cellElement);
        const { _userKeyEventsState, _focusedElements } = this;
        // REF-7
        if (_userKeyEventsState[KEYBOARD_KEY.TAB])
            CaretPosition.setToEndOfText(this, cellElement);
        FocusedCellUtils.set(_focusedElements.cell, cellElement, rowIndex, columnIndex);
    }
    static setEvents(at, cellElement, rowIndex, columnIndex) {
        cellElement.onfocus = DataCellEvents.focusCell.bind(at, rowIndex, columnIndex);
        cellElement.onblur = DataCellEvents.blurCell.bind(at, rowIndex, columnIndex);
        // these are used in date cells and overwritten when converted from
        cellElement.onmouseenter = () => { };
        cellElement.onmouseleave = () => { };
        // this is used by select/label element and overwritten when converted from
        cellElement.onmousedown = () => { };
        cellElement.oninput = DataCellEvents.inputCell.bind(at, rowIndex, columnIndex);
        cellElement.onpaste = DataCellEvents.pasteCell.bind(at, rowIndex, columnIndex);
        cellElement.onkeydown = DataCellEvents.keyDownCell.bind(at);
    }
}
//# sourceMappingURL=dataCellEvents.js.map