import { UpdateRowElement } from '../../utils/insertRemoveStructure/update/updateRowElement';
import { ColumnSizerFillerElement } from './columnSizerFillerElement';
import { SEMI_TRANSPARENT_COLOR } from '../../consts/colors';
// REF-12
// the reason why there is a unique column sizer for each column is because sometimes the user may hover over
// it before hovering over a cell which makes state management difficult - e.g from top/below
// another reason is because the column sizer neeeds to know which column it is manipulating and needs to
// be binded to the header cell
export class ColumnSizerElement {
    static isHovered(columnSizerElement) {
        return columnSizerElement.style.backgroundImage === ColumnSizerElement.EMPTY_BACKGROUND_IMAGE;
    }
    static setBackgroundImage(columnSizerElement, backgroundImage) {
        columnSizerElement.style.backgroundImage = backgroundImage;
    }
    static unsetBackgroundImage(columnSizerElement) {
        columnSizerElement.style.backgroundImage = ColumnSizerElement.EMPTY_BACKGROUND_IMAGE;
    }
    static setBackgroundColor(columnSizerElement, color) {
        columnSizerElement.style.backgroundColor = color;
    }
    static setTransitionTime(columnSizerElement) {
        columnSizerElement.style.transition = ColumnSizerElement.TRANSITION_TIME;
    }
    static unsetTransitionTime(columnSizerElement) {
        columnSizerElement.style.transition = '0.0s';
    }
    // is not used to unset background image
    static unsetElementsToDefault(columnSizerElement, width, setColors = true) {
        if (setColors)
            ColumnSizerElement.setBackgroundColor(columnSizerElement, SEMI_TRANSPARENT_COLOR);
        ColumnSizerFillerElement.hide(columnSizerElement.children[0]);
        columnSizerElement.style.width = width;
    }
    // this is recalculated as it depends on the column index that the sizer is on
    static setStaticProperties(columnSizerElement, marginRight) {
        columnSizerElement.style.marginRight = marginRight;
    }
    static setElementId(columnSizerElement, sizerIndex) {
        columnSizerElement.id = `${ColumnSizerElement.COLUMN_SIZER_ID_PREFIX}${sizerIndex}`;
    }
    static create(sizerIndex, hoverColor) {
        const columnSizerElement = document.createElement('div');
        ColumnSizerElement.setElementId(columnSizerElement, sizerIndex);
        columnSizerElement.classList.add(ColumnSizerElement.COLUMN_SIZER_CLASS);
        const fillerElement = ColumnSizerFillerElement.create(hoverColor);
        columnSizerElement.append(fillerElement);
        ColumnSizerElement.hide(columnSizerElement);
        return columnSizerElement;
    }
    static display(columnSizerElement) {
        var _a;
        // originally executed this when a new column was added/removed etc, but there were too many cases
        // where the height of the column was augmented, hence setting it here for ease of maintenance
        UpdateRowElement.updateHeaderRowHeight((_a = columnSizerElement.parentElement) === null || _a === void 0 ? void 0 : _a.parentElement);
        columnSizerElement.style.display = 'flex';
    }
    static hide(columnSizerElement) {
        columnSizerElement.style.display = 'none';
    }
    static hideWithBlurAnimation(columnSizerElement) {
        setTimeout(() => {
            ColumnSizerElement.hide(columnSizerElement);
        }, ColumnSizerElement.HALF_TRANSITION_TIME_ML);
    }
    static hideWhenCellNotHovered(columnSizer, wasHovered) {
        // do not hide if the other side cell is hovered
        if (columnSizer.isSideCellHovered)
            return;
        if (wasHovered) {
            ColumnSizerElement.hideWithBlurAnimation(columnSizer.element);
        }
        else {
            ColumnSizerElement.hide(columnSizer.element);
        }
    }
    static setHoverStyle(columnSizer, width, setTransition, anotherColor) {
        const { element, hoverColor } = columnSizer;
        ColumnSizerFillerElement.display(element.children[0]);
        if (setTransition)
            ColumnSizerElement.setTransitionTime(element);
        ColumnSizerElement.setBackgroundColor(element, anotherColor || hoverColor);
        element.style.width = width;
    }
}
ColumnSizerElement.FILLED_BACKGROUND_IMAGE = 'linear-gradient(180deg, #cdcdcd, #cdcdcd 75%, transparent 75%, transparent 100%)';
ColumnSizerElement.EMPTY_BACKGROUND_IMAGE = 'none';
// this is not part of the ColumnResizerStyles object as it remains consistent for all sizers after setting it once
ColumnSizerElement.DEFAULT_HOVER_COLOR = 'grey';
ColumnSizerElement.COLUMN_SIZER_CLASS = 'column-sizer';
ColumnSizerElement.COLUMN_SIZER_ID_PREFIX = `${ColumnSizerElement.COLUMN_SIZER_CLASS}-`;
ColumnSizerElement.TRANSITION_TIME_ML = 200;
ColumnSizerElement.TRANSITION_TIME = `${ColumnSizerElement.TRANSITION_TIME_ML / 1000}s`;
ColumnSizerElement.HALF_TRANSITION_TIME_ML = ColumnSizerElement.TRANSITION_TIME_ML / 2;
//# sourceMappingURL=columnSizerElement.js.map