import { UpdateRowElement } from '../../utils/insertRemoveStructure/update/updateRowElement';
import { ColumnSizerGenericUtils } from './utils/columnSizerGenericUtils';
import { MovableColumnSizerElement } from './movableColumnSizerElement';
import { ColumnSizerSetWidth } from './utils/columnSizerSetWidth';
import { SEMI_TRANSPARENT_COLOR } from '../../consts/colors';
import { ColumnSizerElement } from './columnSizerElement';
export class ColumnSizerExtrinsicEvents {
    static moveMovableElement(selectedColumnSizer, columnsDetails, newLeft) {
        const { columnSizer } = ColumnSizerGenericUtils.getSizerDetailsViaElementId(selectedColumnSizer.id, columnsDetails);
        columnSizer.movableElement.style.left = `${newLeft}px`;
    }
    // prettier-ignore
    static windowMouseMove(at, newXMovement) {
        const { _activeOverlayElements: { selectedColumnSizer }, _columnsDetails } = at;
        if (selectedColumnSizer) {
            const { moveLimits, element } = selectedColumnSizer;
            selectedColumnSizer.mouseMoveOffset += newXMovement;
            if (selectedColumnSizer.mouseMoveOffset >= moveLimits.left
                && selectedColumnSizer.mouseMoveOffset <= moveLimits.right) {
                ColumnSizerExtrinsicEvents.moveMovableElement(element, _columnsDetails, selectedColumnSizer.mouseMoveOffset);
            }
        }
    }
    // prettier-ignore
    static setWidth(selectedColumnSizer, tableElement, tableDimensions, leftHeader, rightHeader) {
        ColumnSizerElement.unsetTransitionTime(selectedColumnSizer.element);
        ColumnSizerSetWidth.set(selectedColumnSizer, tableElement, tableDimensions, leftHeader, rightHeader);
    }
    // prettier-ignore
    static mouseUp(at) {
        var _a;
        const { _activeOverlayElements: activeOverlayElements, _columnsDetails, _tableDimensions, _tableElementRef } = at;
        const selectedColumnSizer = activeOverlayElements.selectedColumnSizer;
        const { columnSizer, headerCell, sizerNumber } = ColumnSizerGenericUtils.getSizerDetailsViaElementId(selectedColumnSizer.element.id, _columnsDetails);
        ColumnSizerExtrinsicEvents.setWidth(selectedColumnSizer, _tableElementRef, _tableDimensions, headerCell, ColumnSizerGenericUtils.findNextResizableColumnHeader(_columnsDetails, sizerNumber));
        MovableColumnSizerElement.hide(columnSizer.movableElement);
        UpdateRowElement.updateHeaderRowHeight((_a = columnSizer.element.parentElement) === null || _a === void 0 ? void 0 : _a.parentElement);
    }
    static setSizerStyleToHoverNoAnimation(columnSizer, anotherColor) {
        const { width } = columnSizer.styles.hover;
        ColumnSizerElement.setHoverStyle(columnSizer, width, false, anotherColor);
        ColumnSizerElement.unsetBackgroundImage(columnSizer.element);
    }
    static mouseUpNotOnSizer(columnSizer) {
        const { element: sizerElement, styles: sizerStyles, movableElement } = columnSizer;
        ColumnSizerExtrinsicEvents.setSizerStyleToHoverNoAnimation(columnSizer, movableElement.style.backgroundColor);
        // this kicks off the animation with the hover properties from above
        setTimeout(() => {
            ColumnSizerElement.setTransitionTime(sizerElement);
            ColumnSizerElement.unsetElementsToDefault(sizerElement, sizerStyles.default.width, false);
            ColumnSizerElement.hideWhenCellNotHovered(columnSizer, true);
        });
        // reset properties after the animation so we have the right properties for mouse enter
        setTimeout(() => {
            ColumnSizerElement.setBackgroundImage(sizerElement, sizerStyles.default.backgroundImage);
            ColumnSizerElement.setBackgroundColor(sizerElement, SEMI_TRANSPARENT_COLOR);
        }, ColumnSizerElement.TRANSITION_TIME_ML);
    }
    // if the user clicks mouse up on the table first - this will not be activated as columnSizer selected will be removed
    // prettier-ignore
    static windowMouseUp(at) {
        const { columnSizer } = ColumnSizerGenericUtils.getSizerDetailsViaElementId(at._activeOverlayElements.selectedColumnSizer.element.id, at._columnsDetails);
        ColumnSizerExtrinsicEvents.mouseUp(at);
        ColumnSizerExtrinsicEvents.mouseUpNotOnSizer(columnSizer);
        delete at._activeOverlayElements.selectedColumnSizer;
    }
    static mouseUpOnSizer(columnSizer) {
        ColumnSizerExtrinsicEvents.setSizerStyleToHoverNoAnimation(columnSizer);
        columnSizer.isMouseUpOnSizer = true;
        setTimeout(() => {
            columnSizer.isMouseUpOnSizer = false;
            ColumnSizerElement.setTransitionTime(columnSizer.element);
        });
    }
    // this method is used to get what exact element was clicked on as window events just returns the component as the target
    // prettier-ignore
    static tableMouseUp(at, target) {
        const selectedColumnSizer = at._activeOverlayElements.selectedColumnSizer;
        const { columnSizer } = ColumnSizerGenericUtils.getSizerDetailsViaElementId(selectedColumnSizer.element.id, at._columnsDetails);
        ColumnSizerExtrinsicEvents.mouseUp(at);
        // when autorise happens - the sizer usually moves out of the cursor area
        if (MovableColumnSizerElement.isMovableColumnSizer(target) && !selectedColumnSizer.wasAutoresized) {
            ColumnSizerExtrinsicEvents.mouseUpOnSizer(columnSizer);
        }
        else {
            ColumnSizerExtrinsicEvents.mouseUpNotOnSizer(columnSizer);
        }
        delete at._activeOverlayElements.selectedColumnSizer;
    }
}
//# sourceMappingURL=columnSizerExtrinsicEvents.js.map