// REF-12
export class MovableColumnSizerElement {
    // this is recalculated as it depends on the column index that the sizer is on
    static setStaticProperties(movableSizerElement, marginRight, width) {
        movableSizerElement.style.marginRight = marginRight;
        movableSizerElement.style.width = width;
    }
    // the vertical line has no pointer events, hence it should not be expected to be passed in here
    static isMovableColumnSizer(element) {
        return element.classList.contains(MovableColumnSizerElement.MOVABLE_SIZER_CLASS);
    }
    static getVerticalLineHeight(tableElement, addRowCellPresent) {
        let height = tableElement.offsetHeight;
        if (addRowCellPresent) {
            const addRowCellHeight = tableElement.lastChild.offsetHeight;
            height -= addRowCellHeight;
        }
        return height;
    }
    static display(tableElement, columnSizer, addRowCellPresent) {
        const movableSizer = columnSizer.movableElement;
        movableSizer.style.display = 'flex';
        const verticalLine = movableSizer.children[0];
        verticalLine.style.height = `${MovableColumnSizerElement.getVerticalLineHeight(tableElement, addRowCellPresent)}px`;
    }
    static hide(movableSizer) {
        movableSizer.style.display = 'none';
        movableSizer.style.left = '';
    }
    static createVerticalLine(backgroundColor) {
        const verticalLine = document.createElement('div');
        verticalLine.style.backgroundColor = backgroundColor;
        verticalLine.classList.add(MovableColumnSizerElement.VERTICAL_LINE_CLASS);
        return verticalLine;
    }
    static getMovableBackgroundColor(columnResizerColors) {
        return columnResizerColors.click || columnResizerColors.hover || MovableColumnSizerElement.DEFAULT_BACKGROUND_COLOR;
    }
    static create(columnResizerColors) {
        const backgroundColor = MovableColumnSizerElement.getMovableBackgroundColor(columnResizerColors);
        const movableSizer = document.createElement('div');
        movableSizer.style.backgroundColor = backgroundColor;
        movableSizer.classList.add(MovableColumnSizerElement.MOVABLE_SIZER_CLASS);
        MovableColumnSizerElement.hide(movableSizer);
        const verticalLine = MovableColumnSizerElement.createVerticalLine(backgroundColor);
        movableSizer.appendChild(verticalLine);
        return movableSizer;
    }
}
MovableColumnSizerElement.DEFAULT_BACKGROUND_COLOR = '#4668ed';
MovableColumnSizerElement.MOVABLE_SIZER_CLASS = 'movable-column-sizer';
MovableColumnSizerElement.VERTICAL_LINE_CLASS = 'movable-column-sizer-vertical-line';
//# sourceMappingURL=movableColumnSizerElement.js.map