import { ColumnSizerElement } from '../columnSizerElement';
import { MovableColumnSizerElement } from '../movableColumnSizerElement';
import { ColumnSizerOverlayElement } from '../columnSizerOverlayElement';
export class ColumnSizer {
    static shouldWidthBeIncreased(widthPx) {
        return widthPx > 4;
    }
    // prettier-ignore
    static getBackgroundImage(totalCellBorderWidth, leftCellLeft, beforeLeftCellRight, isLastCell, tableElement) {
        // REF-1
        // for last column sizer:
        // the strategy is to have a filled column sizer background image if the table has no border or even if it does
        // and the cells do not as they will too have filled backgrounds, hence this will maintain the consistency
        // empty background image if both cells and table have borders
        // for first to second last column sizer:
        // filled background if no border and empty if present
        if (isLastCell && tableElement) {
            if (Number.parseInt(getComputedStyle(tableElement).borderRightWidth) > 0
                && (leftCellLeft > 0 || (beforeLeftCellRight === undefined || beforeLeftCellRight > 0))) {
                return ColumnSizerElement.EMPTY_BACKGROUND_IMAGE;
            }
        }
        else if (totalCellBorderWidth > 0) {
            return ColumnSizerElement.EMPTY_BACKGROUND_IMAGE;
        }
        return ColumnSizerElement.FILLED_BACKGROUND_IMAGE;
    }
    static getMarginRight(borderWidths, isLastCell) {
        if (isLastCell || !borderWidths)
            return '0px';
        return `${borderWidths.leftCellRight - borderWidths.rightCellLeft}px`;
    }
    static getTotalCellBorderWidth(borderWidths) {
        return borderWidths ? borderWidths.rightCellLeft + borderWidths.leftCellRight : 0;
    }
    static generateBorderWidthsInfo(columnsDetails, sizerIndex) {
        var _a, _b, _c;
        // prettier-ignore
        const borderWidths = {
            rightCellLeft: 0, leftCellLeft: 0, leftCellRight: 0, beforeLeftCellRight: undefined
        };
        const beforeLeftCell = (_a = columnsDetails[sizerIndex - 1]) === null || _a === void 0 ? void 0 : _a.elements[0];
        if (beforeLeftCell) {
            borderWidths.beforeLeftCellRight = Number.parseInt(getComputedStyle(beforeLeftCell).borderRightWidth) || 0;
        }
        const leftCell = (_b = columnsDetails[sizerIndex]) === null || _b === void 0 ? void 0 : _b.elements[0];
        if (leftCell) {
            const leftCellStyle = getComputedStyle(leftCell);
            borderWidths.leftCellLeft = Number.parseInt(leftCellStyle.borderLeftWidth) || 0;
            borderWidths.leftCellRight = Number.parseInt(leftCellStyle.borderRightWidth) || 0;
        }
        const rightCell = (_c = columnsDetails[sizerIndex + 1]) === null || _c === void 0 ? void 0 : _c.elements[0];
        if (rightCell)
            borderWidths.rightCellLeft = Number.parseInt(getComputedStyle(rightCell).borderLeftWidth) || 0;
        return borderWidths;
    }
    // prettier-ignore
    static createObject(columnSizerElement, columnsDetails, sizerIndex, tableElement, overlayElement, movableColumnSizer, columnResizerColors) {
        const borderWidthsInfo = ColumnSizer.generateBorderWidthsInfo(columnsDetails, sizerIndex);
        const totalCellBorderWidth = ColumnSizer.getTotalCellBorderWidth(borderWidthsInfo);
        const isLastCell = columnsDetails.length - 1 === sizerIndex;
        const marginRight = ColumnSizer.getMarginRight(borderWidthsInfo, isLastCell);
        const backgroundImage = ColumnSizer.getBackgroundImage(totalCellBorderWidth, borderWidthsInfo.leftCellLeft, borderWidthsInfo.beforeLeftCellRight, isLastCell, tableElement);
        // movableElement should be treated as always present in columnSizer, but InsertRemoveColumnSizer needs to create
        // a new object to overwrite its other properties
        const shouldWidthBeIncreased = ColumnSizer.shouldWidthBeIncreased(totalCellBorderWidth);
        const columnSizerState = {
            element: columnSizerElement,
            styles: {
                default: {
                    width: shouldWidthBeIncreased ? `${totalCellBorderWidth + 2}px` : '1.5px',
                    backgroundImage,
                },
                hover: {
                    width: shouldWidthBeIncreased ? `${(totalCellBorderWidth + 2) * 1.5}px` : '9px',
                },
                static: {
                    marginRight,
                }
            },
            isSideCellHovered: false,
            isSizerHovered: false,
            isMouseUpOnSizer: false,
        };
        if (columnResizerColors) {
            columnSizerState.hoverColor = columnResizerColors.hover || ColumnSizerElement.DEFAULT_HOVER_COLOR;
        }
        if (movableColumnSizer)
            columnSizerState.movableElement = movableColumnSizer;
        if (overlayElement)
            columnSizerState.overlayElement = overlayElement;
        return columnSizerState;
    }
    // prettier-ignore
    static create(at, sizerIndex) {
        const { _columnsDetails, _tableElementRef, columnResizerColors } = at;
        const columnSizerElement = ColumnSizerElement.create(sizerIndex, columnResizerColors.hover);
        const movableColumnSizer = MovableColumnSizerElement.create(columnResizerColors);
        const overlayElement = ColumnSizerOverlayElement.create();
        const columnSizer = ColumnSizer.createObject(columnSizerElement, _columnsDetails, sizerIndex, _tableElementRef, overlayElement, movableColumnSizer, columnResizerColors);
        ColumnSizerOverlayElement.applyEvents(at, columnSizer);
        return columnSizer;
    }
}
//# sourceMappingURL=columnSizer.js.map