import { ColumnSizerOverlayElement } from '../columnSizerOverlayElement';
import { MovableColumnSizerElement } from '../movableColumnSizerElement';
import { ColumnSizerFillerElement } from '../columnSizerFillerElement';
import { ColumnSizerElement } from '../columnSizerElement';
import { ColumnSizer } from './columnSizer';
export class InsertRemoveColumnSizer {
    static updateIdsOfAllSubsequent(columnsDetails, nextIndex) {
        columnsDetails.slice(nextIndex).forEach((columnDetails, index) => {
            if (!columnDetails.columnSizer)
                return;
            const relativeIndex = nextIndex + index;
            ColumnSizerElement.setElementId(columnDetails.columnSizer.element, relativeIndex);
        });
    }
    static applySizerStateToElements(columnSizer) {
        const { element: sizerElement, movableElement, overlayElement, styles } = columnSizer;
        ColumnSizerElement.unsetElementsToDefault(sizerElement, styles.default.width);
        ColumnSizerFillerElement.setWidth(sizerElement.children[0], styles.default.width);
        ColumnSizerElement.setStaticProperties(sizerElement, styles.static.marginRight);
        ColumnSizerElement.setBackgroundImage(sizerElement, styles.default.backgroundImage);
        MovableColumnSizerElement.setStaticProperties(movableElement, styles.static.marginRight, styles.hover.width);
        ColumnSizerOverlayElement.setStaticProperties(overlayElement, styles.static.marginRight, styles.hover.width);
    }
    static insertAtIndex(at, newColumnDetails, columnIndex) {
        // assuming this has already been added, otherwise pass it down through params
        const cellDividerElement = newColumnDetails.elements[0].nextSibling;
        const columnSizer = ColumnSizer.create(at, columnIndex);
        newColumnDetails.columnSizer = columnSizer;
        cellDividerElement.appendChild(columnSizer.element);
        cellDividerElement.appendChild(columnSizer.overlayElement);
        cellDividerElement.appendChild(columnSizer.movableElement);
        InsertRemoveColumnSizer.applySizerStateToElements(columnSizer);
    }
    // prettier-ignore
    static updateSizer(columnSizer, columnsDetails, sizerIndex, tableElement) {
        // no need for full creation as there is a need to retain the element and its bindings
        const newColumnSizer = ColumnSizer.createObject(columnSizer.element, columnsDetails, sizerIndex, tableElement);
        // cannot simply overwrite columnSizer object as it has already binded to elements
        // movableElement ref is not overwritten
        Object.assign(columnSizer, newColumnSizer);
        InsertRemoveColumnSizer.applySizerStateToElements(columnSizer);
    }
    static updatePrevious(columnsDetails, columnIndex, tableElement) {
        var _a;
        const previousIndex = columnIndex - 1;
        if (previousIndex < 0)
            return;
        const { columnSizer } = columnsDetails[previousIndex];
        if (((_a = columnsDetails[previousIndex].settings.widths) === null || _a === void 0 ? void 0 : _a.staticWidth) !== undefined || !columnSizer)
            return;
        InsertRemoveColumnSizer.updateSizer(columnSizer, columnsDetails, columnIndex, tableElement);
    }
    static getNewColumnIndexIfWidthSet(columnsDetails, columnIndex) {
        var _a;
        // if inserting at the end and the previous column has a sizer (happens when populating the table initially)
        // do not insert a new sizer, if no sizer - insert a new sizer
        if (columnsDetails.length - 1 === columnIndex) {
            return ((_a = columnsDetails[columnIndex - 1]) === null || _a === void 0 ? void 0 : _a.columnSizer) ? -1 : columnIndex - 1;
        }
        return columnIndex;
    }
    static isNotResizable(columnDetails) {
        const { widths, isColumnResizable } = columnDetails.settings;
        return (widths === null || widths === void 0 ? void 0 : widths.staticWidth) !== undefined || !isColumnResizable;
    }
    // REF-13
    static insert(at, columnIndex) {
        const { _columnsDetails } = at;
        if (InsertRemoveColumnSizer.isNotResizable(_columnsDetails[columnIndex]))
            return;
        if (at._tableDimensions.width !== undefined) {
            columnIndex = InsertRemoveColumnSizer.getNewColumnIndexIfWidthSet(at._columnsDetails, columnIndex);
            if (columnIndex === -1 || InsertRemoveColumnSizer.isNotResizable(_columnsDetails[columnIndex]))
                return;
        }
        else {
            // only dynamic width tables have a sizer on the last column - hence only their styles need to be changed
            InsertRemoveColumnSizer.updatePrevious(_columnsDetails, columnIndex, at._tableElementRef);
        }
        InsertRemoveColumnSizer.insertAtIndex(at, _columnsDetails[columnIndex], columnIndex);
        InsertRemoveColumnSizer.updateIdsOfAllSubsequent(_columnsDetails, columnIndex + 1);
    }
    // this is only used for when table width is static, otherwise it is removed directly with the column
    static removeSizer(newColumnDetails) {
        var _a, _b, _c, _d, _e, _f;
        (_b = (_a = newColumnDetails.columnSizer) === null || _a === void 0 ? void 0 : _a.element) === null || _b === void 0 ? void 0 : _b.remove();
        (_d = (_c = newColumnDetails.columnSizer) === null || _c === void 0 ? void 0 : _c.movableElement) === null || _d === void 0 ? void 0 : _d.remove();
        (_f = (_e = newColumnDetails.columnSizer) === null || _e === void 0 ? void 0 : _e.overlayElement) === null || _f === void 0 ? void 0 : _f.remove();
        delete newColumnDetails.columnSizer;
    }
    // need to remove the sizer of the new last column as when width is set - last column does not have a sizer
    static removeIfLastColumn(columnsDetails, columnIndex) {
        const isLastColumn = columnsDetails.length === columnIndex;
        if (isLastColumn && columnsDetails[columnIndex]) {
            columnIndex -= 1;
            InsertRemoveColumnSizer.removeSizer(columnsDetails[columnIndex]);
        }
        return columnIndex;
    }
    static remove(at, columnIndex) {
        const { _tableDimensions, _columnsDetails, _tableElementRef } = at;
        if (_tableDimensions.width !== undefined) {
            columnIndex = InsertRemoveColumnSizer.removeIfLastColumn(_columnsDetails, columnIndex);
        }
        InsertRemoveColumnSizer.updatePrevious(_columnsDetails, columnIndex, _tableElementRef);
        InsertRemoveColumnSizer.updateIdsOfAllSubsequent(_columnsDetails, columnIndex);
    }
    // This is used to cleanup sizers for columns that have or had static widths because they do not have sizers,
    // additionally when the table width is set the last column that is not static also does not have a sizer.
    static cleanUpCustomColumnSizers(at, changedColumnIndex) {
        const { _tableDimensions, _columnsDetails } = at;
        if (_tableDimensions.width === undefined)
            return;
        let isLastDynamicColumnFound = false;
        // traversing backwards
        for (let i = _columnsDetails.length - 1; i >= 0; i -= 1) {
            const columnDetails = _columnsDetails[i];
            // if the column has a width or it is the last column, it should not have a sizer
            if (InsertRemoveColumnSizer.isNotResizable(columnDetails)) {
                if (columnDetails.columnSizer)
                    InsertRemoveColumnSizer.removeSizer(columnDetails);
                // dynamic column traversal (columns without a set width in settings)
            }
            else if (isLastDynamicColumnFound === false) {
                isLastDynamicColumnFound = true;
                // last column index should not have a sizer
                if (columnDetails.columnSizer)
                    InsertRemoveColumnSizer.removeSizer(columnDetails);
                // exit only if the first column without settings is before changedColumnIndex
                if (i < changedColumnIndex)
                    break;
            }
            else {
                // if column does not have settings and it is not last, it should have a sizer
                if (!columnDetails.columnSizer && _columnsDetails.length - 1 !== i) {
                    InsertRemoveColumnSizer.insertAtIndex(at, columnDetails, i);
                }
                // if the last dynamic column has already been identified and we are beyond the changed index, can exit
                if (isLastDynamicColumnFound === true && i < changedColumnIndex)
                    break;
            }
        }
    }
}
//# sourceMappingURL=insertRemoveColumnSizer.js.map