import { StaticTable } from '../../../utils/tableDimensions/staticTable/staticTable';
import { ExtractElements } from '../../../utils/elements/extractElements';
export class MoveLimits {
    // Borders of the side cells tend to breach over the limits of the table (when no side frame elements),
    // causing the offsets to give incorrect data and set the limits beyond the table. The breach magnitude is
    // influenced by the sizer start position when cells have borders - which is the very center position of
    // the total of those two borders width.
    // prettier-ignore
    static getSideLimitDelta(leftElement) {
        // left element will always be the actual element, however when width is set on the right header(s), rightHeader
        // will actually be first dynamic header in the ones following the sizer. Hence the only reliably way
        // of obtaining the actual right header is by extracting it manually by traversing the DOM.
        const rightElement = ExtractElements.getRightColumnSiblingCell(leftElement);
        const sideLimitDelta = (Number.parseFloat(getComputedStyle(leftElement).borderRightWidth) || 0)
            - (Number.parseFloat(getComputedStyle(rightElement).borderLeftWidth) || 0);
        return sideLimitDelta / 2;
    }
    static getRightLimitDynamicWidthTable() {
        return window.innerWidth;
    }
    // prettier-ignore
    static getRightLimitForMaxWidth(tableElement, tableDimensions, rightHeader) {
        if (StaticTable.isTableAtMaxWidth(tableElement, tableDimensions)) {
            return rightHeader ? Number.parseFloat(rightHeader.style.width) : 0;
        }
        return tableDimensions.maxWidth - tableElement.offsetWidth;
    }
    static getRightLimit(at, rightHeader) {
        if (at._tableDimensions.width !== undefined) {
            // there is always a resizable header on right of a sizer when table width is set
            return Number.parseFloat(rightHeader.style.width);
        }
        else if (at._tableDimensions.maxWidth !== undefined && at._tableElementRef) {
            return MoveLimits.getRightLimitForMaxWidth(at._tableElementRef, at._tableDimensions, rightHeader);
        }
        return MoveLimits.getRightLimitDynamicWidthTable();
    }
    static getLeftLimit(leftHeader, sideLimitDelta) {
        let leftLimit = -leftHeader.offsetWidth;
        if (sideLimitDelta !== undefined)
            leftLimit += sideLimitDelta;
        return leftLimit;
    }
    // prettier-ignore
    static generate(at, isFirstSizer, isLastSizer, columnSizerOffset, rightHeader, leftHeader) {
        const sideLimitDelta = isFirstSizer || isLastSizer ? MoveLimits.getSideLimitDelta(leftHeader) : 0;
        return {
            left: MoveLimits.getLeftLimit(leftHeader, isFirstSizer ? sideLimitDelta : undefined) + columnSizerOffset,
            right: MoveLimits.getRightLimit(at, rightHeader),
        };
    }
}
//# sourceMappingURL=moveLimits.js.map