import { RGBAToHex } from '../../../../utils/color/rgbaToHex';
import { OptionColorButton } from './optionColorButton';
import { OptionButton } from './optionButton';
import { Dropdown } from '../../dropdown';
export class OptionColorButtonEvents {
    static updateCellElements(columnDetails, colorPickerNewValue) {
        const { itemText, backgroundColor } = colorPickerNewValue;
        columnDetails.elements.slice(1).forEach((element) => {
            const textElement = element.children[0];
            if (textElement.innerText === itemText)
                textElement.style.backgroundColor = backgroundColor;
        });
    }
    // prettier-ignore
    static updateIfUpdatable(columnDetails, defaultColumnTypeName, colorPickerNewValue) {
        const { itemText, backgroundColor } = colorPickerNewValue;
        const itemDetails = columnDetails.cellDropdown.itemsDetails[itemText];
        if (itemDetails && (!itemDetails.isCustomBackgroundColor || defaultColumnTypeName === columnDetails.activeType.name)) {
            itemDetails.backgroundColor = backgroundColor;
            OptionColorButtonEvents.updateCellElements(columnDetails, colorPickerNewValue);
        }
    }
    // prettier-ignore
    static updateElements(columnsDetails, defaultColumnTypeName, colorPickerNewValue) {
        columnsDetails.forEach((columnDetails) => {
            if (columnDetails.cellDropdown.labelDetails) {
                OptionColorButtonEvents.updateIfUpdatable(columnDetails, defaultColumnTypeName, colorPickerNewValue);
            }
        });
    }
    static updateColorStates(columnDetails, colorPickerNewValue) {
        var _a, _b, _c;
        const { itemText, backgroundColor } = colorPickerNewValue;
        // type state
        (_b = (_a = columnDetails.activeType.cellDropdownProps) === null || _a === void 0 ? void 0 : _a.options) === null || _b === void 0 ? void 0 : _b.forEach((option) => {
            if (option.text === itemText)
                option.backgroundColor = backgroundColor;
        });
        // global color state
        const existingColors = (_c = columnDetails.cellDropdown.labelDetails) === null || _c === void 0 ? void 0 : _c.globalItemColors.existingColors;
        if (existingColors === null || existingColors === void 0 ? void 0 : existingColors[itemText])
            existingColors[itemText] = backgroundColor;
    }
    // prettier-ignore
    static updateColumnLabelColors(columnsDetails, columnDetails) {
        const { cellDropdown: { labelDetails }, activeType } = columnDetails;
        if (!labelDetails || !labelDetails.colorPickerNewValue)
            return;
        OptionColorButtonEvents.updateColorStates(columnDetails, labelDetails.colorPickerNewValue);
        OptionColorButtonEvents.updateElements(columnsDetails, activeType.name, labelDetails.colorPickerNewValue);
        delete labelDetails.colorPickerNewValue;
        setTimeout(() => columnDetails.fireColumnsUpdate());
    }
    // important to note that mouse/key down events are not fired when clicked on picker
    static windowEventClosePicker(columnsDetails, focusedElements) {
        if (focusedElements.cellDropdown) {
            const columnIndex = focusedElements.cell.columnIndex;
            OptionButton.hideAfterColorPickerContainerClose(columnsDetails, columnsDetails[columnIndex]);
        }
    }
    // bug fix comments are for code that fixes a firefox bug where color picker is still open after closing the dropdown
    static inputEvent(dropdown, event) {
        if (!Dropdown.isDisplayed(dropdown.element))
            return; // bug fix
        const inputElement = event.target;
        const { containerElement, textElement, dropdownItemElement } = OptionColorButton.extractRelativeParentElements(inputElement);
        const itemText = textElement.textContent;
        const backgroundColor = inputElement.value;
        dropdownItemElement.style.backgroundColor = backgroundColor;
        const itemDetails = dropdown.itemsDetails[itemText];
        if (itemDetails.backgroundColor !== backgroundColor) {
            itemDetails.backgroundColor = backgroundColor;
            dropdown.labelDetails.colorPickerNewValue = { backgroundColor, itemText };
            setTimeout(() => {
                var _a;
                var _b;
                (_a = (_b = dropdown.labelDetails).colorPickerContainer) !== null && _a !== void 0 ? _a : (_b.colorPickerContainer = containerElement); // bug fix
            });
        }
    }
    // prettier-ignore
    static mouseDownContainer(columnsDetails, columnDetails, event) {
        const { cellDropdown: { labelDetails } } = columnDetails;
        if (!labelDetails)
            return;
        if (labelDetails.colorPickerContainer) {
            delete labelDetails.colorPickerContainer;
            OptionColorButtonEvents.updateColumnLabelColors(columnsDetails, columnDetails);
            return;
        }
        const buttonElement = event.target;
        const { containerElement, dropdownItemElement } = OptionColorButton.extractRelativeParentElements(buttonElement);
        const inputElement = buttonElement.previousSibling;
        // using getComputedStyle because if custom backgroundColor is 'red', that's what .style.backgroundColor will return 
        inputElement.value = RGBAToHex.convert(getComputedStyle(dropdownItemElement).backgroundColor);
        inputElement.showPicker();
        setTimeout(() => (labelDetails.colorPickerContainer = containerElement));
    }
    // prettier-ignore
    static setEvents(container, colorInput, columnsDetails, columnDetails) {
        container.onmousedown = OptionColorButtonEvents.mouseDownContainer.bind(this, columnsDetails, columnDetails);
        colorInput.oninput = OptionColorButtonEvents.inputEvent.bind(this, columnDetails.cellDropdown);
    }
}
//# sourceMappingURL=optionColorButtonEvents.js.map