import { CellWithTextEvents } from '../../cell/cellsWithTextDiv/cellWithTextEvents';
import { CellDropdownItem } from './cellDropdownItem';
import { OptionButton } from './buttons/optionButton';
import { DropdownItem } from '../dropdownItem';
import { Dropdown } from '../dropdown';
export class CellDropdownEvents {
    // instead of binding click event handlers with the context of current row index to individual item elements every
    // time the dropdown is displayed, click events are handled on the dropdown instead, the reason for this is
    // because it can be expensive to rebind an arbitrary amount of items e.g. 10000+
    // prettier-ignore
    static click(event) {
        const targetElement = event.target;
        // target is dropdown when clicked on top/bottom paddding
        if (targetElement.classList.contains(Dropdown.DROPDOWN_CLASS)
            || targetElement.classList.contains(OptionButton.BUTTON_CLASS))
            return;
        const { rowIndex, columnIndex, element: cellElement } = this._focusedElements.cell;
        const itemElement = targetElement.classList.contains(DropdownItem.DROPDOWN_ITEM_CLASS)
            ? targetElement : targetElement.parentElement;
        CellDropdownItem.selectExistingItem(this, itemElement, rowIndex, columnIndex, cellElement.children[0]);
        CellWithTextEvents.programmaticBlur(this);
    }
    // this is required to record to stop cell blur from closing the dropdown
    // additionally if the user clicks on dropdown scroll or padding, this will record it
    static mouseDown(focusedElements, dropdownElement) {
        focusedElements.cellDropdown = dropdownElement;
    }
    static set(at, dropdownElement) {
        dropdownElement.onmousedown = CellDropdownEvents.mouseDown.bind(this, at._focusedElements, dropdownElement);
        dropdownElement.onclick = CellDropdownEvents.click.bind(at);
    }
}
//# sourceMappingURL=cellDropdownEvents.js.map