import { LabelCellTextElement } from '../../cell/cellsWithTextDiv/selectCell/label/labelCellTextElement';
import { CaretPosition } from '../../../utils/focusedElements/caretPosition';
import { LabelColorUtils } from '../../../utils/color/labelColorUtils';
import { CellDropdownItemEvents } from './cellDropdownItemEvents';
import { OptionDeleteButton } from './buttons/optionDeleteButton';
import { OptionColorButton } from './buttons/optionColorButton';
import { FireEvents } from '../../../utils/events/fireEvents';
import { Browser } from '../../../utils/browser/browser';
import { CellElement } from '../../cell/cellElement';
import { EMPTY_STRING } from '../../../consts/text';
import { CellEvents } from '../../cell/cellEvents';
import { DropdownItem } from '../dropdownItem';
export class CellDropdownItem {
    // prettier-ignore
    static updateCellElementIfNotUpdated(at, newText, rowIndex, columnIndex, textElement) {
        if ((at.content[rowIndex][columnIndex]) !== newText) {
            CellEvents.updateCell(at, newText, rowIndex, columnIndex, { processText: false, element: textElement });
        }
    }
    // prettier-ignore
    static selectExistingItem(at, activeItemElement, rowIndex, columnIndex, textElement) {
        var _a;
        const newText = CellElement.getText(activeItemElement.children[0]);
        CellDropdownItem.updateCellElementIfNotUpdated(at, newText, rowIndex, columnIndex, textElement);
        if (LabelCellTextElement.isLabelText(textElement)) {
            textElement.style.backgroundColor = (_a = at._columnsDetails[columnIndex]
                .cellDropdown.itemsDetails[newText]) === null || _a === void 0 ? void 0 : _a.backgroundColor;
        }
    }
    // prettier-ignore
    static addNewItem(at, textElement, columnDetails, color) {
        var _a;
        const { cellDropdown: { labelDetails } } = columnDetails;
        const newItemText = CellElement.getText(textElement);
        if (newItemText === EMPTY_STRING)
            return;
        let newColor = '';
        if (labelDetails) {
            const { globalItemColors: { newColors, existingColors } } = labelDetails;
            newColor = color || existingColors[newItemText]
                || newColors[newColors.length - 1] || LabelColorUtils.getLatestPasteleColor();
            textElement.style.backgroundColor = newColor;
            (_a = existingColors[newItemText]) !== null && _a !== void 0 ? _a : (existingColors[newItemText] = newColor);
            newColors.pop() || LabelColorUtils.setNewLatestPasteleColor();
        }
        else {
            newColor = CellDropdownItem.ACTIVE_ITEM_BACKGROUND_COLOR;
        }
        CellDropdownItem.addItem(at, newItemText, newColor, columnDetails);
        setTimeout(() => FireEvents.onColumnsUpdate(at));
    }
    // prettier-ignore
    static updateCellTextBgColor(itemElement, textElement, dropdown, defaultText) {
        const cellText = CellElement.getText(textElement);
        if (itemElement) {
            textElement.style.backgroundColor = dropdown.itemsDetails[cellText].backgroundColor;
        }
        else if (!dropdown.canAddMoreOptions || cellText === EMPTY_STRING || cellText === defaultText) {
            textElement.style.backgroundColor = '';
        }
        else if (dropdown.labelDetails) {
            const { globalItemColors: { newColors, existingColors } } = dropdown.labelDetails;
            textElement.style.backgroundColor = existingColors[cellText] || (newColors === null || newColors === void 0 ? void 0 : newColors[newColors.length - 1])
                || LabelColorUtils.getLatestPasteleColor();
        }
    }
    static updateItemColor(itemElement, activeItems) {
        if (itemElement) {
            activeItems.matchingWithCellText = itemElement;
            itemElement.dispatchEvent(new MouseEvent('mouseenter'));
        }
    }
    static hideHoveredItemHighlight(activeItems) {
        const { hovered, matchingWithCellText } = activeItems;
        if (hovered) {
            hovered.style.backgroundColor = '';
        }
        else {
            activeItems.hovered = matchingWithCellText;
        }
    }
    // prettier-ignore
    static attemptHighlightMatchingItemWithCell(textElement, dropdown, defaultText, updateCellText, matchingCellElement) {
        var _a;
        const { activeItems, itemsDetails } = dropdown;
        const targetText = CellElement.getText(textElement);
        const itemElement = matchingCellElement || ((_a = itemsDetails[targetText]) === null || _a === void 0 ? void 0 : _a.element);
        if (!itemElement || activeItems.matchingWithCellText !== itemElement) {
            // this is used to preserve the ability for the user to still allow the use of arrow keys to traverse the dropdown
            CellDropdownItem.hideHoveredItemHighlight(activeItems);
            CellDropdownItemEvents.blurItem(dropdown, 'matchingWithCellText');
        }
        CellDropdownItem.updateItemColor(itemElement, activeItems);
        if (updateCellText && dropdown.labelDetails) {
            CellDropdownItem.updateCellTextBgColor(itemElement, textElement, dropdown, defaultText);
        }
    }
    // prettier-ignore
    static setItemOnCell(at, item) {
        const { element, rowIndex, columnIndex } = at._focusedElements.cell;
        const { cellDropdown, settings: { defaultText } } = at._columnsDetails[columnIndex];
        const textElement = element.children[0];
        const itemText = CellElement.getText(item.children[0]);
        CellDropdownItem.updateCellElementIfNotUpdated(at, itemText, rowIndex, columnIndex, textElement);
        CellDropdownItem.attemptHighlightMatchingItemWithCell(textElement, cellDropdown, defaultText, true, item);
        CaretPosition.setToEndOfText(at, textElement);
    }
    // prettier-ignore
    static setSiblingItemOnCell(at, activeItems, sibling) {
        const { hovered, matchingWithCellText } = activeItems;
        const currentlyHighlightedItem = hovered || matchingWithCellText;
        const siblingItem = currentlyHighlightedItem === null || currentlyHighlightedItem === void 0 ? void 0 : currentlyHighlightedItem[sibling];
        if (siblingItem) {
            CellDropdownItem.setItemOnCell(at, siblingItem);
        }
        else {
            const { columnIndex } = at._focusedElements.cell;
            const dropdownElement = at._columnsDetails[columnIndex].cellDropdown.element;
            if (sibling === 'nextSibling') {
                const firstItem = dropdownElement.children[0];
                if (firstItem)
                    CellDropdownItem.setItemOnCell(at, firstItem);
            }
            else {
                const lastItem = dropdownElement.children[dropdownElement.children.length - 1];
                if (lastItem)
                    CellDropdownItem.setItemOnCell(at, lastItem);
            }
        }
    }
    static addItemElement(at, text, columnDetails, atStart = false) {
        const { cellDropdown } = columnDetails;
        const itemElement = DropdownItem.addPlaneButtonItem(cellDropdown.element, text, atStart ? 0 : undefined);
        if (cellDropdown.customItemStyle)
            itemElement.style.color = cellDropdown.customItemStyle.textColor;
        if (cellDropdown.canAddMoreOptions) {
            const deleteButtonElement = OptionDeleteButton.create(at, columnDetails);
            itemElement.appendChild(deleteButtonElement);
            if (Browser.IS_COLOR_PICKER_SUPPORTED && cellDropdown.labelDetails) {
                const colorInputElement = OptionColorButton.create(at._columnsDetails, columnDetails);
                itemElement.appendChild(colorInputElement);
            }
        }
        CellDropdownItemEvents.set(at.shadowRoot, itemElement, cellDropdown);
        return itemElement;
    }
    static addItem(at, itemText, color, columnDetails, custom = false) {
        columnDetails.cellDropdown.itemsDetails[itemText] = {
            backgroundColor: color,
            isCustomBackgroundColor: custom,
            element: CellDropdownItem.addItemElement(at, itemText, columnDetails),
        };
    }
    static addItems(at, itemToColor, columnDetails) {
        columnDetails.cellDropdown.element.replaceChildren();
        columnDetails.cellDropdown.itemsDetails = {};
        Object.keys(itemToColor).forEach((itemText) => {
            CellDropdownItem.addItem(at, itemText, itemToColor[itemText].color, columnDetails, !!itemToColor[itemText].isCustom);
        });
    }
    static postProcessItemToColor(isDefaultTxtRemovable, itemToColor, defaultText) {
        if (isDefaultTxtRemovable)
            delete itemToColor[defaultText];
    }
    // prettier-ignore
    static processNewItemsToColor(content, columnIndex, itemToColor, labelDetails) {
        content.slice(1).reduce((itemToColor, row) => {
            var _a;
            const cellText = row[columnIndex];
            if (cellText !== EMPTY_STRING && !itemToColor[cellText]) {
                if (labelDetails) {
                    const { globalItemColors: { newColors, existingColors } } = labelDetails;
                    itemToColor[cellText] = { color: existingColors[cellText] || newColors.pop()
                            || LabelColorUtils.getLatestPasteleColorAndSetNew() };
                    (_a = existingColors[cellText]) !== null && _a !== void 0 ? _a : (existingColors[cellText] = itemToColor[cellText].color);
                }
                else {
                    itemToColor[cellText] = { color: CellDropdownItem.ACTIVE_ITEM_BACKGROUND_COLOR };
                }
            }
            return itemToColor;
        }, itemToColor);
    }
    // prettier-ignore
    static changeUserOptionsToItemToColor(userOptions, labelDetails) {
        return userOptions.reduce((itemToColor, option) => {
            var _a;
            var _b;
            if (labelDetails) {
                const { globalItemColors: { newColors, existingColors } } = labelDetails;
                itemToColor[option.text] = { color: option.backgroundColor || existingColors[option.text]
                        || newColors.pop() || LabelColorUtils.getLatestPasteleColorAndSetNew(), isCustom: true };
                (_a = existingColors[_b = option.text]) !== null && _a !== void 0 ? _a : (existingColors[_b] = itemToColor[option.text].color);
            }
            else {
                itemToColor[option.text] = { color: CellDropdownItem.ACTIVE_ITEM_BACKGROUND_COLOR, isCustom: true };
            }
            return itemToColor;
        }, {});
    }
    // prettier-ignore
    static populateItems(at, columnIndex) {
        const { content, _columnsDetails } = at;
        const columnDetails = _columnsDetails[columnIndex];
        const { cellDropdown: { labelDetails }, settings: { defaultText, isDefaultTextRemovable }, activeType: { cellDropdownProps } } = columnDetails;
        if (!cellDropdownProps)
            return;
        let itemToColor = {};
        if (cellDropdownProps.options) {
            itemToColor = CellDropdownItem.changeUserOptionsToItemToColor(cellDropdownProps.options, labelDetails);
        }
        if (cellDropdownProps.canAddMoreOptions) {
            CellDropdownItem.processNewItemsToColor(content, columnIndex, itemToColor, labelDetails);
        }
        CellDropdownItem.postProcessItemToColor(isDefaultTextRemovable, itemToColor, defaultText);
        CellDropdownItem.addItems(at, itemToColor, columnDetails);
    }
}
CellDropdownItem.ACTIVE_ITEM_BACKGROUND_COLOR = '#4a69d4';
//# sourceMappingURL=cellDropdownItem.js.map