import { DropdownItemHighlightUtils } from '../../../utils/color/dropdownItemHighlightUtils';
import { CellDropdownHorizontalScrollFix } from './cellDropdownHorizontalScrollFix';
import { ElementVisibility } from '../../../utils/elements/elementVisibility';
import { OptionButton } from './buttons/optionButton';
import { SIDE } from '../../../types/side';
export class CellDropdownItemEvents {
    // prettier-ignore
    static blurItem(dropdown, typeOfItem, event) {
        var _a;
        const { activeItems, labelDetails } = dropdown;
        if (labelDetails === null || labelDetails === void 0 ? void 0 : labelDetails.colorPickerContainer)
            return; // do not blur if color picker open
        const itemElement = activeItems[typeOfItem];
        if (itemElement !== undefined) {
            if (typeOfItem === 'matchingWithCellText'
                || (typeOfItem === 'hovered' && itemElement !== activeItems.matchingWithCellText)) {
                itemElement.style.backgroundColor = '';
                if (!labelDetails)
                    itemElement.style.color = ((_a = dropdown.customItemStyle) === null || _a === void 0 ? void 0 : _a.textColor) || '';
                delete activeItems[typeOfItem];
            }
        }
        if (event && dropdown.canAddMoreOptions)
            OptionButton.changeVisibility(event, dropdown);
    }
    // prettier-ignore
    static scrollToItem(shadow, itemElement, isHorizontalScrollPresent, dropdownElement, event) {
        // not automatically scrolling when user hovers their mouse over a partial item as it is bad UX
        if (event.isTrusted)
            return;
        const visibilityDetails = ElementVisibility.isVerticallyVisibleInsideParent(itemElement, shadow);
        if (!visibilityDetails.isFullyVisible) {
            itemElement.scrollIntoView({ block: 'nearest' });
            // REF-4
            if (isHorizontalScrollPresent && visibilityDetails.blockingSides.has(SIDE.BOTTOM)) {
                CellDropdownHorizontalScrollFix.scrollDownFurther(dropdownElement);
            }
        }
    }
    static highlightItem(dropdown, event) {
        const { scrollbarPresence, activeItems, labelDetails, canAddMoreOptions, element, itemsDetails } = dropdown;
        if (labelDetails === null || labelDetails === void 0 ? void 0 : labelDetails.colorPickerContainer)
            return; // do not highlight new if color picker open
        // this is used for a case where an item is highlighted via arrow and then mouse hovers over another item
        if (activeItems.hovered) {
            activeItems.hovered.style.backgroundColor = '';
            if (!labelDetails)
                activeItems.hovered.style.color = '';
        }
        const itemElement = event.target;
        const text = itemElement.children[0].innerText;
        itemElement.style.backgroundColor = itemsDetails[text].backgroundColor;
        const dropdownElement = itemElement.parentElement;
        CellDropdownItemEvents.scrollToItem(this, itemElement, scrollbarPresence.horizontal, dropdownElement, event);
        if (itemElement === activeItems.matchingWithCellText) {
            if (!labelDetails)
                itemElement.style.color = 'white';
            delete activeItems.hovered;
        }
        else {
            if (!labelDetails)
                itemElement.style.backgroundColor = DropdownItemHighlightUtils.HOVER_BACKGROUND_COLOR;
            activeItems.hovered = itemElement;
        }
        if (canAddMoreOptions)
            OptionButton.changeVisibility(event, dropdown, element);
    }
    static set(shadow, itemElement, dropdown) {
        itemElement.onmouseenter = CellDropdownItemEvents.highlightItem.bind(shadow, dropdown);
        itemElement.onmouseleave = CellDropdownItemEvents.blurItem.bind(this, dropdown, 'hovered');
    }
}
//# sourceMappingURL=cellDropdownItemEvents.js.map