import { MaximumColumns } from '../../../utils/insertRemoveStructure/insert/maximum/maximumColumns';
import { ColumnDropdownButtonItemConf } from './columnDropdownButtonItemConf';
import { ColumnDropdownItemEvents } from './columnDropdownItemEvents';
import { ObjectUtils } from '../../../utils/object/objectUtils';
import { ColumnTypeDropdown } from './columnTypeDropdown';
import { DropdownItem } from '../dropdownItem';
export class ColumnDropdownItem {
    static resetItems(dropdownElement) {
        const items = Array.from(dropdownElement.children);
        items.forEach((item) => DropdownItem.toggleItem(item, true));
    }
    static addItems(at, dropdownElement) {
        // creating icons is expensive and they are not needed on initial render
        setTimeout(() => {
            DropdownItem.addTitle(dropdownElement, 'Property type');
            ColumnTypeDropdown.create(at, dropdownElement);
            DropdownItem.addDivider(dropdownElement);
            ColumnDropdownButtonItemConf.ITEMS.slice(0, 2).forEach((item) => {
                DropdownItem.addButtonItem(at, dropdownElement, item, ColumnDropdownItem.SORT_ITEM_CLASS);
            });
            ColumnDropdownButtonItemConf.ITEMS.slice(2).forEach((item) => {
                DropdownItem.addButtonItem(at, dropdownElement, item);
            });
        });
    }
    // hide divider when there are no items below
    static hideDivider(items) {
        const visibleIcon = items.slice(4).find((element) => element.style.display !== 'none');
        if (!visibleIcon)
            DropdownItem.toggleItem(items[3], false);
    }
    static toggleItems(settings, items) {
        const { isSortAvailable, isDeleteAvailable, isInsertLeftAvailable, isInsertRightAvailable, isMoveAvailable } = settings;
        if (!isSortAvailable) {
            DropdownItem.toggleItem(items[4], false);
            DropdownItem.toggleItem(items[5], false);
        }
        if (!isInsertLeftAvailable)
            DropdownItem.toggleItem(items[6], false);
        if (!isInsertRightAvailable)
            DropdownItem.toggleItem(items[7], false);
        if (!isMoveAvailable) {
            // their display should be toggled if can't move any further
            DropdownItem.toggleItem(items[8], false);
            DropdownItem.toggleItem(items[9], false);
        }
        if (!isDeleteAvailable)
            DropdownItem.toggleItem(items[10], false);
        ColumnDropdownItem.hideDivider(items);
    }
    // prettier-ignore
    static setUpInputElement(at, columnIndex, cellElement, inputItem, dropdownElement) {
        var _a, _b, _c;
        const { isCellTextEditable, isHeaderTextEditable } = at._columnsDetails[columnIndex].settings;
        if (((_c = (_b = (_a = at._defaultColumnsSettings.columnDropdown) === null || _a === void 0 ? void 0 : _a.displaySettings) === null || _b === void 0 ? void 0 : _b.openMethod) === null || _c === void 0 ? void 0 : _c.overlayClick) ||
            (ObjectUtils.areValuesFullyDefined(isHeaderTextEditable) ? !isHeaderTextEditable : !isCellTextEditable)) {
            DropdownItem.toggleItem(inputItem, false);
        }
        else {
            const inputElement = inputItem.children[0];
            inputElement.value = at.content[0][columnIndex];
            ColumnDropdownItemEvents.setInputItemEvent(at, columnIndex, cellElement, inputElement, dropdownElement);
        }
    }
    static setUp(at, dropdownElement, columnIndex, cellElement) {
        ColumnTypeDropdown.setUp(at, dropdownElement, columnIndex);
        const items = Array.from(dropdownElement.children);
        ColumnDropdownItem.setUpInputElement(at, columnIndex, cellElement, items[0], dropdownElement);
        ColumnDropdownItem.toggleItems(at._columnsDetails[columnIndex].settings.columnDropdown, items);
        ColumnDropdownItem.updateItemsStyle(at, columnIndex, dropdownElement);
        ColumnDropdownItemEvents.setItemEvents(at, columnIndex, dropdownElement);
    }
    static updateMoveColumnItemsStyle(at, colIndex, items) {
        const { isMoveAvailable } = at._columnsDetails[colIndex].settings.columnDropdown;
        if (!isMoveAvailable)
            return;
        DropdownItem.toggleUsability(items[8], true);
        DropdownItem.toggleUsability(items[9], true);
        if (colIndex === 0) {
            DropdownItem.toggleUsability(items[8], false);
        }
        if (colIndex === at._columnsDetails.length - 1) {
            DropdownItem.toggleUsability(items[9], false);
        }
    }
    static updateInsertColumnItemsStyle(at, items) {
        const canAddMoreColumns = MaximumColumns.canAddMore(at);
        if (canAddMoreColumns) {
            DropdownItem.toggleUsability(items[6], true);
            DropdownItem.toggleUsability(items[7], true);
        }
        else {
            DropdownItem.toggleUsability(items[6], false);
            DropdownItem.toggleUsability(items[7], false);
        }
    }
    static updateItemsStyle(at, columnIndex, dropdownElement) {
        const items = Array.from(dropdownElement.children);
        ColumnDropdownItem.updateInsertColumnItemsStyle(at, items);
        ColumnDropdownItem.updateMoveColumnItemsStyle(at, columnIndex, items);
    }
}
ColumnDropdownItem.SORT_ITEM_CLASS = 'dropdown-sort-item';
//# sourceMappingURL=columnDropdownItem.js.map