import { GenericElementUtils } from '../../utils/elements/genericElementUtils';
import { DropdownItem } from './dropdownItem';
export class Dropdown {
    static createBase() {
        const dropdownElement = document.createElement('div');
        dropdownElement.classList.add(Dropdown.DROPDOWN_CLASS);
        // using width to be able to center the dropdown relative to the cell
        // alternative approach is to use a parent div for the dropdown which would be centered relativer to the cell
        // and there would be no need for an equation to center the dropdown using its width, but this is simpler
        dropdownElement.style.width = `${Dropdown.DROPDOWN_WIDTH}px`;
        // padding specified to allow use of element style before displaying it
        dropdownElement.style.paddingTop = Dropdown.DROPDOWN_VERTICAL_PX;
        dropdownElement.style.paddingBottom = Dropdown.DROPDOWN_VERTICAL_PX;
        Dropdown.hide(dropdownElement);
        return dropdownElement;
    }
    static isDisplayed(element) {
        return (element === null || element === void 0 ? void 0 : element.style.display) === Dropdown.CSS_DISPLAY_VISIBLE;
    }
    static display(...elements) {
        elements.forEach((element) => {
            element.style.display = Dropdown.CSS_DISPLAY_VISIBLE;
        });
    }
    static hide(...elements) {
        GenericElementUtils.hideElements(...elements);
    }
    static isPartOfDropdownElement(element) {
        return element.classList.contains(Dropdown.DROPDOWN_CLASS) || DropdownItem.doesElementContainItemClass(element);
    }
}
Dropdown.DROPDOWN_CLASS = 'active-table-dropdown';
// when there is a horizontal overflow (select/label) - this automatically stretches all items to the dropdown width
Dropdown.CSS_DISPLAY_VISIBLE = 'grid';
Dropdown.DROPDOWN_WIDTH = 176;
Dropdown.DROPDOWN_VERTICAL_PX = '4px';
//# sourceMappingURL=dropdown.js.map