import { NestedDropdownItem } from './nestedDropdown/nestedDropdownItem';
import { DropdownItem } from './dropdownItem';
import { Dropdown } from './dropdown';
export class DropdownItemNavigation {
    static focusInputElement(inputItemElement) {
        inputItemElement.children[0].dispatchEvent(new MouseEvent('mouseenter'));
    }
    // either at the end when isNext is true or the start when isNext is false
    static focusItemWhenOnEdge(focusedItem, dropdownElement, isNext) {
        var _a;
        // when inside an input item
        if (DropdownItem.doesElementContainInputClass(focusedItem)) {
            const itemElement = focusedItem.parentElement;
            return DropdownItemNavigation.focusSiblingItem(itemElement, dropdownElement, isNext);
        }
        // when at the end of nested dropdown item
        const dropdownParent = (_a = focusedItem.parentElement) === null || _a === void 0 ? void 0 : _a.parentElement;
        if (dropdownParent.classList.contains(DropdownItem.DROPDOWN_ITEM_CLASS)) {
            dropdownElement = focusedItem.parentElement;
        }
        // when on last item
        const lastItem = isNext ? dropdownElement.children[0] : dropdownElement.children[dropdownElement.children.length - 1];
        return DropdownItemNavigation.focusSiblingItem(lastItem, dropdownElement, isNext, true);
    }
    // isEdgeItem means is it a start/end or inside item
    // prettier-ignore
    static focusSiblingItem(focusedItem, dropdownElement, isNext, isEdgeItem = false) {
        if (focusedItem.classList.contains(NestedDropdownItem.NESTED_DROPDOWN_ITEM)) {
            const nestedDropdownElement = focusedItem.children[2];
            // when on item that has open nested dropdown
            if (Dropdown.isDisplayed(nestedDropdownElement))
                Dropdown.hide(nestedDropdownElement);
        }
        const siblingElement = isEdgeItem
            ? focusedItem : focusedItem[isNext ? 'nextSibling' : 'previousSibling'];
        if (!siblingElement) {
            return DropdownItemNavigation.focusItemWhenOnEdge(focusedItem, dropdownElement, isNext);
            // when item is a title, divider or not displayed
        }
        else if (!DropdownItem.isDisplayed(siblingElement)
            || siblingElement.classList.contains(DropdownItem.DROPDOWN_TITLE_ITEM_CLASS)
            || siblingElement.classList.contains(DropdownItem.DROPDOWN_ITEM_DIVIDER_CLASS)) {
            return DropdownItemNavigation.focusSiblingItem(siblingElement, dropdownElement, isNext);
            // when on an input item
        }
        else if (siblingElement.classList.contains(DropdownItem.DROPDOWN_INPUT_ITEM_CLASS)) {
            return DropdownItemNavigation.focusInputElement(siblingElement);
        }
        siblingElement.dispatchEvent(new MouseEvent('mouseenter'));
    }
    static focusFirstNestedDropdownItem(focusedItem) {
        if (focusedItem.classList.contains(NestedDropdownItem.NESTED_DROPDOWN_ITEM)) {
            const nestedDropdownElement = focusedItem.children[2];
            // when on item that has open nested dropdown
            if (Dropdown.isDisplayed(nestedDropdownElement)) {
                const lastNestedDropdownElement = nestedDropdownElement.children[0];
                lastNestedDropdownElement.dispatchEvent(new MouseEvent('mouseenter'));
            }
        }
    }
    static focusNestedDropdownParentItem(focusedItem) {
        var _a;
        const dropdownParentItem = (_a = focusedItem.parentElement) === null || _a === void 0 ? void 0 : _a.parentElement;
        if (dropdownParentItem.classList.contains(DropdownItem.DROPDOWN_ITEM_CLASS)) {
            Dropdown.hide(focusedItem.parentElement);
            dropdownParentItem.dispatchEvent(new MouseEvent('mouseenter'));
        }
    }
}
//# sourceMappingURL=dropdownItemNavigation.js.map