import { ElementVisibility } from '../../../utils/elements/elementVisibility';
import { OverflowUtils } from '../../../utils/overflow/overflowUtils';
import { DropdownItem } from '../dropdownItem';
import { SIDE } from '../../../types/side';
import { Dropdown } from '../dropdown';
export class NestedDropdown {
    static create(at, itemSettings) {
        const dropdownElement = Dropdown.createBase();
        dropdownElement.style.top = `-${Number.parseInt(dropdownElement.style.paddingTop) + 22}px`;
        if (at && itemSettings)
            DropdownItem.addNewButtonItems(at, dropdownElement, itemSettings);
        return dropdownElement;
    }
    static resetPosition(nestedDropdownElement) {
        nestedDropdownElement.style.left = '';
    }
    static hideDropdown(event) {
        const nestedDropdownElement = event.target.children[2];
        nestedDropdownElement.style.display = 'none';
        NestedDropdown.resetPosition(nestedDropdownElement);
    }
    // prettier-ignore
    static correctPosition(nestedDropdownElement, parentDropdownElement, borderDimensions) {
        const visibilityDetails = ElementVisibility.getDetailsInWindow(nestedDropdownElement, borderDimensions);
        if (!visibilityDetails.isFullyVisible && visibilityDetails.blockingSides.has(SIDE.RIGHT)) {
            nestedDropdownElement.style.left = `-${parentDropdownElement.style.width}`;
            const visibilityDetails = ElementVisibility.getDetailsInWindow(nestedDropdownElement, borderDimensions);
            if (!visibilityDetails.isFullyVisible && visibilityDetails.blockingSides.has(SIDE.LEFT)) {
                nestedDropdownElement.style.left = '';
            }
        }
    }
    // prettier-ignore
    static correctPositionForOverflow(at, nestedDropdownElement, parentDropdownElement) {
        const { _tableElementRef, _overflow } = at;
        if (!_tableElementRef || !_overflow)
            return;
        if (_tableElementRef.offsetWidth !== _overflow.overflowContainer.scrollWidth) {
            nestedDropdownElement.style.left = `-${parentDropdownElement.style.width}`;
            if (nestedDropdownElement.getBoundingClientRect().x < 0) {
                nestedDropdownElement.style.left = '';
            }
        }
    }
    static displayAndSetDropdownPosition(event) {
        const nestedDropdownElement = event.target.children[2];
        const parentDropdownElement = event.target.parentElement;
        nestedDropdownElement.style.left = parentDropdownElement.style.width;
        nestedDropdownElement.style.display = parentDropdownElement.style.display;
        if (this._overflow && OverflowUtils.isOverflowElement(this._overflow.overflowContainer)) {
            NestedDropdown.correctPositionForOverflow(this, nestedDropdownElement, parentDropdownElement);
        }
        else {
            NestedDropdown.correctPosition(nestedDropdownElement, parentDropdownElement, this._tableDimensions.border);
        }
    }
}
//# sourceMappingURL=nestedDropdown.js.map