import { RowDropdownCellOverlayEvents } from './rowDropdownCellOverlayEvents';
import { ExtractElements } from '../../../../utils/elements/extractElements';
import { DropdownCellOverlay } from '../../cellOverlay/dropdownCellOverlay';
export class RowDropdownCellOverlay {
    static setDefault(rowDropdownCellOverlay, overlayStyles) {
        var _a;
        rowDropdownCellOverlay.style.backgroundColor = ((_a = overlayStyles === null || overlayStyles === void 0 ? void 0 : overlayStyles.default) === null || _a === void 0 ? void 0 : _a.backgroundColor) || '';
    }
    static resetDefaultColor(displaySettings, rowDropdownCellOverlay) {
        var _a;
        const overlayStyles = displaySettings.overlayStyles;
        if ((_a = overlayStyles === null || overlayStyles === void 0 ? void 0 : overlayStyles.hover) === null || _a === void 0 ? void 0 : _a.backgroundColor) {
            RowDropdownCellOverlay.setDefault(rowDropdownCellOverlay, overlayStyles);
        }
    }
    static setHoverColor(displaySettings, rowDropdownCellOverlay) {
        var _a, _b;
        const hoverBackgroundColor = (_b = (_a = displaySettings.overlayStyles) === null || _a === void 0 ? void 0 : _a.hover) === null || _b === void 0 ? void 0 : _b.backgroundColor;
        if (hoverBackgroundColor)
            rowDropdownCellOverlay.style.backgroundColor = hoverBackgroundColor;
    }
    static hide(at, rowIndex) {
        const currentIndexCell = at._hoveredElements.leftMostCell;
        setTimeout(() => {
            if (currentIndexCell !== at._hoveredElements.leftMostCell) {
                const overlayElement = at._rowDropdownCellOverlays[rowIndex].element;
                overlayElement.style.width = DropdownCellOverlay.HIDDEN_PX;
            }
        });
    }
    static display(at, rowIndex) {
        const firstColumn = at._columnsDetails[0];
        const rowDropdownCellOverlay = at._rowDropdownCellOverlays[rowIndex].element;
        rowDropdownCellOverlay.style.width = DropdownCellOverlay.VISIBLE_PX;
        const firstColElement = firstColumn.elements[rowIndex];
        const { displayIndexColumn } = at._frameComponents;
        const leftMostElement = (displayIndexColumn ? firstColElement.previousSibling : firstColElement);
        const onePercentWidth = leftMostElement.offsetHeight / 100;
        rowDropdownCellOverlay.style.height = `${onePercentWidth * 60}px`;
        rowDropdownCellOverlay.style.top = `${onePercentWidth * 20}px`;
        const left = displayIndexColumn ? firstColumn.elements[0].offsetWidth : 0;
        rowDropdownCellOverlay.style.left = `-${leftMostElement.offsetWidth + left}px`;
    }
    static create(overlayStyles) {
        const rowDropdownCellOverlay = document.createElement('div');
        rowDropdownCellOverlay.classList.add(RowDropdownCellOverlay.ROW_DROPDOWN_CELL_OVERLAY_CLASS);
        rowDropdownCellOverlay.classList.add(DropdownCellOverlay.DROPDOWN_CELL_OVERLAY_CLASS);
        rowDropdownCellOverlay.style.width = DropdownCellOverlay.HIDDEN_PX;
        RowDropdownCellOverlay.setDefault(rowDropdownCellOverlay, overlayStyles);
        return rowDropdownCellOverlay;
    }
    static getCellDividerElement(leftMostCell, displayIndexColumn) {
        let cellDividerElement = leftMostCell.nextSibling;
        // index column does not have a cell divider so using the first data column divider instead
        if (displayIndexColumn)
            cellDividerElement = cellDividerElement.nextSibling;
        return cellDividerElement;
    }
    static add(at, rowIndex, leftMostCell) {
        const rowDropdownCellOverlay = RowDropdownCellOverlay.create(at.rowDropdown.displaySettings.overlayStyles);
        const { displayIndexColumn } = at._frameComponents;
        const cellDividerElement = RowDropdownCellOverlay.getCellDividerElement(leftMostCell, !!displayIndexColumn);
        cellDividerElement.appendChild(rowDropdownCellOverlay);
        at._rowDropdownCellOverlays.splice(rowIndex, 0, {
            element: rowDropdownCellOverlay,
            // these events are stubs and will be replaced by real ones in RowDropdownCellOverlayEvents.addCellEvents
            enter: () => { },
            leave: () => { },
        });
    }
    static resetOverlays(at) {
        var _a;
        if (!((_a = at.rowDropdown.displaySettings.openMethod) === null || _a === void 0 ? void 0 : _a.overlayClick))
            return;
        at._rowDropdownCellOverlays.splice(0, at._rowDropdownCellOverlays.length);
        const rows = ExtractElements.textRowsArrFromTBody(at._tableBodyElementRef, at.content);
        rows.forEach((rowElement, rowIndex) => {
            const leftMostCell = rowElement.children[0];
            RowDropdownCellOverlay.add(at, rowIndex, leftMostCell);
            RowDropdownCellOverlayEvents.setOverlayEvents(at, rowIndex, leftMostCell);
        });
    }
}
RowDropdownCellOverlay.ROW_DROPDOWN_CELL_OVERLAY_CLASS = 'row-dropdown-cell-overlay';
//# sourceMappingURL=rowDropdownCellOverlay.js.map