import { DropdownItemNavigation } from '../dropdownItemNavigation';
import { KEYBOARD_KEY } from '../../../consts/keyboardKeys';
import { DropdownEvents } from '../dropdownEvents';
import { RowDropdown } from './rowDropdown';
export class RowDropdownEvents {
    // the reason why we track window key events is because the table is not actually focused when it is displayed,
    // (unlike column dropdown which has an input), hence initially clicking tab does not focus the dropdown and
    // instead we need to focus it programmatically here. Once focused, the actual dropdown events can take over.
    // prettier-ignore
    static windowOnKeyDown(at, event) {
        const { _activeOverlayElements: { rowDropdown, fullTableOverlay }, shadowRoot } = at;
        if (at._focusedElements.rowDropdown || !rowDropdown || !fullTableOverlay)
            return;
        if (event.key === KEYBOARD_KEY.ENTER || event.key === KEYBOARD_KEY.ESCAPE) {
            RowDropdown.hide(at);
        }
        else if (!(shadowRoot === null || shadowRoot === void 0 ? void 0 : shadowRoot.activeElement)) {
            if (event.key === KEYBOARD_KEY.TAB || event.key === KEYBOARD_KEY.ARROW_DOWN) {
                event.preventDefault();
                at._focusedElements.rowDropdown = rowDropdown;
                DropdownItemNavigation.focusSiblingItem(rowDropdown.children[0], rowDropdown, true, true);
            }
            else if (event.key === KEYBOARD_KEY.ARROW_UP) {
                at._focusedElements.rowDropdown = rowDropdown;
                DropdownItemNavigation.focusSiblingItem(rowDropdown.children[rowDropdown.children.length - 1], rowDropdown, false, true);
            }
        }
    }
    static dropdownOnKeyDown(dropdownElement, event) {
        if (event.key === KEYBOARD_KEY.ENTER) {
            const itemElement = event.target;
            itemElement.dispatchEvent(new Event('mouseenter'));
            itemElement.dispatchEvent(new Event('click'));
        }
        else if (event.key === KEYBOARD_KEY.ESCAPE) {
            RowDropdown.hide(this);
        }
        DropdownEvents.itemKeyNavigation(this.shadowRoot, dropdownElement, event);
    }
    static set(at, dropdownElement) {
        dropdownElement.onkeydown = RowDropdownEvents.dropdownOnKeyDown.bind(at, dropdownElement);
    }
}
//# sourceMappingURL=rowDropdownEvents.js.map