import { OuterDropdownButtonUtils } from '../../../../../utils/outerTableComponents/dropdown/outerDropdownButtonUtils';
import { StatefulCSSEvents } from '../../../../../utils/elements/statefulCSSEvents';
import { FileExportDropdown } from '../dropdown/fileExportDropdown';
export class FileExportButtonElement {
    static createButtonArrow(button, exportProps) {
        const arrow = OuterDropdownButtonUtils.createArrow([FileExportButtonElement.ARROW_CONTAINER_CLASS], [FileExportButtonElement.ARROW_ICON_CLASS]);
        const styles = typeof exportProps === 'object' && exportProps.formats && exportProps.buttonArrowStyles;
        if (styles) {
            OuterDropdownButtonUtils.processAndApplyDefaultStyle(arrow, styles);
            setTimeout(() => StatefulCSSEvents.setEvents(button, styles, undefined, arrow));
        }
        return arrow;
    }
    // if there is more than 1 format - automatically create a dropdown
    static getDropdownFormats(exportProps) {
        if (typeof exportProps === 'object' && exportProps.formats) {
            const { formats } = exportProps;
            const validFormats = formats.filter((format) => FileExportButtonElement.VALID_FORMATS[format.toLocaleLowerCase()]);
            if (validFormats.length > 1) {
                return validFormats;
            }
        }
        return undefined;
    }
    // prettier-ignore
    static applyDropdown(at, button, container, formats, exportProps) {
        const dropdown = FileExportDropdown.create(at, button, formats);
        container.appendChild(dropdown.element);
        button.appendChild(FileExportButtonElement.createButtonArrow(button, exportProps));
    }
}
FileExportButtonElement.ARROW_CONTAINER_CLASS = 'file-button-arrow-container';
FileExportButtonElement.ARROW_ICON_CLASS = 'file-button-arrow-container-icon';
// prettier-ignore
FileExportButtonElement.VALID_FORMATS = ['csv', 'xls', 'xlsx', 'ods', 'txt']
    .reduce((acc, val) => {
    acc[val] = true;
    return acc;
}, {});
//# sourceMappingURL=fileExportButtonElement.js.map