import { FileImportButtonEvents } from '../buttons/importButton/fileImportButtonEvents';
import { DEFAULT_FILE_FORMATS } from '../../../consts/fileFormats';
export class DragAndDropEvents {
    static async uploadFile(at, formats, event) {
        var _a, _b, _c;
        const file = (_b = (_a = event.dataTransfer) === null || _a === void 0 ? void 0 : _a.files) === null || _b === void 0 ? void 0 : _b[0];
        const options = typeof ((_c = at.files) === null || _c === void 0 ? void 0 : _c.dragAndDrop) === 'object' ? at.files.dragAndDrop.overwriteOptions : undefined;
        FileImportButtonEvents.importFile(at, file, formats, options);
    }
    static toggleOverlayElement(overlayElement, isDisplayed) {
        overlayElement.style.display = isDisplayed ? 'block' : 'none';
    }
    static getAcceptedFileFormats(files) {
        var _a;
        if (typeof (files === null || files === void 0 ? void 0 : files.dragAndDrop) === 'object' && files.dragAndDrop.formats) {
            return files.dragAndDrop.formats;
        }
        const importButtonFormats = (_a = files === null || files === void 0 ? void 0 : files.buttons) === null || _a === void 0 ? void 0 : _a.filter((button) => button.import).map((button) => {
            return typeof button.import === 'object' && button.import.formats ? button.import.formats : DEFAULT_FILE_FORMATS;
        }).flat(1);
        if (importButtonFormats && importButtonFormats.length > 0) {
            return Array.from(new Set(importButtonFormats)); // makes all array entries unique
        }
        return DEFAULT_FILE_FORMATS;
    }
    static setEvents(at, fullTableContainer, overlayElement) {
        const formats = DragAndDropEvents.getAcceptedFileFormats(at.files);
        fullTableContainer.ondragenter = (event) => {
            event.preventDefault();
            DragAndDropEvents.toggleOverlayElement(overlayElement, true);
        };
        overlayElement.ondragleave = (event) => {
            event.preventDefault();
            DragAndDropEvents.toggleOverlayElement(overlayElement, false);
        };
        overlayElement.ondragover = (event) => {
            event.preventDefault();
        };
        overlayElement.ondrop = (event) => {
            event.preventDefault();
            DragAndDropEvents.uploadFile(at, formats, event);
            DragAndDropEvents.toggleOverlayElement(overlayElement, false);
        };
    }
}
//# sourceMappingURL=dragAndDropEvents.js.map