import { OuterContainerElements } from '../../../utils/outerTableComponents/outerContainerElements';
import { PaginationElements } from '../paginationElements';
export class NumberOfVisibleRowsElement {
    static updateForRelativeRowNumber(pagination, dataRowsLength) {
        const { activePageNumber, rowsPerPage, numberOfVisibleRowsElement } = pagination;
        const maxRowIndex = activePageNumber * rowsPerPage;
        const minVisibleRowIndex = dataRowsLength < 1 ? 0 : Math.max(maxRowIndex - rowsPerPage + 1, 1);
        const maxVisibleRowIndex = Math.min(dataRowsLength, maxRowIndex);
        numberOfVisibleRowsElement.innerText = `${minVisibleRowIndex}-${maxVisibleRowIndex} of ${dataRowsLength}`;
    }
    static updateForAllRows(numberOfVisibleRowsElement, dataRowsLength) {
        numberOfVisibleRowsElement.innerText = `${Math.min(dataRowsLength, 1)}-${dataRowsLength} of ${dataRowsLength}`;
    }
    static update(at) {
        const { _pagination, content, dataStartsAtHeader } = at;
        const { numberOfVisibleRowsElement, isAllRowsOptionSelected } = _pagination;
        if (!numberOfVisibleRowsElement)
            return;
        // using max as when there are no contents on startup - dataRowsLength is -1
        const dataRowsLength = Math.max(dataStartsAtHeader ? content.length : content.length - 1, 0);
        if (isAllRowsOptionSelected) {
            NumberOfVisibleRowsElement.updateForAllRows(numberOfVisibleRowsElement, dataRowsLength);
        }
        else {
            NumberOfVisibleRowsElement.updateForRelativeRowNumber(at._pagination, dataRowsLength);
        }
    }
    static create(at, containers) {
        const numberOfVisibleRowsElement = document.createElement('div');
        numberOfVisibleRowsElement.id = NumberOfVisibleRowsElement.ID;
        numberOfVisibleRowsElement.classList.add(PaginationElements.PAGINATION_TEXT_COMPONENT_CLASS);
        const { styles, positions } = at._pagination;
        numberOfVisibleRowsElement.style.order = String(positions.numberOfVisibleRows.order);
        Object.assign(numberOfVisibleRowsElement.style, styles.numberOfVisibleRows);
        OuterContainerElements.addToContainer(positions.numberOfVisibleRows.position, containers, numberOfVisibleRowsElement);
        setTimeout(() => NumberOfVisibleRowsElement.update(at));
        return numberOfVisibleRowsElement;
    }
}
NumberOfVisibleRowsElement.ID = 'pagination-number-of-visible-rows';
//# sourceMappingURL=numberOfVisibleRowsElement.js.map