import { PaginationVisibleButtonsUtils } from '../../../utils/outerTableComponents/pagination/paginationVisibleButtonsUtils';
import { OuterContainerElements } from '../../../utils/outerTableComponents/outerContainerElements';
import { PaginationUtils } from '../../../utils/outerTableComponents/pagination/paginationUtils';
import { PreviousPageButtonElement } from './buttons/prevNext/previousPageButtonElement';
import { FirstPageButtonElement } from './buttons/firstLast/firstPageButtonElement';
import { PageNumberButtonElement } from './buttons/number/pageNumberButtonElement';
import { LastPageButtonElement } from './buttons/firstLast/lastPageButtonElement';
import { NextPageButtonElement } from './buttons/prevNext/nextPageButtonElement';
import { PageButtonContainerEvents } from './pageButtonContainerEvents';
import { PageButtonElement } from './pageButtonElement';
export class PageButtonContainerElement {
    static shouldButtonsBeActive(at) {
        const minNumberOfContentToBeActive = at.dataStartsAtHeader ? 1 : 2;
        return at.content.length >= minNumberOfContentToBeActive;
    }
    static setStyle(at, pageNumber) {
        if (PageButtonContainerElement.shouldButtonsBeActive(at)) {
            PageButtonElement.setActive(at, pageNumber !== null && pageNumber !== void 0 ? pageNumber : 1);
        }
        else {
            PageButtonElement.setDisabled(at._pagination);
        }
    }
    static addNumberButtons(at) {
        // the reason why 1 button is required when it should be 0 is because we hide it and show it when a row is added
        const requiredNumberOfButtons = PaginationUtils.getLastPossiblePageNumber(at);
        const { maxNumberOfVisiblePageButtons, buttonContainer } = at._pagination;
        for (let i = 0; i < Math.min(requiredNumberOfButtons, maxNumberOfVisiblePageButtons); i += 1) {
            const buttonElement = PageNumberButtonElement.create(at, i + 1);
            buttonContainer.appendChild(buttonElement);
        }
    }
    static addButton(pagination, button) {
        pagination.buttonContainer.appendChild(button);
        pagination.numberOfActionButtons += 1;
    }
    static addButtons(at) {
        const { displayPrevNext, displayFirstLast } = at._pagination;
        if (displayFirstLast) {
            PageButtonContainerElement.addButton(at._pagination, FirstPageButtonElement.create(at));
        }
        if (displayPrevNext) {
            PageButtonContainerElement.addButton(at._pagination, PreviousPageButtonElement.create(at));
        }
        PageButtonContainerElement.addNumberButtons(at);
        if (displayPrevNext) {
            PageButtonContainerElement.addButton(at._pagination, NextPageButtonElement.create(at));
        }
        if (displayFirstLast) {
            PageButtonContainerElement.addButton(at._pagination, LastPageButtonElement.create(at));
        }
    }
    static resetState(pagination) {
        pagination.activePageNumber = 1;
        pagination.numberOfActionButtons = 0;
        pagination.visibleEdgeButtons = [];
    }
    static repopulateButtons(at) {
        PageButtonContainerElement.resetState(at._pagination);
        at._pagination.buttonContainer.replaceChildren();
        PageButtonContainerElement.addButtons(at);
        PageButtonContainerElement.setStyle(at);
    }
    static addInitialElements(at, containers) {
        PageButtonContainerElement.repopulateButtons(at);
        PaginationVisibleButtonsUtils.setStateAndStyles(at);
        const { positions, buttonContainer } = at._pagination;
        OuterContainerElements.addToContainer(positions.pageButtons.position, containers, buttonContainer);
    }
    static create(at) {
        const buttonContainerElement = document.createElement('div');
        buttonContainerElement.id = PageButtonContainerElement.PAGINATION_BUTTON_CONTAINER_ID;
        const { styles, positions } = at._pagination;
        buttonContainerElement.style.order = String(positions.pageButtons.order);
        Object.assign(buttonContainerElement.style, styles.pageButtons.container);
        PageButtonContainerEvents.setEvents(buttonContainerElement, at._pagination);
        return buttonContainerElement;
    }
}
PageButtonContainerElement.PAGINATION_BUTTON_CONTAINER_ID = 'pagination-button-container';
//# sourceMappingURL=pageButtonContainerElement.js.map