import { OuterDropdownButtonUtils } from '../../../../utils/outerTableComponents/dropdown/outerDropdownButtonUtils';
import { GenericElementUtils } from '../../../../utils/elements/genericElementUtils';
import { StatefulCSSEvents } from '../../../../utils/elements/statefulCSSEvents';
import { RowsPerPageSelectButtonEvents } from './rowsPerPageSelectButtonEvents';
export class RowsPerPageSelectButtonElement {
    // prettier-ignore
    static applyStylesOnElements(button, cssState, rowsPerPageSelect) {
        if (!rowsPerPageSelect)
            return;
        const { button: buttonStyle, buttonText: textStyle, buttonArrow: arrowStyle } = rowsPerPageSelect;
        if (buttonStyle) {
            StatefulCSSEvents.apply(buttonStyle, buttonStyle[cssState], button);
        }
        if (textStyle) {
            const buttonText = button.children[0];
            StatefulCSSEvents.apply(textStyle, textStyle[cssState], buttonText);
        }
        if (arrowStyle) {
            const buttonArrow = button.children[1];
            StatefulCSSEvents.apply(arrowStyle, arrowStyle[cssState], buttonArrow);
        }
    }
    static createButtonArrow(pagination) {
        var _a;
        const arrow = OuterDropdownButtonUtils.createArrow();
        OuterDropdownButtonUtils.processAndApplyDefaultStyle(arrow, (_a = pagination.styles.rowsPerPageSelect) === null || _a === void 0 ? void 0 : _a.buttonArrow);
        return arrow;
    }
    static updateButtonText(optionsButton, rowsPerPage) {
        const text = optionsButton.children[0];
        text.innerText = rowsPerPage;
    }
    static createButtonText(pagination) {
        var _a;
        const { isAllRowsOptionSelected, rowsPerPageOptionsItemText, rowsPerPage, styles } = pagination;
        const text = document.createElement('div');
        text.id = RowsPerPageSelectButtonElement.TEXT_ID;
        text.classList.add(GenericElementUtils.NOT_SELECTABLE_CLASS);
        OuterDropdownButtonUtils.processAndApplyDefaultStyle(text, (_a = styles.rowsPerPageSelect) === null || _a === void 0 ? void 0 : _a.buttonText);
        text.innerText = isAllRowsOptionSelected ? rowsPerPageOptionsItemText[0] : String(rowsPerPage);
        return text;
    }
    static createOptionsButton(pagination) {
        var _a;
        const optionsButton = document.createElement('div');
        optionsButton.id = RowsPerPageSelectButtonElement.BUTTON_ID;
        OuterDropdownButtonUtils.processAndApplyDefaultStyle(optionsButton, (_a = pagination.styles.rowsPerPageSelect) === null || _a === void 0 ? void 0 : _a.button);
        return optionsButton;
    }
    static create(at) {
        const optionsButton = RowsPerPageSelectButtonElement.createOptionsButton(at._pagination);
        optionsButton.appendChild(RowsPerPageSelectButtonElement.createButtonText(at._pagination));
        optionsButton.appendChild(RowsPerPageSelectButtonElement.createButtonArrow(at._pagination));
        setTimeout(() => RowsPerPageSelectButtonEvents.setEvents(at, optionsButton));
        return optionsButton;
    }
}
RowsPerPageSelectButtonElement.BUTTON_ID = 'rows-per-page-select-button';
RowsPerPageSelectButtonElement.TEXT_ID = 'rows-per-page-select-button-text';
//# sourceMappingURL=rowsPerPageSelectButtonElement.js.map