import { InsertNewColumn } from '../../../../utils/insertRemoveStructure/insert/insertNewColumn';
export class AddNewColumnEvents {
    static setHeaderCellStyle(headerCell, headerColors, isHighlight) {
        const { default: defaultColors, hover: hoverColors } = headerColors;
        // set here and not on addColumnCol because toggling 'color' on that element does not change cell 'color' style
        // additionally because frame elements header cells can inherit the user set header style, we must set it
        // manually anyway
        headerCell.style.color = isHighlight ? hoverColors.color : defaultColors.color;
        headerCell.style.backgroundColor = isHighlight ? hoverColors.backgroundColor : defaultColors.backgroundColor;
    }
    static setDataCellStyle(elements, backgroundColor) {
        // executed asynchronously
        setTimeout(() => {
            elements.forEach((element) => {
                element.style.backgroundColor = backgroundColor;
            });
        });
    }
    // prettier-ignore
    static setDataCellsStyle(isHighlight, addColumnCellsElementsRef, data) {
        const backgroundColor = isHighlight ? data.hover.backgroundColor : data.default.backgroundColor;
        const dataArray = addColumnCellsElementsRef.slice(1);
        const chunkSize = Math.ceil(dataArray.length / AddNewColumnEvents.NUMBER_OF_HIGHLIGHT_CHUNKS);
        // The reason why we are not using web workers is because they only accept serializable arguments and not dom elements
        for (let i = 0; i < dataArray.length; i += chunkSize) {
            const chunk = dataArray.slice(i, i + chunkSize);
            AddNewColumnEvents.setDataCellStyle(chunk, backgroundColor);
        }
    }
    // prettier-ignore
    static toggleColor(isHighlight, addColumnCellsElementsRef, cellColors) {
        const { data, header } = cellColors;
        const headerCell = addColumnCellsElementsRef[0];
        if (headerCell)
            AddNewColumnEvents.setHeaderCellStyle(headerCell, header, isHighlight);
        if (addColumnCellsElementsRef.length > 1) {
            AddNewColumnEvents.setDataCellsStyle(isHighlight, addColumnCellsElementsRef, data);
        }
    }
    // prettier-ignore
    static setEvents(at, cellElement) {
        const { _addColumnCellsElementsRef: ref, _frameComponents: { cellColors } } = at;
        cellElement.onmouseenter = AddNewColumnEvents.toggleColor.bind(this, true, ref, cellColors);
        cellElement.onmouseleave = AddNewColumnEvents.toggleColor.bind(this, false, ref, cellColors);
        cellElement.onclick = InsertNewColumn.insertEvent.bind(at);
    }
}
AddNewColumnEvents.NUMBER_OF_HIGHLIGHT_CHUNKS = 3;
//# sourceMappingURL=addNewColumnEvents.js.map