import { TableDimensionsUtils } from '../../../../utils/tableDimensions/tableDimensionsUtils';
import { ElementStyle } from '../../../../utils/elements/elementStyle';
import { AddNewRowElement } from '../row/addNewRowElement';
import { RootCellEvents } from './rootCellEvents';
// REF-18
export class RootCellElement {
    // prettier-ignore
    static convertFromRootCell(at) {
        const { _addRowCellElementRef, rootCell, _eventFunctions: { rootCell: rootCellEvents } } = at;
        if (!_addRowCellElementRef)
            return;
        _addRowCellElementRef.classList.remove(RootCellElement.ROOT_CELL_CLASS);
        if (rootCell === null || rootCell === void 0 ? void 0 : rootCell.styles)
            ElementStyle.unsetAllCSSStates(_addRowCellElementRef, rootCell.styles);
        RootCellEvents.removeEvents(_addRowCellElementRef, rootCellEvents);
    }
    static convertToRootCell(addNewRowCell, text) {
        addNewRowCell.classList.add(RootCellElement.ROOT_CELL_CLASS);
        addNewRowCell.innerText = text || '+';
        addNewRowCell.style.width = `${TableDimensionsUtils.MINIMAL_TABLE_WIDTH}px`;
    }
    // addNewRowCell is preserved as it is reused as the root cell
    static removeRows(tableBodyElement) {
        Array.from(tableBodyElement.children)
            .slice(0, tableBodyElement.children.length - 1)
            .forEach((rowElement) => rowElement.remove());
    }
    // prettier-ignore
    static display(at) {
        const { _tableBodyElementRef, _addColumnCellsElementsRef, _addRowCellElementRef, rootCell, _frameComponents: { displayAddNewColumn, displayAddNewRow } } = at;
        if (!_addRowCellElementRef)
            return;
        const tableBodyElement = _tableBodyElementRef;
        if (displayAddNewColumn)
            _addColumnCellsElementsRef.splice(0, _addColumnCellsElementsRef.length);
        RootCellElement.removeRows(tableBodyElement);
        if (displayAddNewRow)
            RootCellElement.convertToRootCell(_addRowCellElementRef, rootCell === null || rootCell === void 0 ? void 0 : rootCell.text);
        if (!at._eventFunctions.rootCell.applied)
            RootCellEvents.applyEvents(at, _addRowCellElementRef);
        AddNewRowElement.setDisplay(_addRowCellElementRef, true);
    }
}
RootCellElement.ROOT_CELL_CLASS = 'root-cell';
//# sourceMappingURL=rootCellElement.js.map