import { MaximumRows } from '../../../../utils/insertRemoveStructure/insert/maximum/maximumRows';
import { RootCellElement } from '../rootCell/rootCellElement';
import { CellElement } from '../../../cell/cellElement';
import { AddNewRowEvents } from './addNewRowEvents';
import { RowElement } from './rowElement';
export class AddNewRowElement {
    static isDisplayed(addNewRowCell) {
        return addNewRowCell.style.display === AddNewRowElement.VISIBLE;
    }
    static setDisplay(addNewRowCell, isDisplay) {
        if (AddNewRowElement.isDisplayed(addNewRowCell) !== isDisplay) {
            addNewRowCell.style.display = isDisplay ? AddNewRowElement.VISIBLE : AddNewRowElement.HIDDEN;
        }
    }
    static setDefaultStyle(addNewRowCell) {
        addNewRowCell.innerText = '+ New';
        addNewRowCell.style.width = '';
    }
    // prettier-ignore
    static createCell(at) {
        const { _defaultColumnsSettings: { cellStyle }, _frameComponents: { displayAddNewRow, styles }, rootCell } = at;
        const addNewRowCell = CellElement.createContentCell(false, cellStyle, styles === null || styles === void 0 ? void 0 : styles.default);
        addNewRowCell.id = AddNewRowElement.ID;
        if (!displayAddNewRow) {
            // if this is not displayed when there is content, always use the root cell style - REF-18
            RootCellElement.convertToRootCell(addNewRowCell, rootCell === null || rootCell === void 0 ? void 0 : rootCell.text);
            addNewRowCell.addEventListener('click', AddNewRowElement.setDisplay.bind(this, addNewRowCell, false));
        }
        else {
            AddNewRowElement.setDefaultStyle(addNewRowCell);
        }
        AddNewRowElement.setDisplay(addNewRowCell, displayAddNewRow);
        // set to high number to always merge cells in this row
        addNewRowCell.colSpan = AddNewRowElement.DEFAULT_COL_SPAN;
        AddNewRowEvents.setCellEvents(at, addNewRowCell);
        return addNewRowCell;
    }
    static create(at) {
        const addNewRowRow = RowElement.create();
        const addNewRowCell = AddNewRowElement.createCell(at);
        addNewRowRow.appendChild(addNewRowCell);
        return addNewRowCell;
    }
    // prettier-ignore
    static toggle(at) {
        const { _tableBodyElementRef, _addRowCellElementRef, _frameComponents: { displayAddNewRow } } = at;
        if (!(_addRowCellElementRef === null || _addRowCellElementRef === void 0 ? void 0 : _addRowCellElementRef.parentElement) || !_tableBodyElementRef)
            return;
        if (displayAddNewRow)
            AddNewRowElement.setDisplay(_addRowCellElementRef, MaximumRows.canAddMore(at));
        RowElement.toggleLastRowClass(at);
    }
    static isAddNewRowRow(rowElement) {
        var _a;
        return ((_a = rowElement === null || rowElement === void 0 ? void 0 : rowElement.children[0]) === null || _a === void 0 ? void 0 : _a.id) === AddNewRowElement.ID;
    }
}
AddNewRowElement.DEFAULT_COL_SPAN = 1000000000;
AddNewRowElement.HIDDEN = 'none';
AddNewRowElement.VISIBLE = '';
AddNewRowElement.ID = 'add-new-row-cell';
//# sourceMappingURL=addNewRowElement.js.map