import { AddNewRowElement } from './addNewRowElement';
export class RowElement {
    static create() {
        const rowElement = document.createElement('tr');
        rowElement.classList.add('row');
        return rowElement;
    }
    static moveClassToLastVisibleRow(lastVisibleRow, lastMarkedRow) {
        if (lastMarkedRow)
            lastMarkedRow.id = '';
        lastVisibleRow.id = RowElement.LAST_VISIBLE_ROW_ID;
    }
    static toggleNonAddRow(at, addNewRowElement, lastMarkedRow) {
        if (at.pagination && at._pagination) {
            const lastVisibleElement = at._pagination.visibleRows[at._pagination.visibleRows.length - 1];
            if (lastVisibleElement)
                return RowElement.moveClassToLastVisibleRow(lastVisibleElement, lastMarkedRow);
        }
        const { previousElementSibling } = addNewRowElement;
        if (previousElementSibling)
            RowElement.moveClassToLastVisibleRow(previousElementSibling, lastMarkedRow);
    }
    // REF-25
    // Add new row element is always appended to the table, but not always visible (e.g. if the user has
    // chosen not to display it or max rows has been reached), hence we must always monitor its current
    // visibility and given that it can be safely assumed that it is the last row element, we can use
    // its isDisplayed method to help assign the last-visible row id to the correct row
    static toggleLastRowClass(at) {
        const shadowRoot = at.shadowRoot;
        const addNewRowElement = at._addRowCellElementRef.parentElement;
        const lastMarkedRow = shadowRoot.getElementById(RowElement.LAST_VISIBLE_ROW_ID);
        if (AddNewRowElement.isDisplayed(addNewRowElement.children[0])) {
            if (addNewRowElement.id !== RowElement.LAST_VISIBLE_ROW_ID) {
                RowElement.moveClassToLastVisibleRow(addNewRowElement, lastMarkedRow);
            }
        }
        else {
            RowElement.toggleNonAddRow(at, addNewRowElement, lastMarkedRow);
        }
    }
}
// REF-25
// the reason why ID is used instead of a class is because only one element should ever have this at any given time
RowElement.LAST_VISIBLE_ROW_ID = 'last-visible-row';
//# sourceMappingURL=rowElement.js.map