import { DateCellInputElement } from '../cell/cellsWithTextDiv/dateCell/dateCellInputElement';
import { UserKeyEventsStateUtils } from '../../utils/userEventsState/userEventsStateUtils';
import { OptionColorButton } from '../dropdown/cellDropdown/buttons/optionColorButton';
import { ColumnSizerExtrinsicEvents } from '../columnSizer/columnSizerExtrinsicEvents';
import { CellWithTextEvents } from '../cell/cellsWithTextDiv/cellWithTextEvents';
import { MOUSE_EVENT } from '../../consts/mouseEvents';
import { CellElement } from '../cell/cellElement';
import { Dropdown } from '../dropdown/dropdown';
export class TableEvents {
    // not using hoveredElements state as the targetElement will be the element clicked, hence need to use
    // activeOverlayElements.datePickerCell to get the cell of the date picker input
    // prettier-ignore
    static closeDatePicker(activeOverlayElements, targetElement) {
        if (activeOverlayElements.datePickerCell) {
            if (activeOverlayElements.datePickerCell !== CellElement.getCellElement(targetElement)) {
                DateCellInputElement.toggle(activeOverlayElements.datePickerCell, false);
            }
            delete activeOverlayElements.datePickerCell;
        }
    }
    // REF-44
    // text blur will not activate when the dropdown has been clicked and will not close if its scrollbar, padding
    // or delete category buttons are clicked. If the user clicks elsewhere on the table, the dropdown is closed
    // programmatically as follows
    // prettier-ignore
    static closeCellDropdown(at, targetElement) {
        const { _focusedElements } = at;
        if (_focusedElements.cellDropdown && !Dropdown.isPartOfDropdownElement(targetElement)
            && !targetElement.classList.contains(OptionColorButton.COLOR_BUTTON_CLASS)
            && _focusedElements.cell.element !== CellElement.getCellElement(targetElement)) {
            CellWithTextEvents.programmaticBlur(at);
        }
    }
    static onMouseDown(event) {
        const targetElement = event.target;
        UserKeyEventsStateUtils.temporarilyIndicateEvent(this._userKeyEventsState, MOUSE_EVENT.DOWN);
        TableEvents.closeCellDropdown(this, targetElement);
        TableEvents.closeDatePicker(this._activeOverlayElements, event.target);
    }
    static onMouseUp(event) {
        if (this._activeOverlayElements.selectedColumnSizer) {
            ColumnSizerExtrinsicEvents.tableMouseUp(this, event.target);
        }
    }
}
//# sourceMappingURL=tableEvents.js.map