import { FilterInternalUtils } from '../../../utils/outerTableComponents/filter/rows/filterInternalUtils';
import { OuterContainerElements } from '../../../utils/outerTableComponents/outerContainerElements';
import { FilterDropdownElement } from './activeColumn/dropdown/filterDropdownElement';
import { ToggleableElement } from '../../../utils/elements/toggleableElement';
import { StatefulCSSEvents } from '../../../utils/elements/statefulCSSEvents';
import { FilterInputCaseElement } from './case/filterInputCaseElement';
import { ElementStyle } from '../../../utils/elements/elementStyle';
import { FilterInputElement } from './input/filterInputElement';
export class FilterElements {
    static createContainerElement(order) {
        const containerElement = document.createElement('div');
        containerElement.classList.add('filter-rows-container');
        containerElement.style.order = String(order || 0);
        return containerElement;
    }
    // the order at which the elements are added is very important - please check the css selectors
    // prettier-ignore
    static createComponent(at, outerContainers, userConfig) {
        var _a;
        const position = userConfig.position || FilterElements.DEFAULT_INPUT_POSITION;
        const containerElement = FilterElements.createContainerElement(userConfig.order);
        const internalConfig = FilterInternalUtils.addConfig(at, userConfig);
        if (userConfig.dropdown !== false) {
            const dropdownElement = FilterDropdownElement.create(at, containerElement, position, internalConfig, (_a = userConfig.styles) === null || _a === void 0 ? void 0 : _a.dropdownIcon);
            setTimeout(() => containerElement.appendChild(dropdownElement)); // appended at the end
        }
        if (userConfig.caseButton !== false) {
            FilterInputCaseElement.create(at, containerElement, internalConfig, userConfig.styles);
        }
        const inputElement = FilterInputElement.create(internalConfig, userConfig, at.content);
        containerElement.appendChild(inputElement);
        OuterContainerElements.addToContainer(position, outerContainers, containerElement);
    }
    static create(at, outerContainers) {
        if (typeof at.filter === 'boolean') {
            FilterElements.createComponent(at, outerContainers, {});
        }
        else if (Array.isArray(at.filter)) {
            at.filter.forEach((userConfig) => {
                FilterElements.createComponent(at, outerContainers, userConfig);
            });
        }
        else if (at.filter) {
            FilterElements.createComponent(at, outerContainers, at.filter);
        }
        setTimeout(() => FilterInternalUtils.resetAllInputs(at));
    }
    static applyStatefulStyles(element, hoverStyle, styles = {}) {
        const statefulStyles = ElementStyle.generateStatefulCSS(styles, hoverStyle, { color: '#484848' });
        Object.assign(element.style, statefulStyles.default);
        setTimeout(() => StatefulCSSEvents.setEvents(element, statefulStyles, ToggleableElement.ACTIVE_BUTTON_CLASS));
    }
}
FilterElements.DEFAULT_INPUT_POSITION = 'top-right';
//# sourceMappingURL=filterElements.js.map