import { FilterInternalUtils } from '../../../../utils/outerTableComponents/filter/rows/filterInternalUtils';
export class FilterInputElement {
    static setPlaceholder(inputElement, headerName, template) {
        if (headerName && headerName !== '') {
            const activeTemplate = template || FilterInputElement.DEFAULT_PLACEHOLDER_TEMPLATE;
            inputElement.placeholder = activeTemplate.replace(FilterInputElement.TEMPLATE_VARIABLE, headerName);
        }
        else {
            inputElement.placeholder = FilterInputElement.DEFAULT_PLACEHOLDER;
        }
    }
    static createElement(headerName, template, styles) {
        const inputElement = document.createElement('input');
        inputElement.classList.add(FilterInputElement.INPUT_CLASS);
        const placeholderColor = (styles === null || styles === void 0 ? void 0 : styles.placeholderColor) || '#656565';
        inputElement.style.setProperty('--active-table-filter-placeholder-color', placeholderColor);
        Object.assign(inputElement.style, styles === null || styles === void 0 ? void 0 : styles.input);
        FilterInputElement.setPlaceholder(inputElement, headerName, template);
        return inputElement;
    }
    static create(config, userConfig, content) {
        // done here as resetInput is in a timeout which will cause the input text display to be delayed on startup
        const defaultHeader = FilterInternalUtils.generateDefaultHeaderName(content, config.defaultColumnHeaderName);
        const input = FilterInputElement.createElement(defaultHeader, config.placeholderTemplate, userConfig.styles);
        config.inputElement = input;
        return input;
    }
}
FilterInputElement.INPUT_CLASS = 'filter-rows-input';
FilterInputElement.TEMPLATE_VARIABLE = '{headerName}';
FilterInputElement.DEFAULT_PLACEHOLDER = 'Filter';
FilterInputElement.DEFAULT_PLACEHOLDER_TEMPLATE = `Filter ${FilterInputElement.TEMPLATE_VARIABLE}...`;
//# sourceMappingURL=filterInputElement.js.map