import { SelectCellTextBaseEvents } from '../cell/cellsWithTextDiv/selectCell/baseEvents/selectCellTextBaseEvents';
import { OuterDropdownEvents } from '../../utils/outerTableComponents/dropdown/outerDropdownEvents';
import { OptionColorButtonEvents } from '../dropdown/cellDropdown/buttons/optionColorButtonEvents';
import { DateCellInputElement } from '../cell/cellsWithTextDiv/dateCell/dateCellInputElement';
import { DateCellInputEvents } from '../cell/cellsWithTextDiv/dateCell/dateCellInputEvents';
import { ColumnSizerExtrinsicEvents } from '../columnSizer/columnSizerExtrinsicEvents';
import { ColumnDropdownEvents } from '../dropdown/columnDropdown/columnDropdownEvents';
import { CellWithTextEvents } from '../cell/cellsWithTextDiv/cellWithTextEvents';
import { RowDropdownEvents } from '../dropdown/rowDropdown/rowDropdownEvents';
import { ColumnDropdown } from '../dropdown/columnDropdown/columnDropdown';
import { DragColumn } from '../../utils/moveStructure/drag/dragColumn';
import { HeaderText } from '../../utils/columnDetails/headerText';
import { RowDropdown } from '../dropdown/rowDropdown/rowDropdown';
import { DragRow } from '../../utils/moveStructure/drag/dragRow';
import { KEYBOARD_KEY } from '../../consts/keyboardKeys';
import { ActiveTable } from '../../activeTable';
import { Dropdown } from '../dropdown/dropdown';
export class WindowEvents {
    static onKeyDown(event) {
        var _a, _b;
        if (Dropdown.isDisplayed((_a = this._activeOverlayElements.outerContainerDropdown) === null || _a === void 0 ? void 0 : _a.element)) {
            OuterDropdownEvents.windowOnKeyDown(this, event);
        }
        if (Dropdown.isDisplayed(this._activeOverlayElements.rowDropdown)) {
            RowDropdownEvents.windowOnKeyDown(this, event);
        }
        const { rowIndex, columnIndex, element } = this._focusedElements.cell;
        if (rowIndex === undefined || columnIndex === undefined)
            return;
        if (rowIndex === 0 && !Dropdown.isDisplayed(this._activeOverlayElements.columnDropdown)) {
            if (event.key === KEYBOARD_KEY.ESCAPE) {
                return HeaderText.onAttemptChange(this, element, columnIndex);
            }
            // workaround for when opened dropdown does not have a focused item
        }
        else if (Dropdown.isDisplayed(this._activeOverlayElements.columnDropdown) && !((_b = this.shadowRoot) === null || _b === void 0 ? void 0 : _b.activeElement)) {
            return ColumnDropdownEvents.onKeyDown.bind(this)(this._activeOverlayElements.columnDropdown, event);
        }
        if (rowIndex > 0 && this._columnsDetails[columnIndex].activeType.cellDropdownProps) {
            SelectCellTextBaseEvents.keyDownText(this, rowIndex, columnIndex, event);
        }
    }
    static onKeyUp(event) {
        if (event.key === KEYBOARD_KEY.ESCAPE) {
            OptionColorButtonEvents.windowEventClosePicker(this._columnsDetails, this._focusedElements); // picker stops key down
            DateCellInputEvents.escapeKeyInput(this);
        }
        else if (event.key === KEYBOARD_KEY.ENTER) {
            OptionColorButtonEvents.windowEventClosePicker(this._columnsDetails, this._focusedElements); // picker stops key down
        }
    }
    // prettier-ignore
    static onMouseDown(event) {
        var _a;
        OptionColorButtonEvents.windowEventClosePicker(this._columnsDetails, this._focusedElements);
        if (Dropdown.isDisplayed((_a = this._activeOverlayElements.outerContainerDropdown) === null || _a === void 0 ? void 0 : _a.element)) {
            OuterDropdownEvents.windowOnMouseDown(this);
        }
        // window event.target can only identify the parent element in shadow dom, not elements
        // inside it, hence if the user clicks inside the element, the elements inside will
        // handle the click event instead (full table overlay element for column dropdown)
        // and table element for the other closable elements  
        if (event.target.tagName === ActiveTable._ELEMENT_TAG)
            return;
        const { _activeOverlayElements: { columnDropdown, rowDropdown }, _focusedElements } = this;
        // if the user clicks outside of the shadow dom and a dropdown is open, close it
        if (Dropdown.isDisplayed(rowDropdown)) {
            RowDropdown.hide(this);
        }
        if (Dropdown.isDisplayed(columnDropdown)) {
            ColumnDropdown.processTextAndHide(this);
            // cell blur will not activate when the dropdown has been clicked and will not close if its scrollbar or padding are
            // clicked, if clicked elsewhere on the window we close the dropdown programmatically as follows
        }
        else if (_focusedElements.cellDropdown) {
            CellWithTextEvents.programmaticBlur(this);
        }
        else if (this._activeOverlayElements.datePickerCell) {
            DateCellInputElement.toggle(this._activeOverlayElements.datePickerCell, false);
            delete this._activeOverlayElements.datePickerCell;
        }
    }
    static onMouseUp() {
        if (this._activeOverlayElements.selectedColumnSizer)
            ColumnSizerExtrinsicEvents.windowMouseUp(this);
        DragColumn.windowMouseUp(this);
        DragRow.windowMouseUp(this);
    }
    static onMouseMove(event) {
        if (this._activeOverlayElements.selectedColumnSizer)
            ColumnSizerExtrinsicEvents.windowMouseMove(this, event.movementX);
        if (DragColumn.CELL)
            DragColumn.windowDrag(DragColumn.CELL, event);
        if (DragRow.ROW)
            DragRow.windowDrag(event);
    }
}
//# sourceMappingURL=windowEvents.js.map