import { ColumnSettingsBorderUtils } from './columnSettingsBorderUtils';
import { ExtractElements } from '../elements/extractElements';
import { ResetColumnStyles } from './resetColumnStyles';
// REF-23
export class ColumnSettingsFrameBorderUtils {
    // prettier-ignore
    static toggleFrameBorder(frameElements, columnElements, subjectBorder, columnsSettings) {
        if (frameElements.length > 0) {
            // subject is the frame column and sibling is the data column
            const { subjectBorderStyle, siblingBorderStyle } = ColumnSettingsBorderUtils.getColumnBorderStyles(subjectBorder);
            const frameHeaderElement = frameElements[0];
            const columnHeaderElement = columnElements[0];
            // if data column does not have a border, set the frame border (if we had unset it)
            if (!ColumnSettingsBorderUtils.isBorderDisplayed(columnHeaderElement, siblingBorderStyle)) {
                if (frameHeaderElement.style[subjectBorderStyle] === ColumnSettingsBorderUtils.UNSET_PX) {
                    ResetColumnStyles.applyDefaultStyles(frameElements, columnsSettings);
                }
                // if data column does have a border - unset the frame border if it has one
            }
            else {
                ColumnSettingsBorderUtils.unsetSubjectBorder(frameElements, columnElements, subjectBorder, 0);
            }
        }
    }
    // prettier-ignore
    static updateFrameColumns(at, currentColumnDetails, leftColumnDetails, rightColumnDetails) {
        const currentColumn = currentColumnDetails || leftColumnDetails; // when last column removed - use the left one instead
        if (!currentColumn)
            return;
        const { _defaultColumnsSettings: defColumnsSettings, _addColumnCellsElementsRef, _frameComponents: { displayAddNewColumn, displayIndexColumn } } = at;
        if (!rightColumnDetails && displayAddNewColumn) {
            ColumnSettingsFrameBorderUtils.toggleFrameBorder(_addColumnCellsElementsRef, currentColumn.elements, 'left', defColumnsSettings);
        }
        if (!leftColumnDetails && displayIndexColumn) {
            const rowElements = ExtractElements.textRowsArrFromTBody(at._tableBodyElementRef, at.content, 0);
            const indexCells = rowElements.map((row) => row.children[0]);
            ColumnSettingsFrameBorderUtils.toggleFrameBorder(indexCells, currentColumn.elements, 'right', defColumnsSettings);
        }
    }
}
//# sourceMappingURL=columnSettingsFrameBorderUtils.js.map