import { ProcessedDataTextStyle } from '../columnType/processedDataTextStyle';
import { ColumnSettingsBorderUtils } from './columnSettingsBorderUtils';
import { ColumnDetails } from '../columnDetails/columnDetails';
import { CellElement } from '../../elements/cell/cellElement';
import { ElementStyle } from '../elements/elementStyle';
import { RegexUtils } from '../regex/regexUtils';
export class ColumnSettingsStyleUtils {
    static applySettingsStyleOnCell(settings, cellElement, isHeader) {
        var _a;
        Object.assign(cellElement.style, settings.cellStyle || {}, isHeader ? ((_a = settings.headerStyles) === null || _a === void 0 ? void 0 : _a.default) || {} : {});
    }
    // prettier-ignore
    static setNewHeaderStyle(at, columnDetails) {
        var _a;
        const { settings, elements } = columnDetails;
        const newHeaderStyle = settings.cellStyle || ((_a = settings.headerStyles) === null || _a === void 0 ? void 0 : _a.default);
        if (newHeaderStyle)
            ColumnSettingsStyleUtils.applySettingsStyleOnCell(settings, elements[0], true);
        const newStyleSettings = newHeaderStyle ? settings : undefined;
        columnDetails.headerStateColors = ColumnDetails.createHeaderStateColors(at._defaultColumnsSettings, newStyleSettings, at._defaultCellHoverColors);
        ColumnSettingsBorderUtils.overwriteSideBorderIfSiblingsHaveSettings(columnDetails, [elements[0]]);
    }
    static unsetHeaderSettingStyle(headerElement, style) {
        Object.keys(style).forEach((styleName) => {
            ElementStyle.setStyle(headerElement, styleName, '');
        });
    }
    // prettier-ignore
    static resetHeaderStyleToDefault(columnElements, settings, columnsSettings) {
        var _a;
        if ((_a = settings.headerStyles) === null || _a === void 0 ? void 0 : _a.default) {
            ColumnSettingsStyleUtils.unsetHeaderSettingStyle(columnElements[0], settings.headerStyles.default);
        }
        if (settings.cellStyle)
            ElementStyle.unsetStyle(columnElements[0], settings.cellStyle);
        const { cellStyle, headerStyles } = columnsSettings;
        CellElement.setDefaultCellStyle(columnElements[0], cellStyle, headerStyles === null || headerStyles === void 0 ? void 0 : headerStyles.default);
    }
    // prettier-ignore
    static changeHeaderStyleFunc(columnIndex, oldSettings) {
        var _a, _b, _c;
        const columnDetails = this._columnsDetails[columnIndex];
        const { elements, settings: { isHeaderTextEditable } } = columnDetails;
        ColumnSettingsStyleUtils.resetHeaderStyleToDefault(elements, oldSettings, this._defaultColumnsSettings);
        ColumnSettingsStyleUtils.setNewHeaderStyle(this, columnDetails);
        const cellClickDropdownOpen = (_c = (_b = (_a = this._defaultColumnsSettings.columnDropdown) === null || _a === void 0 ? void 0 : _a.displaySettings) === null || _b === void 0 ? void 0 : _b.openMethod) === null || _c === void 0 ? void 0 : _c.cellClick;
        const isEditable = !cellClickDropdownOpen && isHeaderTextEditable;
        CellElement.prepContentEditable(CellElement.getTextElement(elements[0]), Boolean(isEditable), cellClickDropdownOpen);
    }
    // prettier-ignore
    static changeStyleFunc(at, columnIndex, oldSettings) {
        // resetDataCellsStyle unsets and reapplies settings style hence we only need to set the header here
        ProcessedDataTextStyle.resetDataCellsStyle(at, columnIndex, ColumnSettingsStyleUtils.changeHeaderStyleFunc.bind(at, columnIndex, oldSettings), oldSettings.cellStyle);
    }
    static doStylesHaveVisibleDimension(style, styleKeys) {
        for (let i = 0; i < styleKeys.length; i += 1) {
            const styleValue = style[styleKeys[i]];
            if (styleValue) {
                const integerStrArr = RegexUtils.extractIntegerStrs(String(styleValue));
                if (integerStrArr.length > 0 && Number(integerStrArr[0]) > 0)
                    return true;
            }
        }
        return false;
    }
    // REF-23
    // prettier-ignore
    static doesSettingHaveSideBorderStyle(settings) {
        var _a;
        const settingsStyle = settings.cellStyle || ((_a = settings.headerStyles) === null || _a === void 0 ? void 0 : _a.default);
        if (settingsStyle) {
            const doesStyleHaveSideBorder = ColumnSettingsStyleUtils.doStylesHaveVisibleDimension(settingsStyle, ['border', 'borderLeft', 'borderLeftWidth', 'borderRight', 'borderRightWidth']);
            return doesStyleHaveSideBorder;
        }
        return false;
    }
}
//# sourceMappingURL=columnSettingsStyleUtils.js.map