import { ColumnDropdownCellOverlay } from '../../elements/dropdown/columnDropdown/cellOverlay/columnDropdownCellOverlay';
import { HeaderIconCellElement } from '../../elements/cell/cellsWithTextDiv/headerIconCell/headerIconCellElement';
import { AddNewColumnElement } from '../../elements/table/addNewElements/column/addNewColumnElement';
import { InsertRemoveColumnSizer } from '../../elements/columnSizer/utils/insertRemoveColumnSizer';
import { DropdownDisplaySettingsUtil } from '../../elements/dropdown/dropdownDisplaySettingsUtil';
import { ColumnSettingsDefaultTextUtils } from './columnSettingsDefaultTextUtils';
import { StringDimensionUtils } from '../tableDimensions/stringDimensionUtils';
import { ColumnSettingsBorderUtils } from './columnSettingsBorderUtils';
import { ColumnSettingsStyleUtils } from './columnSettingsStyleUtils';
import { ColumnSettingsWidthUtils } from './columnSettingsWidthUtils';
import { ColumnTypesUtils } from '../columnType/columnTypesUtils';
import { ResetColumnStructure } from './resetColumnStructure';
import { CellElement } from '../../elements/cell/cellElement';
import { EMPTY_STRING } from '../../consts/text';
export class ColumnSettingsUtils {
    static updateSizer(at, columnIndex) {
        const { _columnsDetails, _tableElementRef } = at;
        if (!_tableElementRef)
            return;
        const { columnSizer } = _columnsDetails[columnIndex];
        // if not needed - cleanUpCustomColumnSizers will remove it (however it would not insert it otherwise)
        if (!columnSizer)
            InsertRemoveColumnSizer.insert(at, columnIndex);
        InsertRemoveColumnSizer.cleanUpCustomColumnSizers(at, columnIndex);
        if (columnSizer) {
            InsertRemoveColumnSizer.updateSizer(columnSizer, _columnsDetails, columnIndex, _tableElementRef);
        }
        const previousColumnIndex = columnIndex - 1;
        if (columnIndex > 0 && _columnsDetails[previousColumnIndex].columnSizer) {
            const { columnSizer: previousColumnSizer } = _columnsDetails[previousColumnIndex];
            InsertRemoveColumnSizer.updateSizer(previousColumnSizer, _columnsDetails, previousColumnIndex, _tableElementRef);
        }
    }
    // prettier-ignore
    static change(at, headerElement, columnIndex, oldSettings, newSettings, onColumnMove) {
        const columnDetails = at._columnsDetails[columnIndex];
        ColumnSettingsDefaultTextUtils.unsetDefaultText(at, columnDetails, columnIndex);
        columnDetails.settings = newSettings;
        columnDetails.activeType = ColumnTypesUtils.getActiveType(newSettings, columnDetails.settings.defaultColumnTypeName);
        ResetColumnStructure.reset(at, columnDetails, columnIndex);
        ColumnSettingsDefaultTextUtils.setDefaultText(at, columnDetails, columnIndex);
        if (!onColumnMove)
            ColumnSettingsWidthUtils.changeWidth(at, headerElement, oldSettings.widths, newSettings.widths);
        ColumnSettingsStyleUtils.changeStyleFunc(at, columnIndex, oldSettings);
        ColumnSettingsBorderUtils.updateSiblingColumns(at, columnIndex);
        ColumnSettingsUtils.updateSizer(at, columnIndex);
        if (at.displayHeaderIcons)
            HeaderIconCellElement.changeHeaderIcon(at._columnsDetails[columnIndex]);
        ColumnDropdownCellOverlay.updateIfDisplayed(columnDetails);
        AddNewColumnElement.toggle(at, true);
    }
    // prettier-ignore
    static parseSettingsChange(at) {
        const { _customColumnsSettings, _columnsDetails, _focusedElements: { cell: { element: cellElement, columnIndex } } } = at;
        const columnDetails = _columnsDetails[columnIndex];
        const oldSettings = columnDetails.settings;
        const newSettings = _customColumnsSettings[CellElement.getText(cellElement)];
        const areSettingsDifferent = newSettings ? oldSettings !== newSettings : false;
        return { oldSettings, newSettings, areSettingsDifferent };
    }
    // prettier-ignore
    static changeColumnSettingsIfNameDifferent(at, cellElement, colIndex, onColMove = false) {
        const { oldSettings, newSettings, areSettingsDifferent } = ColumnSettingsUtils.parseSettingsChange(at);
        if (areSettingsDifferent)
            ColumnSettingsUtils.change(at, cellElement, colIndex, oldSettings, newSettings, onColMove);
    }
    static setDropdownSettings(customDropdown, defDropdown) {
        var _a, _b, _c, _d, _e;
        if (!customDropdown || !defDropdown)
            return;
        (_a = customDropdown.isSortAvailable) !== null && _a !== void 0 ? _a : (customDropdown.isSortAvailable = defDropdown.isSortAvailable);
        (_b = customDropdown.isDeleteAvailable) !== null && _b !== void 0 ? _b : (customDropdown.isDeleteAvailable = defDropdown.isDeleteAvailable);
        (_c = customDropdown.isInsertLeftAvailable) !== null && _c !== void 0 ? _c : (customDropdown.isInsertLeftAvailable = defDropdown.isInsertLeftAvailable);
        (_d = customDropdown.isInsertRightAvailable) !== null && _d !== void 0 ? _d : (customDropdown.isInsertRightAvailable = defDropdown.isInsertRightAvailable);
        (_e = customDropdown.isMoveAvailable) !== null && _e !== void 0 ? _e : (customDropdown.isMoveAvailable = defDropdown.isMoveAvailable);
    }
    static processCellDimensions(settings) {
        const cellStyle = settings.cellStyle;
        if (!cellStyle)
            return;
        const internalSettings = settings;
        if (cellStyle.width) {
            const key = settings.isColumnResizable === false ? 'staticWidth' : 'initialWidth';
            internalSettings.widths = { [key]: cellStyle.width };
            // when customSetting does not have width set and is resizable, but default settings have a static width set
        }
        else if (internalSettings.widths && settings.isColumnResizable && internalSettings.widths.staticWidth) {
            internalSettings.widths = { initialWidth: internalSettings.widths.staticWidth };
        }
        StringDimensionUtils.removeAllDimensions(cellStyle);
    }
    static createInternalSettings(settings, defSettings) {
        const internalSettings = settings;
        if (ColumnSettingsStyleUtils.doesSettingHaveSideBorderStyle(internalSettings)) {
            internalSettings.stylePrecedence = true; // REF-23
        }
        ColumnSettingsUtils.setDropdownSettings(settings.columnDropdown, defSettings.columnDropdown);
        Object.keys(defSettings).forEach((key) => {
            var _a;
            var _b;
            (_a = (_b = internalSettings)[key]) !== null && _a !== void 0 ? _a : (_b[key] = defSettings[key]);
        });
        internalSettings.types = ColumnTypesUtils.getProcessedTypes(internalSettings);
        ColumnSettingsUtils.processCellDimensions(settings); // here to first inherit isColumnResizable if not set by user
        return internalSettings;
    }
    static createInternalMap(customSettings, defaultSettings) {
        return customSettings.reduce((settingsMap, clientSettings) => {
            settingsMap[clientSettings.headerName] = ColumnSettingsUtils.createInternalSettings(clientSettings, defaultSettings);
            return settingsMap;
        }, {});
    }
    static setDefaultTypeProperties(at) {
        const { _defaultColumnsSettings } = at;
        _defaultColumnsSettings.availableDefaultColumnTypes = at.availableDefaultColumnTypes;
        _defaultColumnsSettings.customColumnTypes = at.customColumnTypes;
        _defaultColumnsSettings.defaultColumnTypeName = at.defaultColumnTypeName;
        _defaultColumnsSettings.types = ColumnTypesUtils.getProcessedTypes(_defaultColumnsSettings);
    }
    static setDefaultDropdownProperties(at) {
        var _a, _b, _c, _d, _e, _f;
        var _g, _h, _j, _k, _l, _m;
        const { _defaultColumnsSettings } = at;
        const defaultDisplaySettings = { openMethod: { cellClick: true } };
        _defaultColumnsSettings.columnDropdown = at.columnDropdown || { displaySettings: defaultDisplaySettings };
        (_a = (_g = _defaultColumnsSettings.columnDropdown).displaySettings) !== null && _a !== void 0 ? _a : (_g.displaySettings = defaultDisplaySettings);
        DropdownDisplaySettingsUtil.process(_defaultColumnsSettings.columnDropdown.displaySettings);
        (_b = (_h = _defaultColumnsSettings.columnDropdown).isSortAvailable) !== null && _b !== void 0 ? _b : (_h.isSortAvailable = true);
        (_c = (_j = _defaultColumnsSettings.columnDropdown).isDeleteAvailable) !== null && _c !== void 0 ? _c : (_j.isDeleteAvailable = true);
        (_d = (_k = _defaultColumnsSettings.columnDropdown).isInsertLeftAvailable) !== null && _d !== void 0 ? _d : (_k.isInsertLeftAvailable = true);
        (_e = (_l = _defaultColumnsSettings.columnDropdown).isInsertRightAvailable) !== null && _e !== void 0 ? _e : (_l.isInsertRightAvailable = true);
        (_f = (_m = _defaultColumnsSettings.columnDropdown).isMoveAvailable) !== null && _f !== void 0 ? _f : (_m.isMoveAvailable = true);
    }
    static setDefaultGenericProperties(at) {
        var _a, _b, _c, _d, _e;
        const { _defaultColumnsSettings } = at;
        _defaultColumnsSettings.defaultText = (_a = at.defaultText) !== null && _a !== void 0 ? _a : EMPTY_STRING;
        _defaultColumnsSettings.isDefaultTextRemovable = (_b = at.isDefaultTextRemovable) !== null && _b !== void 0 ? _b : true;
        _defaultColumnsSettings.cellStyle = at.cellStyle;
        _defaultColumnsSettings.isCellTextEditable = (_c = at.isCellTextEditable) !== null && _c !== void 0 ? _c : true;
        _defaultColumnsSettings.headerStyles = at.headerStyles;
        _defaultColumnsSettings.isHeaderTextEditable = (_d = at.isHeaderTextEditable) !== null && _d !== void 0 ? _d : _defaultColumnsSettings.isCellTextEditable;
        _defaultColumnsSettings.headerIconStyle = at.headerIconStyle;
        _defaultColumnsSettings.isColumnResizable = (_e = at.isColumnResizable) !== null && _e !== void 0 ? _e : true;
    }
    static setDefaultColumnsSettings(at) {
        const { _defaultColumnsSettings } = at;
        ColumnSettingsUtils.setDefaultGenericProperties(at);
        ColumnSettingsUtils.processCellDimensions(_defaultColumnsSettings);
        ColumnSettingsUtils.setDefaultDropdownProperties(at);
        ColumnSettingsUtils.setDefaultTypeProperties(at);
    }
    // REF-21
    static setUpInternalSettings(at) {
        ColumnSettingsUtils.setDefaultColumnsSettings(at);
        at._customColumnsSettings = ColumnSettingsUtils.createInternalMap(at.customColumnsSettings, at._defaultColumnsSettings);
    }
}
//# sourceMappingURL=columnSettingsUtils.js.map