import { StringDimensionUtils } from '../tableDimensions/stringDimensionUtils';
import { StaticTableWidthUtils } from '../tableDimensions/staticTable/staticTableWidthUtils';
import { TableElement } from '../../elements/table/tableElement';
import { ColumnDetails } from '../columnDetails/columnDetails';
// REF-24
export class ColumnSettingsWidthUtils {
    // prettier-ignore
    static getSettingsWidthNumber(table, widths, isStatic = true) {
        return StringDimensionUtils.generateNumberDimensionFromClientString(table, widths, isStatic ? 'staticWidth' : 'initialWidth', true, ColumnDetails.MINIMAL_COLUMN_WIDTH);
    }
    static updateColumnWidth(at, cellEl, widths, isNewSetting) {
        const { _tableDimensions, _tableElementRef } = at;
        const { number: numberWidth } = ColumnSettingsWidthUtils.getSettingsWidthNumber(_tableElementRef, widths);
        cellEl.style.width = `${numberWidth}px`;
        TableElement.changeStaticWidthTotal(_tableDimensions, isNewSetting ? numberWidth : -numberWidth);
    }
    // prettier-ignore
    static changeWidth(at, cellElement, oldWidths, newWidths) {
        let hasWidthChanged = false;
        if (oldWidths === null || oldWidths === void 0 ? void 0 : oldWidths.staticWidth) {
            ColumnSettingsWidthUtils.updateColumnWidth(at, cellElement, oldWidths, false);
            hasWidthChanged = true;
        }
        if (newWidths === null || newWidths === void 0 ? void 0 : newWidths.staticWidth) {
            ColumnSettingsWidthUtils.updateColumnWidth(at, cellElement, newWidths, true);
            hasWidthChanged = true;
        }
        if (hasWidthChanged)
            StaticTableWidthUtils.changeWidthsBasedOnColumnInsertRemove(at, true);
    }
}
//# sourceMappingURL=columnSettingsWidthUtils.js.map