import { DateCellInputElement } from '../../elements/cell/cellsWithTextDiv/dateCell/dateCellInputElement';
import { CheckboxValidationFunc } from '../../elements/cell/checkboxCell/checkboxValidationFunc';
import { DropdownButtonItemConf } from '../../elements/dropdown/dropdownButtonItemConf';
import { SelectCell } from '../../elements/cell/cellsWithTextDiv/selectCell/selectCell';
import { CellDropdown } from '../../elements/dropdown/cellDropdown/cellDropdown';
import { DropdownItem } from '../../elements/dropdown/dropdownItem';
import { DefaultColumnTypes } from './defaultColumnTypes';
import { ObjectUtils } from '../object/objectUtils';
import { Browser } from '../browser/browser';
import { Validation } from './validation';
export class ColumnTypesUtils {
    static getTypeByName(availableTypes, targetName) {
        return availableTypes.find((type) => type.name.toLocaleLowerCase() === (targetName === null || targetName === void 0 ? void 0 : targetName.toLocaleLowerCase()));
    }
    static getTypeBasedOnProperties(settings, previousTypeName) {
        // if changing type due to settings change - the activeType would already be set - then try to see if the previous
        // type is present in the new settings and if it is use it
        if (previousTypeName) {
            const type = ColumnTypesUtils.getTypeByName(settings.types, previousTypeName);
            if (type)
                return type;
        }
        // if there is no previous type or it is not found in new settings - use the one the user has set
        if (settings.defaultColumnTypeName) {
            const type = ColumnTypesUtils.getTypeByName(settings.types, settings.defaultColumnTypeName);
            if (type)
                return type;
        }
        return undefined;
    }
    static getActiveType(settings, previousTypeName) {
        const activeType = ColumnTypesUtils.getTypeBasedOnProperties(settings, previousTypeName);
        if (activeType)
            return activeType;
        // if defaultColumnTypeName is not provided, default to first of the following:
        // First type to not have validation/First available type/'Text'
        const noValidationType = settings.types.find((type) => !type.textValidation.func);
        if (noValidationType)
            return noValidationType;
        const firstType = settings.types[0];
        if (firstType)
            return firstType;
        return DefaultColumnTypes.FALLBACK_TYPE;
    }
    // prettier-ignore
    static getReusableDefaultIcon(iconSettings) {
        var _a;
        const targetIconName = (_a = iconSettings.reusableIconName) === null || _a === void 0 ? void 0 : _a.toLocaleLowerCase();
        const defaultSettings = DefaultColumnTypes.DEFAULT_TYPES.find((type) => {
            return type.name.toLocaleLowerCase() === targetIconName;
        });
        if (defaultSettings === null || defaultSettings === void 0 ? void 0 : defaultSettings.iconSettings)
            return defaultSettings.iconSettings;
        return DropdownButtonItemConf.DEFAULT_ITEM.iconSettings;
    }
    static processDropdownItemSettings(type) {
        var _a, _b, _c;
        const { name, iconSettings } = type;
        let dropdownIconSettings;
        if (iconSettings) {
            if (iconSettings.reusableIconName) {
                dropdownIconSettings = ColumnTypesUtils.getReusableDefaultIcon(iconSettings);
            }
            else {
                dropdownIconSettings = iconSettings;
                if (Object.keys(iconSettings).length === 0) {
                    dropdownIconSettings = DropdownButtonItemConf.DEFAULT_ITEM.iconSettings;
                }
                else if (!iconSettings.svgString) {
                    (_a = dropdownIconSettings.svgString) !== null && _a !== void 0 ? _a : (dropdownIconSettings.svgString = DropdownButtonItemConf.DEFAULT_ITEM.iconSettings.svgString);
                    (_b = dropdownIconSettings.containerStyles) !== null && _b !== void 0 ? _b : (dropdownIconSettings.containerStyles = DropdownButtonItemConf.DEFAULT_ITEM.iconSettings.containerStyles);
                }
            }
        }
        else {
            dropdownIconSettings = DropdownButtonItemConf.DEFAULT_ITEM.iconSettings;
        }
        const settings = { text: name, iconSettings: dropdownIconSettings };
        const internalType = type;
        (_c = internalType.dropdownItem) !== null && _c !== void 0 ? _c : (internalType.dropdownItem = { element: null, settings });
        // reason for using timeout - creating icons is expensive and they are not needed on initial render
        setTimeout(() => {
            var _a;
            var _b;
            (_a = (_b = internalType.dropdownItem).element) !== null && _a !== void 0 ? _a : (_b.element = DropdownItem.createButtonItemNoEvents(undefined, settings));
        });
    }
    static processTextValidationProps(type) {
        var _a, _b;
        var _c;
        (_a = type.textValidation) !== null && _a !== void 0 ? _a : (type.textValidation = {});
        (_b = (_c = type.textValidation).setTextToDefaultOnFail) !== null && _b !== void 0 ? _b : (_c.setTextToDefaultOnFail = true);
    }
    static processCheckbox(type) {
        var _a, _b;
        if (type.checkbox && !((_a = type.customTextProcessing) === null || _a === void 0 ? void 0 : _a.changeTextFunc)) {
            (_b = type.customTextProcessing) !== null && _b !== void 0 ? _b : (type.customTextProcessing = {});
            type.customTextProcessing.changeTextFunc = CheckboxValidationFunc.getDefault();
        }
    }
    static processSelectOptions(type) {
        if (typeof type.select === 'object' && type.select.options) {
            const internalSelectProps = type.select;
            internalSelectProps.options = type.select.options.map((option) => {
                return { text: option };
            });
        }
        else if (typeof type.label === 'object' && type.label.options) {
            const internalSelectProps = type.label;
            // the reason for deep copy is because if canAddMoreOptions is set - colors can be changed and if the user
            // is reusing the same object for multiple columns a change in one can affect all others
            internalSelectProps.options = JSON.parse(JSON.stringify(type.label.options));
        }
    }
    static processSelect(type, isDefaultTextRemovable, defaultText) {
        var _a;
        const internalType = type;
        if (type.select === true || type.label === true) {
            internalType.cellDropdownProps = { isBasicSelect: !type.label };
        }
        else if (typeof type.select === 'object' || typeof type.label === 'object') {
            internalType.cellDropdownProps = (type.select || type.label);
            internalType.cellDropdownProps.isBasicSelect = !type.label;
            ColumnTypesUtils.processSelectOptions(type);
            Validation.setSelectValidation(internalType, isDefaultTextRemovable, defaultText);
        }
        if (internalType.cellDropdownProps && internalType.cellDropdownProps.canAddMoreOptions === undefined) {
            internalType.cellDropdownProps.canAddMoreOptions = !((_a = internalType.cellDropdownProps) === null || _a === void 0 ? void 0 : _a.options);
        }
    }
    // the reason why this is needed is when the argument is JSON stringified, properties that hold functions are removed,
    // hence they can only be applied to the component as strings
    static convertStringFunctionsToRealFunctions(type) {
        if (type.textValidation) {
            ObjectUtils.convertStringToFunction(type.textValidation, 'func');
        }
        if (type.customTextProcessing) {
            ObjectUtils.convertStringToFunction(type.customTextProcessing, 'changeTextFunc');
            ObjectUtils.convertStringToFunction(type.customTextProcessing, 'changeStyleFunc');
        }
        if (type.sorting) {
            ObjectUtils.convertStringToFunction(type.sorting, 'ascendingFunc');
            ObjectUtils.convertStringToFunction(type.sorting, 'descendingFunc');
        }
        if (type.calendar) {
            ObjectUtils.convertStringToFunction(type.calendar, 'toYMDFunc');
            ObjectUtils.convertStringToFunction(type.calendar, 'fromYMDFunc');
        }
    }
    // this is important because when types get processed - their resultant structure is not be the same, hence if
    // the same one is used in different settings (e.g. defaultColumnTypes set in default and custom settings),
    // the processing of the same type again would not work
    // JSON.stringify loses element and function references, hence they need to be manually reassigned
    static createTypeDeepCopy(type) {
        const newType = JSON.parse(JSON.stringify(type));
        if (type.dropdownItem)
            newType.dropdownItem = type.dropdownItem;
        if (type.textValidation)
            newType.textValidation = type.textValidation;
        if (type.customTextProcessing)
            newType.customTextProcessing = type.customTextProcessing;
        if (type.sorting)
            newType.sorting = type.sorting;
        if (type.calendar)
            newType.calendar = type.calendar;
        return newType;
    }
    static process(types, isDefaultTextRemovable, defaultText) {
        return types.map((type) => {
            const newType = ColumnTypesUtils.createTypeDeepCopy(type);
            ColumnTypesUtils.convertStringFunctionsToRealFunctions(newType);
            ColumnTypesUtils.processSelect(newType, isDefaultTextRemovable, defaultText);
            ColumnTypesUtils.processCheckbox(newType);
            ColumnTypesUtils.processTextValidationProps(newType);
            ColumnTypesUtils.processDropdownItemSettings(newType);
            return newType;
        });
    }
    static getAvailableTypes(settings) {
        let columnTypes = [...DefaultColumnTypes.DEFAULT_TYPES];
        const { availableDefaultColumnTypes, customColumnTypes } = settings;
        if (availableDefaultColumnTypes) {
            const lowerCaseDefaultNames = availableDefaultColumnTypes.map((typeName) => typeName.toLocaleLowerCase());
            columnTypes = columnTypes.filter((type) => {
                return lowerCaseDefaultNames.indexOf(type.name.toLocaleLowerCase()) > -1;
            });
        }
        if (customColumnTypes)
            columnTypes.push(...customColumnTypes);
        if (columnTypes.length === 0)
            columnTypes.push(DefaultColumnTypes.FALLBACK_TYPE);
        return columnTypes;
    }
    static getProcessedTypes(settings) {
        const { isDefaultTextRemovable, defaultText } = settings;
        const types = ColumnTypesUtils.getAvailableTypes(settings);
        return ColumnTypesUtils.process(types, isDefaultTextRemovable, defaultText);
    }
    // updates label color, date input etc.
    // prettier-ignore
    static updateDataElements(at, rowIndex, columnIndex, cellElement) {
        const { _columnsDetails, _tableDimensions } = at;
        const columnDetails = _columnsDetails[columnIndex];
        if (rowIndex === 0)
            return;
        if (columnDetails.activeType.cellDropdownProps) {
            CellDropdown.updateCellDropdown(cellElement, columnDetails.cellDropdown, _tableDimensions.border, columnDetails.settings.defaultText, true);
            SelectCell.finaliseEditedText(at, cellElement.children[0], columnIndex, true);
        }
        else if (Browser.IS_INPUT_DATE_SUPPORTED && columnDetails.activeType.calendar) {
            DateCellInputElement.updateInputBasedOnTextDiv(cellElement, columnDetails.activeType);
        }
    }
}
//# sourceMappingURL=columnTypesUtils.js.map