import { ElementStyle } from './elementStyle';
export class StatefulCSSEvents {
    static apply(styles, newStyle, element) {
        ElementStyle.unsetAllCSSStates(element, styles);
        Object.assign(element.style, newStyle);
    }
    static mouseUp(styles, inactiveClass, element) {
        if (inactiveClass && element.classList.contains(inactiveClass))
            return;
        StatefulCSSEvents.apply(styles, styles.default, element);
        Object.assign(element.style, styles.hover);
    }
    static mouseDown(styles, inactiveClass, element) {
        if (inactiveClass && element.classList.contains(inactiveClass))
            return;
        Object.assign(element.style, styles.click);
    }
    static mouseLeave(styles, inactiveClass, element) {
        if (inactiveClass && element.classList.contains(inactiveClass))
            return;
        StatefulCSSEvents.apply(styles, styles.default, element);
    }
    static mouseEnter(styles, inactiveClass, element) {
        if (inactiveClass && element.classList.contains(inactiveClass))
            return;
        Object.assign(element.style, styles.hover);
    }
    // can change the styling on another element by using the otherElement argument
    static getEvents(element, styles, inactiveClass, otherElement) {
        const target = otherElement || element;
        return {
            mouseenter: StatefulCSSEvents.mouseEnter.bind(this, styles, inactiveClass, target),
            mouseleave: StatefulCSSEvents.mouseLeave.bind(this, styles, inactiveClass, target),
            mousedown: StatefulCSSEvents.mouseDown.bind(this, styles, inactiveClass, target),
            mouseup: StatefulCSSEvents.mouseUp.bind(this, styles, inactiveClass, target),
        };
    }
    static setEvents(element, styles, inactiveClass, otherElement) {
        const events = StatefulCSSEvents.getEvents(element, styles, inactiveClass, otherElement);
        element.addEventListener('mouseenter', events.mouseenter);
        element.addEventListener('mouseleave', events.mouseleave);
        element.addEventListener('mousedown', events.mousedown);
        element.addEventListener('mouseup', events.mouseup);
        return events;
    }
}
//# sourceMappingURL=statefulCSSEvents.js.map