import { ElementStyle } from './elementStyle';
export class ToggleableElement {
    static set(button, style) {
        button.classList.add(ToggleableElement.ACTIVE_BUTTON_CLASS);
        Object.assign(button.style, style);
    }
    static unset(button, style) {
        button.classList.remove(ToggleableElement.ACTIVE_BUTTON_CLASS);
        ElementStyle.unsetStyle(button, style);
    }
    static toggleActive(button, style) {
        const isActive = !!button.classList.contains(ToggleableElement.ACTIVE_BUTTON_CLASS);
        if (isActive) {
            ToggleableElement.unset(button, style);
            button.dispatchEvent(new MouseEvent('mouseenter'));
        }
        else {
            ToggleableElement.set(button, style);
        }
        return isActive;
    }
    static unsetActive(button, style) {
        const isActive = !!button.classList.contains(ToggleableElement.ACTIVE_BUTTON_CLASS);
        if (isActive) {
            ToggleableElement.unset(button, style);
            button.dispatchEvent(new MouseEvent('mouseleave'));
        }
    }
    static setActive(button, style) {
        const isActive = !!button.classList.contains(ToggleableElement.ACTIVE_BUTTON_CLASS);
        if (!isActive) {
            ToggleableElement.set(button, style);
        }
    }
}
ToggleableElement.ACTIVE_BUTTON_CLASS = 'toggleable-button-active';
// used to allow automatic control of button icon styling, buttons that do not have this have to control their styles
ToggleableElement.AUTO_STYLING_CLASS = 'toggleable-button-auto-styling';
//# sourceMappingURL=toggleableElement.js.map