import { ColumnDropdownCellOverlay } from '../../../elements/dropdown/columnDropdown/cellOverlay/columnDropdownCellOverlay';
import { HeaderIconCellElement } from '../../../elements/cell/cellsWithTextDiv/headerIconCell/headerIconCellElement';
import { InsertRemoveColumnSizer } from '../../../elements/columnSizer/utils/insertRemoveColumnSizer';
import { DateCellElement } from '../../../elements/cell/cellsWithTextDiv/dateCell/dateCellElement';
import { StaticTableWidthUtils } from '../../tableDimensions/staticTable/staticTableWidthUtils';
import { CheckboxCellElement } from '../../../elements/cell/checkboxCell/checkboxCellElement';
import { UpdateIndexColumnWidth } from '../../../elements/indexColumn/updateIndexColumnWidth';
import { SelectCell } from '../../../elements/cell/cellsWithTextDiv/selectCell/selectCell';
import { ColumnSettingsBorderUtils } from '../../columnSettings/columnSettingsBorderUtils';
import { CellDropdown } from '../../../elements/dropdown/cellDropdown/cellDropdown';
import { ProcessedDataTextStyle } from '../../columnType/processedDataTextStyle';
import { CellDividerElement } from '../../../elements/cell/cellDividerElement';
import { CellElementIndex } from '../../elements/cellElementIndex';
import { ColumnDetails } from '../../columnDetails/columnDetails';
import { CellElement } from '../../../elements/cell/cellElement';
import { FireEvents } from '../../events/fireEvents';
import { DataUtils } from '../shared/dataUtils';
export class InsertNewCell {
    // prettier-ignore
    static insertElementsToRow(rowElement, newCellElement, rowIndex, columnIndex, displayIndexColumn) {
        // if child is undefined, the element is added at the end
        const childIndex = CellElementIndex.getViaColumnIndex(columnIndex, displayIndexColumn);
        rowElement.insertBefore(newCellElement, rowElement.children[childIndex]);
        const newCellDividerElement = CellDividerElement.create(rowIndex);
        rowElement.insertBefore(newCellDividerElement, rowElement.children[childIndex + 1]);
    }
    static updateColumnDetailsAndSizers(at, rowIndex, columnIndex, isNewText) {
        const columnDetails = at._columnsDetails[columnIndex];
        if (!columnDetails)
            return;
        if (rowIndex === 0) {
            const columnDropdownCellOverlay = ColumnDropdownCellOverlay.add(at, columnIndex);
            ColumnDetails.updateWithNoSizer(columnDetails, columnDropdownCellOverlay); // REF-13
            InsertRemoveColumnSizer.insert(at, columnIndex); // REF-13
            if (isNewText) {
                InsertRemoveColumnSizer.cleanUpCustomColumnSizers(at, columnIndex);
                UpdateIndexColumnWidth.wrapTextWhenNarrowColumnsBreached(at); // REF-19
            }
        }
    }
    // prettier-ignore
    static insert(at, rowElement, newCellElement, processedCellText, isNewText, rowIndex, columnIndex) {
        const { _frameComponents: { displayIndexColumn }, content, _columnsDetails } = at;
        const columnDetails = _columnsDetails[columnIndex];
        columnDetails.elements.splice(rowIndex, 0, newCellElement); // cannot be in timeout for max rows
        columnDetails.processedStyle.splice(rowIndex, 0, ProcessedDataTextStyle.getDefaultProcessedTextStyle());
        InsertNewCell.insertElementsToRow(rowElement, newCellElement, rowIndex, columnIndex, !!displayIndexColumn);
        // cannot place in a timeout as at.content length is used to get last row index
        content[rowIndex].splice(columnIndex, isNewText ? 0 : 1, processedCellText);
    }
    static convertCell(at, rowIndex, columnIndex, newCellElement) {
        const columnDetails = at._columnsDetails[columnIndex];
        if (rowIndex === 0 && at.displayHeaderIcons) {
            HeaderIconCellElement.setHeaderIconStructure(at, newCellElement, columnIndex);
        }
        if (!columnDetails.activeType)
            return;
        if (columnDetails.activeType.cellDropdownProps) {
            if (rowIndex === 0) {
                CellDropdown.setUpDropdown(at, columnIndex);
            }
            else {
                SelectCell.convertCell(at, columnIndex, newCellElement);
                SelectCell.finaliseEditedText(at, newCellElement.children[0], columnIndex, true);
            }
        }
        else if (rowIndex > 0) {
            if (columnDetails.activeType.checkbox) {
                CheckboxCellElement.setCellCheckboxStructure(at, newCellElement, columnIndex, rowIndex);
            }
            if (columnDetails.activeType.calendar) {
                DateCellElement.setCellDateStructure(at, newCellElement, columnIndex);
            }
        }
    }
    // REF-13
    // prettier-ignore
    static insertInitialColumnDetails(at, cellText, columnIndex) {
        const { _columnsDetails, _customColumnsSettings, _cellDropdownContainer, _defaultColumnsSettings } = at;
        const cellDropdown = CellDropdown.createAndAppend(_cellDropdownContainer);
        const columnDetails = ColumnDetails.createInitial(_defaultColumnsSettings, cellDropdown, _customColumnsSettings[cellText], at._defaultCellHoverColors, FireEvents.onColumnsUpdate.bind(this, at));
        _columnsDetails.splice(columnIndex, 0, columnDetails);
    }
    // isNewText indicates whether rowData is already in the content state or if it needs to be added
    // prettier-ignore
    static insertToRow(at, rowElement, rowIndex, columnIndex, cellText, isNewText) {
        if (rowIndex === 0)
            InsertNewCell.insertInitialColumnDetails(at, cellText, columnIndex); // REF-13
        const processedCellText = DataUtils.processCellText(at, rowIndex, columnIndex, cellText);
        const newCellElement = CellElement.createCellElement(at, processedCellText, columnIndex, rowIndex === 0);
        InsertNewCell.insert(at, rowElement, newCellElement, processedCellText, isNewText, rowIndex, columnIndex);
        InsertNewCell.convertCell(at, rowIndex, columnIndex, newCellElement); // need text set before conversion (checkbox)
        if (rowIndex === 0) {
            if (isNewText)
                StaticTableWidthUtils.changeWidthsBasedOnColumnInsertRemove(at, true); // REF-11
            ColumnSettingsBorderUtils.updateSiblingColumns(at, columnIndex);
        }
        else {
            ProcessedDataTextStyle.setCellStyle(at, rowIndex, columnIndex); // custom style will be applied in cellEvents
        }
        setTimeout(() => InsertNewCell.updateColumnDetailsAndSizers(at, rowIndex, columnIndex, isNewText));
    }
}
//# sourceMappingURL=insertNewCell.js.map