import { ToggleAdditionElements } from '../../../elements/table/addNewElements/shared/toggleAdditionElements';
import { AddNewColumnElement } from '../../../elements/table/addNewElements/column/addNewColumnElement';
import { FocusedCellUtils } from '../../focusedElements/focusedCellUtils';
import { UpdateCellsForColumns } from '../update/updateCellsForColumns';
import { CELL_UPDATE_TYPE } from '../../../enums/onUpdateCellType';
import { ExtractElements } from '../../elements/extractElements';
import { MaximumColumns } from './maximum/maximumColumns';
import { FireEvents } from '../../events/fireEvents';
import { EMPTY_STRING } from '../../../consts/text';
import { LastColumn } from '../shared/lastColumn';
import { InsertNewCell } from './insertNewCell';
export class InsertNewColumn {
    static updateColumns(at, rowElement, rowIndex, columnIndex) {
        const rowDetails = { element: rowElement, index: rowIndex };
        const lastColumn = LastColumn.getDetails(at._columnsDetails, rowIndex);
        UpdateCellsForColumns.rebindAndFireUpdates(at, rowDetails, columnIndex, CELL_UPDATE_TYPE.ADD, lastColumn);
    }
    static insertToAllRows(at, columnIndex, columnData) {
        const rowElements = ExtractElements.textRowsArrFromTBody(at._tableBodyElementRef, at.content);
        rowElements.forEach((rowElement, rowIndex) => {
            const cellText = columnData ? columnData[rowIndex] : EMPTY_STRING;
            InsertNewCell.insertToRow(at, rowElement, rowIndex, columnIndex, cellText, true);
            setTimeout(() => InsertNewColumn.updateColumns(at, rowElement, rowIndex, columnIndex));
        });
    }
    // columnData is in a row format to populate the column by iterating through each row
    static insert(at, columnIndex, columnData) {
        if (MaximumColumns.canAddMore(at)) {
            FocusedCellUtils.incrementColumnIndex(at._focusedElements.cell, columnIndex);
            InsertNewColumn.insertToAllRows(at, columnIndex, columnData);
            ToggleAdditionElements.update(at, true, AddNewColumnElement.toggle);
            setTimeout(() => {
                FireEvents.onContentUpdate(at);
                FireEvents.onColumnsUpdate(at);
            });
        }
    }
    static insertEvent() {
        InsertNewColumn.insert(this, this._columnsDetails.length);
    }
}
//# sourceMappingURL=insertNewColumn.js.map