import { RowDropdownCellOverlay } from '../../../elements/dropdown/rowDropdown/cellOverlay/rowDropdownCellOverlay';
import { ToggleAdditionElements } from '../../../elements/table/addNewElements/shared/toggleAdditionElements';
import { AddNewColumnElement } from '../../../elements/table/addNewElements/column/addNewColumnElement';
import { PaginationRowIndexes } from '../../outerTableComponents/pagination/paginationRowIndexes';
import { AddNewRowElement } from '../../../elements/table/addNewElements/row/addNewRowElement';
import { PaginationUtils } from '../../outerTableComponents/pagination/paginationUtils';
import { RowElement } from '../../../elements/table/addNewElements/row/rowElement';
import { IndexColumn } from '../../../elements/indexColumn/indexColumn';
import { CustomRowProperties } from '../../rows/customRowProperties';
import { CELL_UPDATE_TYPE } from '../../../enums/onUpdateCellType';
import { UpdateCellsForRows } from '../update/updateCellsForRows';
import { MaximumColumns } from './maximum/maximumColumns';
import { MoveRow } from '../../moveStructure/moveRow';
import { FireEvents } from '../../events/fireEvents';
import { MaximumRows } from './maximum/maximumRows';
import { InsertNewCell } from './insertNewCell';
import { DataUtils } from '../shared/dataUtils';
export class InsertNewRow {
    // CAUTION-2 if the addition or removal of row causes the parent div to change width, this is indeed run after rerender,
    // however the notification messages are necessary and the rebinding does not seem to cause issues, nevertheless take
    // note of this if editing any of the logic below
    static bindAndfireCellUpdates(at, rowIndex) {
        var _a;
        const lastRowIndex = at.content.length - 1;
        const lastDataRowElement = (_a = at._tableBodyElementRef) === null || _a === void 0 ? void 0 : _a.children[lastRowIndex];
        const lastRowDetails = { element: lastDataRowElement, index: lastRowIndex };
        UpdateCellsForRows.rebindAndFireUpdates(at, rowIndex, CELL_UPDATE_TYPE.ADD, lastRowDetails); // REF-20
        setTimeout(() => FireEvents.onContentUpdate(at));
    }
    static canStartRenderCellBeAdded(at, rowIndex, columnIndex) {
        if (rowIndex === 0) {
            return MaximumColumns.canAddMore(at);
        }
        return at._columnsDetails[columnIndex];
    }
    // prettier-ignore
    static addCells(at, newRowData, newRowElement, rowIndex, isNewText) {
        const { _frameComponents: { displayIndexColumn, displayAddNewColumn } } = at;
        if (displayIndexColumn)
            IndexColumn.createAndPrependToRow(at, newRowElement, rowIndex);
        newRowData.forEach((cellText, columnIndex) => {
            if (isNewText || InsertNewRow.canStartRenderCellBeAdded(at, rowIndex, columnIndex)) {
                InsertNewCell.insertToRow(at, newRowElement, rowIndex, columnIndex, cellText, isNewText);
            }
        });
        if (displayAddNewColumn)
            AddNewColumnElement.createAndAppendToRow(at, newRowElement, rowIndex);
        setTimeout(() => RowDropdownCellOverlay.add(at, rowIndex, newRowElement.children[0]));
    }
    // prettier-ignore
    static updatePagination(at, rowIndex, isNewText, newRowElement) {
        if (!isNewText) {
            PaginationUtils.initialRowUpdates(at, rowIndex, newRowElement);
        }
        else {
            PaginationUtils.updateOnRowChange(at, rowIndex, newRowElement);
        }
    }
    static insertNewRow(at, rowIndex, isNewText, rowData) {
        var _a, _b;
        const newRowData = rowData || DataUtils.createEmptyStringDataArray(((_a = at.content[0]) === null || _a === void 0 ? void 0 : _a.length) || 1);
        const newRowElement = RowElement.create();
        if (at.pagination)
            InsertNewRow.updatePagination(at, rowIndex, isNewText, newRowElement);
        (_b = at._tableBodyElementRef) === null || _b === void 0 ? void 0 : _b.insertBefore(newRowElement, at._tableBodyElementRef.children[rowIndex]);
        // don't need a timeout as addition of row with new text is not expensive
        if (isNewText)
            at.content.splice(rowIndex, 0, []);
        InsertNewRow.addCells(at, newRowData, newRowElement, rowIndex, isNewText);
        return newRowElement;
    }
    // isNewText indicates whether rowData is already in the content state or if it needs to be added
    static insert(at, rowIndex, isNewText, rowData) {
        if (!MaximumRows.canAddMore(at))
            return;
        const isReplacingHeader = isNewText && rowIndex === 0 && at._columnsDetails.length > 0;
        if (isReplacingHeader)
            rowIndex = 1; // REF-26
        const rowElement = InsertNewRow.insertNewRow(at, rowIndex, isNewText, rowData);
        if (isNewText) {
            ToggleAdditionElements.update(at, true, AddNewRowElement.toggle);
            if (at._frameComponents.displayIndexColumn)
                IndexColumn.updateIndexes(at, rowIndex + 1);
            CustomRowProperties.update(at, rowIndex);
        }
        if (isReplacingHeader)
            MoveRow.move(at, 0, true); // REF-26
        setTimeout(() => {
            if (at._isPopulatingTable) {
                UpdateCellsForRows.updateRowCells(at, rowElement, rowIndex, CELL_UPDATE_TYPE.ADD);
                // this is used to prevent multiple rebindings of same rows as upon the insertion of a new row or after pasting,
                // the content array would be populated synchronously which would cause the lastRowIndex to be high every time
                // this is called and rows between rowIndex and lastRowIndex would be rebinded multiple times
            }
            else if (!rowData) {
                InsertNewRow.bindAndfireCellUpdates(at, rowIndex);
            }
            else if (rowIndex === at.content.length - 1) {
                // may not be best to start from 0 but this method has no concept of starting point
                InsertNewRow.bindAndfireCellUpdates(at, 0);
            }
        });
    }
    // prettier-ignore
    static insertEvent() {
        let newRowIndex = this.content.length;
        if (this.pagination) {
            if (this._visiblityInternal.filters && this._tableBodyElementRef) {
                // before changing this check if new row can be added when none are present and one is present
                newRowIndex = this.content.length === 1 && !this.dataStartsAtHeader
                    ? 1 : PaginationRowIndexes.getVisibleRowRealIndex(this._tableBodyElementRef, this._pagination) + 1;
            }
            else {
                const maxVisibleRowIndex = PaginationRowIndexes.getMaxVisibleRowIndex(this);
                if (maxVisibleRowIndex < newRowIndex)
                    newRowIndex = maxVisibleRowIndex;
            }
        }
        InsertNewRow.insert(this, newRowIndex, true);
    }
}
//# sourceMappingURL=insertNewRow.js.map