import { RowDropdownCellOverlay } from '../../../elements/dropdown/rowDropdown/cellOverlay/rowDropdownCellOverlay';
import { ToggleAdditionElements } from '../../../elements/table/addNewElements/shared/toggleAdditionElements';
import { AddNewColumnElement } from '../../../elements/table/addNewElements/column/addNewColumnElement';
import { InsertRemoveColumnSizer } from '../../../elements/columnSizer/utils/insertRemoveColumnSizer';
import { StaticTableWidthUtils } from '../../tableDimensions/staticTable/staticTableWidthUtils';
import { ColumnSettingsBorderUtils } from '../../columnSettings/columnSettingsBorderUtils';
import { ColumnSettingsWidthUtils } from '../../columnSettings/columnSettingsWidthUtils';
import { UpdateCellsForColumns } from '../update/updateCellsForColumns';
import { TableElement } from '../../../elements/table/tableElement';
import { CellElementIndex } from '../../elements/cellElementIndex';
import { CELL_UPDATE_TYPE } from '../../../enums/onUpdateCellType';
import { ExtractElements } from '../../elements/extractElements';
import { HeaderText } from '../../columnDetails/headerText';
import { FireEvents } from '../../events/fireEvents';
import { LastColumn } from '../shared/lastColumn';
export class RemoveColumn {
    static reduceStaticWidthTotal(at, settings) {
        var _a;
        if ((_a = settings.widths) === null || _a === void 0 ? void 0 : _a.staticWidth) {
            const { number } = ColumnSettingsWidthUtils.getSettingsWidthNumber(at._tableElementRef, settings.widths);
            TableElement.changeStaticWidthTotal(at._tableDimensions, -number);
        }
    }
    static updateTableDimensions(at, settings) {
        RemoveColumn.reduceStaticWidthTotal(at, settings);
        StaticTableWidthUtils.changeWidthsBasedOnColumnInsertRemove(at, false);
    }
    static cleanUpContent(content) {
        // when is no data inside rows - remove them
        if (content.length > 0 && content[0].length === 0) {
            content.splice(0);
        }
    }
    static removeElements(rowElement, columnIndex, displayIndexColumn) {
        const elementColumnIndex = CellElementIndex.getViaColumnIndex(columnIndex, displayIndexColumn);
        // remove the text element
        rowElement.children[elementColumnIndex].remove();
        // remove the divider element
        rowElement.children[elementColumnIndex].remove();
    }
    static removeCell(at, rowElement, rowIndex, columnIndex) {
        const lastColumn = LastColumn.getDetails(at._columnsDetails, rowIndex);
        RemoveColumn.removeElements(rowElement, columnIndex, !!at._frameComponents.displayIndexColumn);
        at.content[rowIndex].splice(columnIndex, 1);
        setTimeout(() => {
            const rowDetails = { element: rowElement, index: rowIndex };
            UpdateCellsForColumns.rebindAndFireUpdates(at, rowDetails, columnIndex, CELL_UPDATE_TYPE.REMOVED, lastColumn);
        });
    }
    static removeCellFromAllRows(at, columnIndex) {
        const rowElements = ExtractElements.textRowsArrFromTBody(at._tableBodyElementRef, at.content);
        rowElements.forEach((rowElement, rowIndex) => {
            RemoveColumn.removeCell(at, rowElement, rowIndex, columnIndex);
        });
        RemoveColumn.cleanUpContent(at.content);
        HeaderText.onAttemptChange(at, at._columnsDetails[columnIndex].elements[0], columnIndex, { colRemove: true });
        // needs to be after getDetails but before changeWidthsBasedOnColumnInsertRemove
        const removedColumnDetails = at._columnsDetails.splice(columnIndex, 1)[0];
        RemoveColumn.updateTableDimensions(at, removedColumnDetails.settings);
        return removedColumnDetails;
    }
    static remove(at, columnIndex) {
        const removedColumnDetails = RemoveColumn.removeCellFromAllRows(at, columnIndex);
        ToggleAdditionElements.update(at, false, AddNewColumnElement.toggle);
        ColumnSettingsBorderUtils.updateSiblingColumns(at, columnIndex);
        setTimeout(() => {
            // CAUTION-2
            removedColumnDetails.cellDropdown.element.remove();
            InsertRemoveColumnSizer.remove(at, columnIndex);
            InsertRemoveColumnSizer.cleanUpCustomColumnSizers(at, columnIndex);
            if (columnIndex === 0 && at._columnsDetails.length > 0)
                RowDropdownCellOverlay.resetOverlays(at);
            setTimeout(() => {
                FireEvents.onContentUpdate(at);
                FireEvents.onColumnsUpdate(at);
            });
        });
    }
    static removeEvent(columnIndex) {
        RemoveColumn.remove(this, columnIndex);
    }
}
//# sourceMappingURL=removeColumn.js.map