import { ToggleAdditionElements } from '../../../elements/table/addNewElements/shared/toggleAdditionElements';
import { AddNewRowElement } from '../../../elements/table/addNewElements/row/addNewRowElement';
import { PaginationUtils } from '../../outerTableComponents/pagination/paginationUtils';
import { IndexColumn } from '../../../elements/indexColumn/indexColumn';
import { CustomRowProperties } from '../../rows/customRowProperties';
import { CELL_UPDATE_TYPE } from '../../../enums/onUpdateCellType';
import { UpdateCellsForRows } from '../update/updateCellsForRows';
import { MoveRow } from '../../moveStructure/moveRow';
import { FireEvents } from '../../events/fireEvents';
import { RemoveColumn } from './removeColumn';
export class RemoveRow {
    // when the last row has been removed, there are no more columns
    static removeAllColumnsDetails(at) {
        const { _columnsDetails } = at;
        _columnsDetails.forEach((columnDetails) => RemoveColumn.reduceStaticWidthTotal(at, columnDetails.settings));
        _columnsDetails.splice(0, _columnsDetails.length);
    }
    static update(at, rowIndex, lastRowElement, lastRowIndex) {
        const lastRow = { element: lastRowElement, index: lastRowIndex };
        UpdateCellsForRows.rebindAndFireUpdates(at, rowIndex, CELL_UPDATE_TYPE.REMOVED, lastRow); // REF-20
        setTimeout(() => FireEvents.onContentUpdate(at));
        if (at._isRendering)
            return;
        if (at.content.length === 0)
            RemoveRow.removeAllColumnsDetails(at);
        at._addColumnCellsElementsRef.splice(rowIndex, 1);
    }
    static rowToBeRemovedIndexWhenPagination(at, rowIndex) {
        var _a;
        const rowToBeRemoved = (_a = at._tableBodyElementRef) === null || _a === void 0 ? void 0 : _a.children[rowIndex];
        return at._pagination.visibleRows.findIndex((row) => row === rowToBeRemoved);
    }
    static removeRow(at, rowIndex) {
        var _a;
        const index = at.pagination ? RemoveRow.rowToBeRemovedIndexWhenPagination(at, rowIndex) : 0; // before it is removed
        (_a = at._tableBodyElementRef) === null || _a === void 0 ? void 0 : _a.children[rowIndex].remove();
        at._rowDropdownCellOverlays.splice(rowIndex, 1);
        const removedContentRow = at.content.splice(rowIndex, 1);
        // needs to be done synchronously as add new row toggle needs elements count when calling MaximumRows.canAddMore
        removedContentRow[0].forEach((_, columnIndex) => {
            at._columnsDetails[columnIndex].elements.splice(rowIndex, 1);
            at._columnsDetails[columnIndex].processedStyle.splice(rowIndex, 1);
        });
        if (at.pagination)
            PaginationUtils.updateOnRowChange(at, index);
        return removedContentRow[0];
    }
    // REF-27
    static changeRowIndexIfRemoveHeaderWithDataBelow(at, rowIndex) {
        const isHeaderRowWithDataBelow = rowIndex === 0 && at._columnsDetails[0].elements.length > 1;
        if (isHeaderRowWithDataBelow) {
            MoveRow.move(at, 0, true);
            return 1;
        }
        return rowIndex;
    }
    static remove(at, rowIndex) {
        var _a;
        rowIndex = RemoveRow.changeRowIndexIfRemoveHeaderWithDataBelow(at, rowIndex);
        const lastRowIndex = at.content.length - 1;
        const lastRowElement = (_a = at._tableBodyElementRef) === null || _a === void 0 ? void 0 : _a.children[lastRowIndex];
        RemoveRow.removeRow(at, rowIndex);
        ToggleAdditionElements.update(at, false, AddNewRowElement.toggle);
        if (at._frameComponents.displayIndexColumn)
            IndexColumn.updateIndexes(at, rowIndex);
        CustomRowProperties.update(at, rowIndex);
        setTimeout(() => RemoveRow.update(at, rowIndex, lastRowElement, lastRowIndex));
    }
}
//# sourceMappingURL=removeRow.js.map