import { NumberOfIdenticalCells } from '../../content/numberOfIdenticalCells';
import { EMPTY_STRING } from '../../../consts/text';
export class DataUtils {
    static createEmptyStringDataArray(length) {
        return new Array(length).fill(EMPTY_STRING);
    }
    static isTextEmpty(defaultText, cellText) {
        if (defaultText !== EMPTY_STRING) {
            const processedCellText = typeof cellText === 'string' ? cellText.trim() : cellText;
            return processedCellText === EMPTY_STRING;
        }
        return false;
    }
    // note that NumberOfIdenticalCells.get uses the at.content top row, so it needs to be up-to-date
    // prettier-ignore
    static shouldBeSetToDefault(at, text, defaultText, rowIndex, textValidation) {
        const { allowDuplicateHeaders, _columnsDetails } = at;
        return DataUtils.isTextEmpty(defaultText, text)
            || (rowIndex === 0 && (!allowDuplicateHeaders && NumberOfIdenticalCells.get(text, _columnsDetails) > 1))
            || (rowIndex > 0 && !(textValidation.func === undefined || textValidation.func(String(text))));
    }
    // prettier-ignore
    static processCellText(at, rowIndex, columnIndex, cellText) {
        let processedText = typeof cellText === 'string' ? cellText.trim() : cellText;
        const columnsDetails = at._columnsDetails[columnIndex];
        if (!columnsDetails)
            return processedText;
        const { activeType: { textValidation, customTextProcessing }, settings: { defaultText } } = columnsDetails;
        if (rowIndex > 0) {
            if (customTextProcessing === null || customTextProcessing === void 0 ? void 0 : customTextProcessing.changeTextFunc) {
                processedText = customTextProcessing.changeTextFunc(String(processedText), rowIndex);
            }
            if (!textValidation.setTextToDefaultOnFail && processedText !== EMPTY_STRING)
                return processedText;
        }
        const shouldSetToDefault = DataUtils.shouldBeSetToDefault(at, processedText, defaultText, rowIndex, textValidation);
        return shouldSetToDefault ? defaultText : processedText;
    }
}
//# sourceMappingURL=dataUtils.js.map