import { CellEventsReset } from '../../../elements/cell/cellEventsReset';
import { CELL_UPDATE_TYPE } from '../../../enums/onUpdateCellType';
import { CellElement } from '../../../elements/cell/cellElement';
import { ExtractElements } from '../../elements/extractElements';
import { FireEvents } from '../../events/fireEvents';
export class UpdateCellsForColumns {
    // prettier-ignore
    static updateColumn(at, rowIndex, cellElement, columnIndex, updateType) {
        if (updateType !== CELL_UPDATE_TYPE.REMOVED) {
            CellEventsReset.reset(at, cellElement, rowIndex, columnIndex); // REF-33
        }
        FireEvents.onCellUpdate(at, CellElement.getText(cellElement), rowIndex, columnIndex, updateType);
    }
    // prettier-ignore
    static updateNextBeforeLastColumns(at, row, startColumnIndex, lastColumnIndex) {
        const nextColumns = ExtractElements.textCellsArrFromRow(row.element).slice(startColumnIndex, lastColumnIndex);
        nextColumns.forEach((cellElement, columnIndex) => {
            const relativeColumnIndex = columnIndex + startColumnIndex;
            UpdateCellsForColumns.updateColumn(at, row.index, cellElement, relativeColumnIndex, CELL_UPDATE_TYPE.UPDATE);
        });
    }
    // the reason why last column details need to be passed here is because after removal of last element, its details are
    // no longer present here as this class's methods are run in setTimeouts, hence those details need to be captured
    // before these methods are executed
    // prettier-ignore
    static rebindAndFireUpdates(at, row, startingColumnIndex, updateType, lastColumn) {
        UpdateCellsForColumns.updateNextBeforeLastColumns(at, row, startingColumnIndex, lastColumn.index);
        UpdateCellsForColumns.updateColumn(at, row.index, lastColumn.element, lastColumn.index, updateType);
    }
}
//# sourceMappingURL=updateCellsForColumns.js.map