// eslint-disable-next-line max-len
import { RowDropdownCellOverlayEvents } from '../../../elements/dropdown/rowDropdown/cellOverlay/rowDropdownCellOverlayEvents';
import { IndexColumnEvents } from '../../../elements/indexColumn/indexColumnEvents';
import { CellEventsReset } from '../../../elements/cell/cellEventsReset';
import { CELL_UPDATE_TYPE } from '../../../enums/onUpdateCellType';
import { CellElement } from '../../../elements/cell/cellElement';
import { ExtractElements } from '../../elements/extractElements';
import { DragRow } from '../../moveStructure/drag/dragRow';
import { FireEvents } from '../../events/fireEvents';
export class UpdateCellsForRows {
    static updateRowCells(at, rowElement, rowIndex, updateType) {
        var _a;
        const dataCellElements = ExtractElements.textCellsArrFromRow(rowElement);
        dataCellElements.forEach((cellElement, columnIndex) => {
            if (updateType !== CELL_UPDATE_TYPE.REMOVED) {
                CellEventsReset.reset(at, cellElement, rowIndex, columnIndex); // REF-33
            }
            FireEvents.onCellUpdate(at, CellElement.getText(cellElement), rowIndex, columnIndex, updateType);
        });
        if (updateType !== CELL_UPDATE_TYPE.REMOVED) {
            const leftMostCell = rowElement.children[0];
            if (at._frameComponents.displayIndexColumn) {
                IndexColumnEvents.setEvents(at, leftMostCell, rowIndex);
                DragRow.applyEventsToElement(at, leftMostCell, leftMostCell);
            }
            if ((_a = at.rowDropdown.displaySettings.openMethod) === null || _a === void 0 ? void 0 : _a.overlayClick) {
                const overlay = RowDropdownCellOverlayEvents.setOverlayEvents(at, rowIndex, leftMostCell);
                DragRow.applyEventsToElement(at, overlay, leftMostCell);
            }
        }
    }
    static updateLastRow(at, updateType, lastRow) {
        var _a;
        if ((_a = at._tableBodyElementRef) === null || _a === void 0 ? void 0 : _a.children) {
            UpdateCellsForRows.updateRowCells(at, lastRow.element, lastRow.index, updateType);
        }
    }
    static updateLowerBeforeLastRows(at, startRowIndex, lastRowIndex) {
        var _a;
        const tableBodyChildren = (_a = at._tableBodyElementRef) === null || _a === void 0 ? void 0 : _a.children;
        if (tableBodyChildren) {
            const lowerRows = Array.from(tableBodyChildren).slice(startRowIndex, lastRowIndex);
            lowerRows.forEach((row, lowerRowIndex) => {
                const relativeContentRowIndex = lowerRowIndex + startRowIndex;
                const rowElement = row;
                UpdateCellsForRows.updateRowCells(at, rowElement, relativeContentRowIndex, CELL_UPDATE_TYPE.UPDATE);
            });
        }
    }
    // REF-20
    // the reason why last row details need to be passed here is because after removal of last row, the last element details
    // are no longer available as this class's methods are run in setTimeouts, hence those details need to be captured
    // before these methods are executed
    // CAUTION-2 if the addition or removal of row causes the parent div to change width, this is indeed run after rerender,
    // however the onCellUpdate messages are required and event rebinding here still appears to be valid
    // prettier-ignore
    static rebindAndFireUpdates(at, startRowIndex, lastRowUpdateType, lastRow) {
        UpdateCellsForRows.updateLowerBeforeLastRows(at, startRowIndex, lastRow.index);
        UpdateCellsForRows.updateLastRow(at, lastRowUpdateType, lastRow);
    }
}
//# sourceMappingURL=updateCellsForRows.js.map