import { AddNewRowElement } from '../../../elements/table/addNewElements/row/addNewRowElement';
import { FocusedCellUtils } from '../../focusedElements/focusedCellUtils';
import { MoveRow } from '../moveRow';
import { Drag } from './drag';
// WORK - when filtering/pagination - move using row dropdown
export class DragRow extends Drag {
    static resetElements(realRow) {
        var _a, _b;
        (_a = DragRow.CLONE_ROW) === null || _a === void 0 ? void 0 : _a.remove();
        const rowChildren = Array.from(realRow.children || []);
        rowChildren.forEach((dataCell) => {
            dataCell.classList.remove(Drag.CELL_HIDDEN_CLASS);
        });
        (_b = DragRow.TARGET_LINE) === null || _b === void 0 ? void 0 : _b.remove();
    }
    static appendTargetLine(tableBody) {
        DragRow.TARGET_LINE = document.createElement('div');
        DragRow.TARGET_LINE.classList.add('row-drag-target-line');
        DragRow.TARGET_LINE.style.opacity = '0';
        tableBody.appendChild(DragRow.TARGET_LINE);
    }
    static prepareElements(tableBody, cloneRow, realRow) {
        cloneRow.classList.add(DragRow.ROW_CLONE_CLASS);
        cloneRow.style.top = `${realRow.offsetTop}px`;
        const height = `${realRow.children[0].offsetHeight}px`;
        const rowChildren = Array.from(realRow.children || []);
        Array.from(cloneRow.children).forEach((cloneCell, index) => {
            cloneCell.style.width = `${rowChildren[index].offsetWidth}px`;
            cloneCell.style.height = height;
        });
        rowChildren.forEach((dataCell) => {
            dataCell.classList.add(Drag.CELL_HIDDEN_CLASS);
        });
        DragRow.appendTargetLine(tableBody);
    }
    static calculateThresholdDown() {
        if (DragRow.TARGET_DOWN_ROW && DragRow.ROW) {
            DragRow.THRESHOLD_DOWN =
                DragRow.TARGET_DOWN_ROW.offsetTop + DragRow.TARGET_DOWN_ROW.offsetHeight / 2 - DragRow.ROW.offsetHeight;
        }
    }
    static calculateThresholdUp() {
        if (DragRow.TARGET_UP_ROW) {
            DragRow.THRESHOLD_UP = DragRow.TARGET_UP_ROW.offsetTop + DragRow.TARGET_UP_ROW.offsetHeight / 2;
        }
    }
    static initiateDragState(tableBody, cloneRow, realRow) {
        var _a;
        DragRow.ROW = realRow;
        DragRow.TARGET_UP_ROW = DragRow.ROW.previousSibling;
        DragRow.TARGET_DOWN_ROW = (_a = DragRow.ROW.nextSibling) === null || _a === void 0 ? void 0 : _a.nextSibling;
        if (!DragRow.TARGET_UP_ROW && AddNewRowElement.isAddNewRowRow(DragRow.TARGET_DOWN_ROW.children[0]))
            return;
        DragRow.CLONE_ROW = cloneRow;
        DragRow.ACTIVE_ROW_TOP_PX = realRow.offsetTop;
        DragRow.ACTIVE_INDEX = 0;
        DragRow.calculateThresholdUp();
        DragRow.calculateThresholdDown();
        const rows = Array.from(tableBody.children);
        Drag.ORIGINAL_INDEX = rows.findIndex((element) => element === DragRow.ROW);
        const addNewRowRow = rows[rows.length - 2].offsetHeight;
        DragRow.MAX_DOWN = tableBody.offsetHeight - DragRow.ROW.offsetHeight - addNewRowRow;
    }
    static processRowCellsToDrag(tableBody, cellElement) {
        const realRow = cellElement.parentElement;
        realRow.dispatchEvent(new MouseEvent('mouseleave')); // optimization - slow rendering with hover style (on many rows)
        const cloneRow = realRow.cloneNode(true); // also clones the index and add column cells
        realRow === null || realRow === void 0 ? void 0 : realRow.insertAdjacentElement('afterend', cloneRow);
        DragRow.prepareElements(tableBody, cloneRow, realRow);
        DragRow.initiateDragState(tableBody, cloneRow, realRow);
    }
    static applyEventsToElement(at, draggableElement, cellElement) {
        if (!DragRow.IS_DRAGGING_ALLOWED)
            return;
        draggableElement.onmousedown = () => {
            DragRow.IS_MOUSE_DOWN = true;
        };
        draggableElement.onmousemove = () => {
            if (DragRow.IS_MOUSE_DOWN && !DragRow.ROW) {
                DragRow.INITIALISING_DRAG_PX += 1;
                if (DragRow.INITIALISING_DRAG_PX > Drag.DRAG_PX_TO_MOVE) {
                    DragRow.processRowCellsToDrag(at._tableBodyElementRef, cellElement);
                    FocusedCellUtils.set(at._focusedElements.cell, cellElement, 0, Drag.ORIGINAL_INDEX);
                }
            }
        };
    }
    static moveTargetLine(targetLine, top) {
        targetLine.style.opacity = '1';
        targetLine.style.top = `${top}px`;
    }
    // Upon approaching the original row the target line is hidden
    static removeLineOnMoveDown(targetLine) {
        targetLine.style.opacity = '0';
        DragRow.ACTIVE_INDEX = 0;
        DragRow.THRESHOLD_TO_NO_LINE_DOWN = -1;
        DragRow.calculateThresholdUp();
    }
    static attemptSwitchUp(targetLine) {
        var _a;
        if (DragRow.TARGET_UP_ROW && DragRow.ROW) {
            if (((_a = DragRow.TARGET_UP_ROW.previousSibling) === null || _a === void 0 ? void 0 : _a.previousSibling) === DragRow.ROW) {
                // this is small drag interim where upon approaching the original row the target line is eventually hidden
                DragRow.THRESHOLD_TO_NO_LINE_UP = DragRow.ROW.offsetTop + DragRow.ROW.offsetHeight / 2;
                DragRow.THRESHOLD_DOWN = DragRow.TARGET_UP_ROW.offsetTop + DragRow.TARGET_UP_ROW.offsetHeight / 2;
                DragRow.TARGET_DOWN_ROW = DragRow.TARGET_UP_ROW;
                DragRow.TARGET_UP_ROW = DragRow.ROW.previousSibling;
                if (DragRow.TARGET_UP_ROW) {
                    DragRow.calculateThresholdUp();
                }
                else {
                    DragRow.THRESHOLD_UP = -1;
                }
            }
            else {
                DragRow.moveTargetLine(targetLine, DragRow.TARGET_UP_ROW.offsetTop - 3);
                DragRow.THRESHOLD_DOWN = DragRow.THRESHOLD_UP;
                DragRow.TARGET_DOWN_ROW = DragRow.TARGET_UP_ROW;
                DragRow.TARGET_UP_ROW = DragRow.TARGET_UP_ROW.previousSibling;
                DragRow.calculateThresholdUp();
                DragRow.ACTIVE_INDEX -= 1;
            }
        }
    }
    // Upon approaching the original row the target line is hidden
    static removeLineOnMoveUp(targetLine) {
        targetLine.style.opacity = '0';
        DragRow.ACTIVE_INDEX = 0;
        DragRow.THRESHOLD_TO_NO_LINE_UP = -1;
        DragRow.calculateThresholdDown();
    }
    static attemptSwitchDown(targetLine) {
        var _a, _b;
        if (DragRow.TARGET_DOWN_ROW) {
            if (DragRow.TARGET_DOWN_ROW.nextSibling === DragRow.ROW) {
                // this is small drag interim where upon approaching the original row the target line is eventually hidden
                DragRow.THRESHOLD_TO_NO_LINE_DOWN = DragRow.TARGET_DOWN_ROW.offsetTop + DragRow.TARGET_DOWN_ROW.offsetHeight / 2;
                DragRow.TARGET_UP_ROW = DragRow.TARGET_DOWN_ROW;
                DragRow.THRESHOLD_UP = DragRow.TARGET_UP_ROW.offsetTop - DragRow.TARGET_UP_ROW.offsetHeight / 2;
                DragRow.TARGET_DOWN_ROW = (_b = (_a = DragRow.ROW) === null || _a === void 0 ? void 0 : _a.nextSibling) === null || _b === void 0 ? void 0 : _b.nextSibling;
                DragRow.calculateThresholdDown();
            }
            else {
                DragRow.moveTargetLine(targetLine, DragRow.TARGET_DOWN_ROW.offsetTop + DragRow.TARGET_DOWN_ROW.offsetHeight - 3);
                DragRow.THRESHOLD_UP = DragRow.THRESHOLD_DOWN;
                DragRow.TARGET_UP_ROW = DragRow.TARGET_DOWN_ROW;
                DragRow.TARGET_DOWN_ROW = DragRow.TARGET_DOWN_ROW.nextSibling;
                DragRow.calculateThresholdDown();
                DragRow.ACTIVE_INDEX += 1;
            }
        }
    }
    static windowDrag(event) {
        if (!DragRow.IS_DRAGGING_ALLOWED || !DragRow.TARGET_LINE || !DragRow.ROW || !DragRow.CLONE_ROW)
            return;
        const minimumDown = Math.max(0, DragRow.ACTIVE_ROW_TOP_PX + event.movementY);
        const newDimension = Math.min(minimumDown, DragRow.MAX_DOWN);
        DragRow.ACTIVE_ROW_TOP_PX = newDimension;
        DragRow.CLONE_ROW.style.top = `${DragRow.ACTIVE_ROW_TOP_PX}px`;
        if (DragRow.ACTIVE_ROW_TOP_PX > DragRow.THRESHOLD_DOWN) {
            DragRow.attemptSwitchDown(DragRow.TARGET_LINE);
        }
        else if (DragRow.ACTIVE_ROW_TOP_PX < DragRow.THRESHOLD_UP) {
            DragRow.attemptSwitchUp(DragRow.TARGET_LINE);
        }
        else if (DragRow.THRESHOLD_TO_NO_LINE_DOWN >= 0 && DragRow.THRESHOLD_TO_NO_LINE_DOWN < DragRow.ACTIVE_ROW_TOP_PX) {
            DragRow.removeLineOnMoveDown(DragRow.TARGET_LINE);
        }
        else if (DragRow.THRESHOLD_TO_NO_LINE_UP >= 0 && DragRow.THRESHOLD_TO_NO_LINE_UP > DragRow.ACTIVE_ROW_TOP_PX) {
            DragRow.removeLineOnMoveUp(DragRow.TARGET_LINE);
        }
    }
    static windowMouseUp(at) {
        DragRow.IS_MOUSE_DOWN = false;
        if (!DragRow.IS_DRAGGING_ALLOWED)
            return;
        if (DragRow.ROW) {
            DragRow.resetElements(DragRow.ROW);
            DragRow.ROW = null;
            DragRow.INITIALISING_DRAG_PX = 0;
            DragRow.move(at, DragRow.ACTIVE_INDEX, MoveRow.move);
        }
    }
}
// WORK - should hold this as component state
DragRow.IS_DRAGGING_ALLOWED = false;
DragRow.ROW_CLONE_CLASS = 'row-clone';
DragRow.INITIALISING_DRAG_PX = 0;
DragRow.ACTIVE_ROW_TOP_PX = 0;
DragRow.ROW = null;
DragRow.CLONE_ROW = null;
DragRow.IS_MOUSE_DOWN = false;
DragRow.ACTIVE_INDEX = 0;
DragRow.THRESHOLD_UP = 0;
DragRow.THRESHOLD_DOWN = 0;
DragRow.MAX_DOWN = 0;
// this are small interims where upon approaching the original row the target line is eventually hidden
DragRow.THRESHOLD_TO_NO_LINE_DOWN = -1;
DragRow.THRESHOLD_TO_NO_LINE_UP = -1;
//# sourceMappingURL=dragRow.js.map