import { DropdownItemHighlightUtils } from '../../color/dropdownItemHighlightUtils';
import { OuterDropdownButtonEvents } from './outerDropdownButtonEvents';
import { ToggleableElement } from '../../elements/toggleableElement';
import { ElementVisibility } from '../../elements/elementVisibility';
import { Dropdown } from '../../../elements/dropdown/dropdown';
import { OuterDropdownEvents } from './outerDropdownEvents';
import { SIDE } from '../../../types/side';
export class OuterDropdownElement {
    static hide(activeOverlayElements, activeStyle) {
        const dropdown = activeOverlayElements.outerContainerDropdown;
        if (dropdown) {
            Dropdown.hide(dropdown.element);
            if (dropdown.button.classList.contains(ToggleableElement.AUTO_STYLING_CLASS)) {
                ToggleableElement.unsetActive(dropdown.button, activeStyle);
            }
            delete activeOverlayElements.outerContainerDropdown;
            DropdownItemHighlightUtils.fadeCurrentlyHighlighted(activeOverlayElements);
        }
    }
    static display(at, dropdown) {
        if (dropdown.button.classList.contains(ToggleableElement.AUTO_STYLING_CLASS)) {
            ToggleableElement.setActive(dropdown.button, dropdown.activeButtonStyle);
        }
        Dropdown.display(dropdown.element);
        at._activeOverlayElements.outerContainerDropdown = dropdown;
    }
    static displayReactToBottomVisibility(at, dropdown) {
        dropdown.element.classList.remove(OuterDropdownElement.DROPUP_CLASS);
        OuterDropdownElement.display(at, dropdown);
        const visibilityDetails = ElementVisibility.getDetailsInWindow(dropdown.element, at._tableDimensions.border, false);
        if (!visibilityDetails.isFullyVisible && visibilityDetails.blockingSides.has(SIDE.BOTTOM)) {
            dropdown.element.classList.add(OuterDropdownElement.DROPUP_CLASS);
        }
    }
    static setOrientation(dropdownElement, position) {
        if (position.endsWith('right'))
            dropdownElement.style.right = '0px';
    }
    static createElement(additionalClasses) {
        const dropdownElement = Dropdown.createBase();
        dropdownElement.style.width = '';
        dropdownElement.classList.add('outer-container-dropdown');
        if (additionalClasses)
            dropdownElement.classList.add(...additionalClasses);
        return dropdownElement;
    }
    // prettier-ignore
    static create(at, button, position, activeButtonStyle, additionalClasses, hide, displayFunc) {
        const dropdownElement = OuterDropdownElement.createElement(additionalClasses);
        const dropdown = { element: dropdownElement, hide, button, activeButtonStyle };
        OuterDropdownElement.setOrientation(dropdownElement, position);
        OuterDropdownButtonEvents.set(at, button, position, dropdown, displayFunc);
        OuterDropdownEvents.set(at, dropdown);
        return dropdown;
    }
}
OuterDropdownElement.DROPUP_CLASS = 'active-table-dropup';
//# sourceMappingURL=outerDropdownElement.js.map