import { DropdownItemNavigation } from '../../../elements/dropdown/dropdownItemNavigation';
import { DropdownEvents } from '../../../elements/dropdown/dropdownEvents';
import { DropdownItem } from '../../../elements/dropdown/dropdownItem';
import { KEYBOARD_KEY } from '../../../consts/keyboardKeys';
export class OuterDropdownEvents {
    static windowOnMouseDown(at) {
        if (at._activeOverlayElements.outerContainerDropdown) {
            at._activeOverlayElements.outerContainerDropdown.hide();
        }
    }
    static focusSiblingItem(dropdownEl, item, sibling) {
        const siblingItem = item === null || item === void 0 ? void 0 : item[sibling];
        if (siblingItem) {
            DropdownItemNavigation.focusSiblingItem(siblingItem, dropdownEl, true, true);
        }
        else {
            if (sibling === 'nextSibling') {
                const firstItem = dropdownEl.children[0];
                if (firstItem)
                    DropdownItemNavigation.focusSiblingItem(firstItem, dropdownEl, true, true);
            }
            else {
                const lastItem = dropdownEl.children[dropdownEl.children.length - 1];
                if (lastItem)
                    DropdownItemNavigation.focusSiblingItem(lastItem, dropdownEl, false, true);
            }
        }
    }
    // prettier-ignore
    static windowOnKeyDownNavigation(dropdownEl, key) {
        const activeItem = dropdownEl.getElementsByClassName(DropdownItem.ACTIVE_ITEM_CLASS)[0];
        if (key === KEYBOARD_KEY.TAB || key === KEYBOARD_KEY.ARROW_DOWN) {
            if (activeItem) {
                OuterDropdownEvents.focusSiblingItem(dropdownEl, activeItem, 'nextSibling');
            }
            else {
                DropdownItemNavigation.focusSiblingItem(dropdownEl.children[0], dropdownEl, true, true);
            }
        }
        else if (key === KEYBOARD_KEY.ARROW_UP) {
            if (activeItem) {
                OuterDropdownEvents.focusSiblingItem(dropdownEl, activeItem, 'previousSibling');
            }
            else {
                DropdownItemNavigation.focusSiblingItem(dropdownEl.children[dropdownEl.children.length - 1], dropdownEl, false, true);
            }
        }
    }
    // the reason why we track window key events is because the table is not actually focused when it is displayed,
    // (unlike column dropdown which has an input), hence initially clicking tab does not focus the dropdown and
    // instead we need to focus it programmatically here. Once focused, the actual dropdown events can take over.
    // prettier-ignore
    static windowOnKeyDown(at, event) {
        const { shadowRoot, _activeOverlayElements: { outerContainerDropdown: dropdown } } = at;
        if (!dropdown)
            return;
        event.preventDefault();
        const { element, hide } = dropdown;
        if (event.key === KEYBOARD_KEY.ENTER || event.key === KEYBOARD_KEY.ESCAPE) {
            hide();
        }
        else if (!(shadowRoot === null || shadowRoot === void 0 ? void 0 : shadowRoot.activeElement)) {
            OuterDropdownEvents.windowOnKeyDownNavigation(element, event.key);
        }
    }
    static dropdownOnKeyDown(dropdown, event) {
        event.preventDefault();
        if (event.key === KEYBOARD_KEY.ENTER) {
            const itemElement = event.target;
            itemElement.dispatchEvent(new MouseEvent('mousedown'));
        }
        else if (event.key === KEYBOARD_KEY.ESCAPE) {
            dropdown.hide();
        }
        DropdownEvents.itemKeyNavigation(this.shadowRoot, dropdown.element, event);
    }
    static set(at, dropdown) {
        dropdown.element.onkeydown = OuterDropdownEvents.dropdownOnKeyDown.bind(at, dropdown);
    }
}
//# sourceMappingURL=outerDropdownEvents.js.map