import { UpdateAllTableData } from '../../../programmaticUpdates/updateAllTableData';
export class CSVImport {
    static getPaddedArray(rowsOfData, largestRowLength) {
        return rowsOfData.map((row) => row.concat(Array(largestRowLength).fill('')).slice(0, largestRowLength));
    }
    static parseDataFromRow(row, rowsOfData, largestRowLength) {
        const data = row.split(',');
        if (data.length > 0) {
            rowsOfData.push(data);
            if (data.length > largestRowLength)
                largestRowLength = data.length;
        }
        return largestRowLength;
    }
    // TO-DO validation and error handling
    static parseCSV(csvText) {
        try {
            const rows = csvText.split(/\r\n|\n/);
            const rowsOfData = [];
            let largestRowLength = 0;
            rows.forEach((row) => {
                largestRowLength = CSVImport.parseDataFromRow(row, rowsOfData, largestRowLength);
            });
            return CSVImport.getPaddedArray(rowsOfData, largestRowLength);
        }
        catch (errorMessage) {
            console.error('Incorrect format');
            return null;
        }
    }
    static getStartRowIndex(numberOfTableRows, options) {
        if (options && typeof options.tableRowStartIndex === 'number') {
            if (options.tableRowStartIndex < 0 || options.tableRowStartIndex > numberOfTableRows) {
                return numberOfTableRows;
            }
            return options.tableRowStartIndex;
        }
        return 0;
    }
    static processFile(at, csvText, options) {
        const csvContent = CSVImport.parseCSV(csvText);
        if (csvContent && options && typeof options.importRowStartIndex === 'number')
            csvContent.splice(0, options.importRowStartIndex);
        if (!csvContent || csvContent.length === 0)
            return;
        const startRowIndex = CSVImport.getStartRowIndex(at.content.length, options);
        UpdateAllTableData.update(at, csvContent, startRowIndex);
    }
    static import(at, file, options) {
        const reader = new FileReader();
        reader.readAsText(file);
        reader.onload = (event) => { var _a; return CSVImport.processFile(at, (_a = event.target) === null || _a === void 0 ? void 0 : _a.result, options); };
    }
}
//# sourceMappingURL=CSVImport.js.map