import { PageButtonContainerElement } from '../../../../elements/pagination/pageButtons/pageButtonContainerElement';
import { FilterInputElement } from '../../../../elements/visibility/filterRows/input/filterInputElement';
import { FilterInputEvents } from '../../../../elements/visibility/filterRows/input/filterInputEvents';
import { FilterElements } from '../../../../elements/visibility/filterRows/filterElements';
import { CellElement } from '../../../../elements/cell/cellElement';
import { PaginationUtils } from '../../pagination/paginationUtils';
import { FilterViaWebWorkers } from './filterViaWebWorkers';
import { FilterViaTimeouts } from './filterViaTimeouts';
export class FilterInternalUtils {
    static finishFiltering(at) {
        if (at.pagination) {
            PageButtonContainerElement.repopulateButtons(at);
            PaginationUtils.displayRowsForDifferentButton(at, 1);
        }
    }
    static getFilterFunc(at) {
        const finish = FilterInternalUtils.finishFiltering.bind(this, at);
        return window.Worker
            ? FilterViaWebWorkers.execute.bind(this, finish, FilterViaWebWorkers.createWorkerBlobURL())
            : FilterViaTimeouts.execute.bind(this, finish);
    }
    static generateDefaultHeaderName(content, defaultColumnHeaderName) {
        var _a, _b, _c;
        if (defaultColumnHeaderName) {
            const headerExists = (_a = content[0]) === null || _a === void 0 ? void 0 : _a.find((headerName) => headerName === defaultColumnHeaderName);
            if (headerExists)
                return defaultColumnHeaderName;
        }
        return ((_b = content[0]) === null || _b === void 0 ? void 0 : _b[0]) !== undefined ? String((_c = content[0]) === null || _c === void 0 ? void 0 : _c[0]) : '';
    }
    static addConfig(at, userConfig) {
        var _a;
        var _b;
        const { placeholderTemplate, defaultColumnHeaderName } = userConfig;
        // other values are added later
        const internalConfig = {
            isCaseSensitive: false,
            placeholderTemplate,
            defaultColumnHeaderName: defaultColumnHeaderName || FilterInternalUtils.generateDefaultHeaderName(at.content),
        };
        (_a = (_b = at._visiblityInternal).filters) !== null && _a !== void 0 ? _a : (_b.filters = []);
        at._visiblityInternal.filters.push(internalConfig);
        return internalConfig;
    }
    // colElements are used to identify active column (not using name as columns can have same names)
    static assignElements(at, rowConfig) {
        var _a;
        const { content, _columnsDetails } = at;
        if (content.length === 0)
            return;
        if (rowConfig.defaultColumnHeaderName) {
            const columnIndex = content[0].findIndex((headerName) => headerName === rowConfig.defaultColumnHeaderName);
            rowConfig.elements = _columnsDetails[columnIndex === -1 ? 0 : columnIndex].elements;
            delete rowConfig.defaultColumnHeaderName;
            // please consider that in codesandbox - upon a second refresh - elements are not there which causes no elements to
            // be assigned to rowConfig.elements, this is caught by !config.elements in method below, but be careful on this
        }
        else if (rowConfig.elements && !((_a = at.shadowRoot) === null || _a === void 0 ? void 0 : _a.contains(rowConfig.elements[0]))) {
            rowConfig.elements = _columnsDetails[0].elements;
        }
    }
    // prettier-ignore
    static resetInput(at, config) {
        const { _visiblityInternal: { filters } } = at;
        FilterInternalUtils.assignElements(at, config);
        if (!config.elements || !filters)
            return;
        const headerName = CellElement.getText(config.elements[0]);
        config.lastRegisteredHeaderName = headerName;
        FilterInputElement.setPlaceholder(config.inputElement, headerName, config.placeholderTemplate);
        FilterInputEvents.setEvents(at, config, filters);
    }
    static unsetFilter(inputElement) {
        if (inputElement.value !== '') {
            inputElement.value = '';
            inputElement.dispatchEvent(new Event('input'));
        }
    }
    static unsetAllFilters(at) {
        var _a, _b;
        let reset = false;
        const { content, _visiblityInternal, _tableBodyElementRef } = at;
        if (content[0] && content[0].length !== 0 && _tableBodyElementRef) {
            (_a = _visiblityInternal.filters) === null || _a === void 0 ? void 0 : _a.forEach((rowConfig) => {
                if (rowConfig.inputElement.value !== '') {
                    rowConfig.inputElement.value = '';
                    reset = true;
                }
            });
            if (reset)
                (_b = _visiblityInternal.filters) === null || _b === void 0 ? void 0 : _b[0].inputElement.dispatchEvent(new Event('input'));
        }
        return reset;
    }
    // prettier-ignore
    static resetAllInputs(at) {
        const { content, _visiblityInternal: { filters } } = at;
        if (!content[0] || content[0].length === 0 || !filters)
            return FilterInputEvents.unsetEvents(filters);
        filters.forEach((config) => FilterInternalUtils.resetInput(at, config));
        FilterInternalUtils.unsetAllFilters(at);
    }
    static completeReset(at) {
        const internalFilters = at._visiblityInternal.filters;
        if (!internalFilters)
            return;
        if (Array.isArray(at.filter)) {
            at.filter.forEach((rowConfig, index) => {
                internalFilters[index].defaultColumnHeaderName = rowConfig.defaultColumnHeaderName;
            });
        }
        else if (typeof at.filter === 'object') {
            internalFilters[0].defaultColumnHeaderName = at.filter.defaultColumnHeaderName;
        }
        FilterInternalUtils.resetAllInputs(at);
    }
    static isContainerRequired(filter, containerPosition) {
        let isRequired = false;
        if (Array.isArray(filter)) {
            isRequired = !!filter.find((filterConfig) => {
                const index = (filterConfig.position || FilterElements.DEFAULT_INPUT_POSITION).indexOf(containerPosition);
                return index !== undefined && index >= 0;
            });
        }
        else if (typeof filter === 'object') {
            const index = (filter.position || FilterElements.DEFAULT_INPUT_POSITION).indexOf(containerPosition);
            isRequired = index !== undefined && index >= 0;
        }
        else if (typeof filter === 'boolean') {
            const index = FilterElements.DEFAULT_INPUT_POSITION.indexOf(containerPosition);
            isRequired = index !== undefined && index >= 0;
        }
        return isRequired;
    }
    static extractUnfilteredRows(tableBodyElement, contentLength) {
        const rows = Array.from(tableBodyElement.children);
        return rows.slice(0, contentLength).filter((row) => !row.classList.contains(FilterInternalUtils.HIDDEN_ROW_CLASS));
    }
    // prettier-ignore
    static wasHeaderChanged(columnsDetails, rowConfigs, columnIndex, colRemove) {
        const elements = columnsDetails[columnIndex].elements;
        const rowConfig = rowConfigs.find((rowConfig) => elements === rowConfig.elements);
        // if rowConfig is set - it means it was the currently edited column
        return rowConfig && (rowConfig.lastRegisteredHeaderName !== CellElement.getText(elements[0]) || colRemove);
    }
}
// IMPORTANT - only one instance of this variable exists for all components in the same browser window
FilterInternalUtils.ACTIVE_WORKERS = 0;
FilterInternalUtils.CHUNK_SIZE = 2;
FilterInternalUtils.HIDDEN_ROW_CLASS = 'filter-hidden-row';
//# sourceMappingURL=filterInternalUtils.js.map