import { FilterInternalUtils } from './filter/rows/filterInternalUtils';
import { FilesUtils } from './files/filesInternalUtils';
export class OuterContainerElements {
    // REF-38
    static getColumnContentContainer(column) {
        return column.children[0].children[0];
    }
    static setContainerHeightBasedOnMiddleColumn(container) {
        if (container.getBoundingClientRect().height === 0) {
            const contentContainer = OuterContainerElements.getColumnContentContainer(container.children[1]);
            container.style.height = `${contentContainer.getBoundingClientRect().height}px`;
        }
    }
    static setHeightsWhenOnlyMiddleColumns(containers) {
        setTimeout(() => {
            if (containers.top)
                OuterContainerElements.setContainerHeightBasedOnMiddleColumn(containers.top);
            if (containers.bottom)
                OuterContainerElements.setContainerHeightBasedOnMiddleColumn(containers.bottom);
        });
    }
    // REF-38
    static appendChildToColumn(column, child) {
        const contentContainer = OuterContainerElements.getColumnContentContainer(column);
        contentContainer.appendChild(child);
    }
    // REF-38
    static addToContainer(position, containers, element) {
        const container = (position.indexOf('top') >= 0 ? containers.top : containers.bottom);
        if (position.indexOf('left') >= 0) {
            OuterContainerElements.appendChildToColumn(container.children[0], element);
        }
        else if (position.indexOf('center') >= 0) {
            OuterContainerElements.appendChildToColumn(container.children[1], element);
        }
        else {
            OuterContainerElements.appendChildToColumn(container.children[2], element);
        }
    }
    // REF-38
    // need an inner divs in order for the inserted components 'width' properties to work as CONTAINER_CLASS has width: 0px
    static createContainerColumn(positionClass, columnNumber) {
        const column = document.createElement('div');
        column.classList.add(OuterContainerElements.COLUMN_CLASS, positionClass);
        const columnInnerContainer = document.createElement('div');
        columnInnerContainer.classList.add(OuterContainerElements.COLUMN_INNER_CLASS);
        const contentContainer = document.createElement('div');
        contentContainer.classList.add(OuterContainerElements.COLUMN_CONTENT_CLASS);
        columnInnerContainer.appendChild(contentContainer);
        column.appendChild(columnInnerContainer);
        column.style.gridColumn = columnNumber;
        return column;
    }
    static createContainerElement() {
        const container = document.createElement('div');
        container.classList.add(OuterContainerElements.CONTAINER_CLASS);
        const left = OuterContainerElements.createContainerColumn(OuterContainerElements.LEFT_COLUMN_CLASS, '1');
        container.appendChild(left);
        const center = OuterContainerElements.createContainerColumn(OuterContainerElements.CENTER_COLUMN_CLASS, '2');
        container.appendChild(center);
        const right = OuterContainerElements.createContainerColumn(OuterContainerElements.RIGHT_COLUMN_CLASS, '3');
        container.appendChild(right);
        return container;
    }
    static addContainer(parentEl, id, tableElement) {
        const container = OuterContainerElements.createContainerElement();
        container.id = id;
        if (tableElement === null || tableElement === void 0 ? void 0 : tableElement.style.fontFamily)
            container.style.fontFamily = tableElement.style.fontFamily; // REF-41
        const insertionLocation = id === OuterContainerElements.TOP_CONTAINER_ID ? 'beforebegin' : 'afterend';
        parentEl.insertAdjacentElement(insertionLocation, container);
        return container;
    }
    // can be reused for other positional components
    static isRequired(object, conPosition) {
        return !!Object.keys(object).find((componentName) => {
            const { position } = object[componentName];
            return position.indexOf(conPosition) >= 0;
        });
    }
    static isContainerRequired(at, containerPosition) {
        var _a;
        let isRequired = false;
        // checking client object as _pagination has default properties
        if (at.pagination) {
            isRequired = OuterContainerElements.isRequired(at._pagination.positions, containerPosition);
        }
        if (!isRequired && ((_a = at.files) === null || _a === void 0 ? void 0 : _a.buttons)) {
            isRequired = !!at.files.buttons.find((button) => {
                const position = button.position || FilesUtils.DEFAULT_BUTTON_POSITION;
                return position.indexOf(containerPosition) >= 0;
            });
        }
        if (!isRequired && at.filter)
            isRequired = FilterInternalUtils.isContainerRequired(at.filter, containerPosition);
        return isRequired;
    }
    // we create a top and a bottom container only if they are required
    static create(at) {
        var _a;
        const containers = {};
        const isTopRequired = OuterContainerElements.isContainerRequired(at, 'top');
        const isBottomRequired = OuterContainerElements.isContainerRequired(at, 'bottom');
        const { _tableElementRef: tableEl } = at;
        const parentEl = ((_a = at._overflow) === null || _a === void 0 ? void 0 : _a.overflowContainer) || tableEl;
        if (!parentEl)
            return containers;
        if (isTopRequired) {
            const container = OuterContainerElements.addContainer(parentEl, OuterContainerElements.TOP_CONTAINER_ID, tableEl);
            containers.top = container;
        }
        if (isBottomRequired) {
            const container = OuterContainerElements.addContainer(parentEl, OuterContainerElements.BOTTOM_CONTAINER_ID, tableEl);
            containers.bottom = container;
        }
        OuterContainerElements.setHeightsWhenOnlyMiddleColumns(containers);
        return containers;
    }
}
OuterContainerElements.CONTAINER_CLASS = 'outer-container';
OuterContainerElements.TOP_CONTAINER_ID = 'outer-top-container';
OuterContainerElements.BOTTOM_CONTAINER_ID = 'outer-bottom-container';
// REF-38
OuterContainerElements.COLUMN_CLASS = 'outer-container-column';
OuterContainerElements.COLUMN_INNER_CLASS = 'outer-container-column-inner';
OuterContainerElements.COLUMN_CONTENT_CLASS = 'outer-container-column-content';
OuterContainerElements.LEFT_COLUMN_CLASS = 'outer-container-left-column';
OuterContainerElements.CENTER_COLUMN_CLASS = 'outer-container-center-column';
OuterContainerElements.RIGHT_COLUMN_CLASS = 'outer-container-right-column';
//# sourceMappingURL=outerContainerElements.js.map