import { RowsPerPageDropdownItem } from '../../../elements/pagination/rowsPerPageSelect/dropdown/rowsPerPageDropdownItem';
import { PageButtonElement } from '../../../elements/pagination/pageButtons/pageButtonElement';
import { FilterInternalUtils } from '../filter/rows/filterInternalUtils';
export class PaginationInternalUtils {
    static getTotalNumberOfRows(at) {
        const { content, _visiblityInternal, _tableBodyElementRef } = at;
        return (_visiblityInternal === null || _visiblityInternal === void 0 ? void 0 : _visiblityInternal.filters)
            ? FilterInternalUtils.extractUnfilteredRows(_tableBodyElementRef, content.length).length
            : content.length;
    }
    static insertNewRowsPerPageOption(newRowsPerPageNumber, rowsPerPageOptionsItemText) {
        let insertionIndex = rowsPerPageOptionsItemText.findIndex((option) => {
            const optionNumber = Number.parseInt(option);
            return isNaN(optionNumber) || newRowsPerPageNumber < optionNumber;
        });
        if (insertionIndex === -1)
            insertionIndex = 0;
        rowsPerPageOptionsItemText.splice(insertionIndex, 0, String(newRowsPerPageNumber));
    }
    static setFirstOptionAsRowsPerPage(at) {
        const { _pagination, dataStartsAtHeader } = at;
        const firstItemText = _pagination.rowsPerPageOptionsItemText[0];
        if (firstItemText.toLocaleLowerCase() === RowsPerPageDropdownItem.ALL_ITEM_TEXT) {
            _pagination.isAllRowsOptionSelected = true;
            const totalNumberOfRows = PaginationInternalUtils.getTotalNumberOfRows(at);
            _pagination.rowsPerPage = dataStartsAtHeader ? totalNumberOfRows : totalNumberOfRows - 1;
        }
        else {
            _pagination.rowsPerPage = Number(firstItemText);
        }
    }
    static processRowsPerPage(at, pagination) {
        const { rowsPerPageSelect } = pagination;
        // the user might set rowsPerPage as string (even if we need type) so this makes sure its a string
        at._pagination.rowsPerPage = Number.parseInt(String(at._pagination.rowsPerPage));
        if (rowsPerPageSelect || rowsPerPageSelect === undefined) {
            const { rowsPerPageOptionsItemText, rowsPerPage } = at._pagination;
            if (!rowsPerPageOptionsItemText.find((value) => value === String(rowsPerPage))) {
                const rowsPerPageNumber = Number.parseInt(String(rowsPerPage));
                if (isNaN(rowsPerPageNumber)) {
                    PaginationInternalUtils.setFirstOptionAsRowsPerPage(at);
                }
                else {
                    PaginationInternalUtils.insertNewRowsPerPageOption(rowsPerPageNumber, rowsPerPageOptionsItemText);
                }
            }
        }
    }
    static processOptionsItemText(userNumber) {
        const number = Number(userNumber);
        if (!isNaN(number) && number < 1)
            return '2';
        return String(userNumber);
    }
    // REF-32
    static changeOptionNumberToEven(options) {
        return options.map((option) => {
            const number = Number(option);
            if (Number.isNaN(number))
                return option;
            return number % 2 === 1 ? number + 1 : number;
        });
    }
    // prettier-ignore
    static setRowsPerPageOptionsText(at) {
        const pagination = at.pagination;
        const { rowsPerPageSelect } = pagination;
        if (rowsPerPageSelect || rowsPerPageSelect === undefined) {
            const defaultOptions = at._pagination.rowsPerPageSelect.options;
            let options = (rowsPerPageSelect === undefined || rowsPerPageSelect === true
                || !rowsPerPageSelect.options || rowsPerPageSelect.options.length === 0
                ? defaultOptions : rowsPerPageSelect.options);
            if (at.stripedRows)
                options = PaginationInternalUtils.changeOptionNumberToEven(options);
            at._pagination.rowsPerPageOptionsItemText = options
                .map((option) => PaginationInternalUtils.processOptionsItemText(option));
        }
    }
    static processRowsPerPageOptions(at) {
        const pagination = at.pagination;
        const { rowsPerPageSelect } = pagination;
        if (rowsPerPageSelect !== undefined && typeof rowsPerPageSelect !== 'boolean' && rowsPerPageSelect.prefixText) {
            at._pagination.rowsPerPageSelect.prefixText = rowsPerPageSelect.prefixText;
        }
        PaginationInternalUtils.setRowsPerPageOptionsText(at);
        delete pagination.rowsPerPageSelect;
    }
    static setDefaultBackgroundColors(style, defaultBackgrounds) {
        var _a, _b, _c;
        var _d, _e, _f;
        // if default backgroundColor is set, then setStatefulCSS has used it for all already
        const { def, hover, click } = defaultBackgrounds;
        (_a = (_d = style.click).backgroundColor) !== null && _a !== void 0 ? _a : (_d.backgroundColor = style.hover.backgroundColor || style.default.backgroundColor || click);
        (_b = (_e = style.hover).backgroundColor) !== null && _b !== void 0 ? _b : (_e.backgroundColor = style.default.backgroundColor || hover);
        (_c = (_f = style.default).backgroundColor) !== null && _c !== void 0 ? _c : (_f.backgroundColor = def);
        ['click', 'hover', 'default'].forEach((key) => {
            style[key].backgroundColor === undefined ? delete style[key].backgroundColor : {};
        });
    }
    static setStatefulCSS(style, elementType) {
        var _a, _b, _c, _d;
        var _e, _f, _g;
        (_a = style[elementType]) !== null && _a !== void 0 ? _a : (style[elementType] = {});
        // deep copy to allow setDefaultBackgroundColor to overwrite objects
        (_b = (_e = style[elementType]).click) !== null && _b !== void 0 ? _b : (_e.click = JSON.parse(JSON.stringify(style[elementType].hover || style[elementType].default || {})));
        (_c = (_f = style[elementType]).hover) !== null && _c !== void 0 ? _c : (_f.hover = JSON.parse(JSON.stringify(style[elementType].default || {})));
        (_d = (_g = style[elementType]).default) !== null && _d !== void 0 ? _d : (_g.default = {});
    }
    // prettier-ignore
    static setRowsPerPageOptionsStyle(style) {
        var _a;
        PaginationInternalUtils.setStatefulCSS(style.rowsPerPageSelect, 'button');
        const defButtonsBackgroundColors = { def: '', hover: '#f5f5f5', click: '#f5f5f5' };
        PaginationInternalUtils.setDefaultBackgroundColors((_a = style.rowsPerPageSelect) === null || _a === void 0 ? void 0 : _a.button, defButtonsBackgroundColors);
    }
    // activeButtons reuse buttons style
    static mergeButtonsStyleWithActiveStyle(statefulStyle) {
        const { buttons, actionButtons, activeButton } = statefulStyle;
        const buttonsClone = JSON.parse(JSON.stringify(buttons));
        buttonsClone.default.backgroundColor = '#e8e8e8';
        buttonsClone.hover.backgroundColor = '#d6d6d6';
        buttonsClone.click.backgroundColor = '#c8c8c8';
        if (activeButton) {
            Object.assign(buttonsClone.default, activeButton.default);
            buttonsClone.hover = activeButton.hover;
            buttonsClone.click = activeButton.click;
        }
        return buttonsClone;
    }
    // actionButtons reuse buttons style
    static mergeButtonsStylesWithActionStyles(pageButtonsStyles) {
        var _a;
        var _b;
        (_a = (_b = pageButtonsStyles).actionButtons) !== null && _a !== void 0 ? _a : (_b.actionButtons = {});
        const { buttons, actionButtons } = pageButtonsStyles;
        // structuredClone does not seem to work properly
        const buttonsClone = JSON.parse(JSON.stringify(buttons));
        Object.assign(buttonsClone.default, actionButtons.default);
        Object.assign(buttonsClone.hover, actionButtons.hover);
        Object.assign(buttonsClone.click, actionButtons.click);
        buttonsClone.previousText = actionButtons.previousText;
        buttonsClone.nextText = actionButtons.nextText;
        buttonsClone.firstText = actionButtons.firstText;
        buttonsClone.lastText = actionButtons.lastText;
        return buttonsClone;
    }
    // prettier-ignore
    static processPageButtonStyles(pagination) {
        var _a, _b, _c, _d;
        var _e, _f, _g;
        (_a = pagination.styles.pageButtons) !== null && _a !== void 0 ? _a : (pagination.styles.pageButtons = {});
        const statefulStyle = pagination.styles.pageButtons;
        // buttons
        const defButtonsBackgroundColors = { def: 'white', hover: '#f5f5f5', click: '#c8c8c8' };
        PaginationInternalUtils.setStatefulCSS(statefulStyle, 'buttons');
        PaginationInternalUtils.setDefaultBackgroundColors(pagination.styles.pageButtons.buttons, defButtonsBackgroundColors);
        // actionButtons
        PaginationInternalUtils.setStatefulCSS(statefulStyle, 'actionButtons');
        PaginationInternalUtils.setDefaultBackgroundColors(pagination.styles.pageButtons.actionButtons, {});
        const newActionButtons = PaginationInternalUtils.mergeButtonsStylesWithActionStyles(statefulStyle);
        pagination.styles.pageButtons.actionButtons = newActionButtons;
        // activeButton
        const newActiveButtons = PaginationInternalUtils.mergeButtonsStyleWithActiveStyle(statefulStyle);
        pagination.styles.pageButtons.activeButton = newActiveButtons;
        // disabledButtons - this inherits the 'buttons' style when using the PageButtonStyle.setDisabled method
        (_b = (_e = pagination.styles.pageButtons).disabledButtons) !== null && _b !== void 0 ? _b : (_e.disabledButtons = { backgroundColor: '#f9f9f9', color: '#9d9d9d', stroke: '#9d9d9d' });
        // first overrides
        const defFirstVisibleOverride = {
            borderLeft: '1px solid #0000004d', borderTopLeftRadius: '2px', borderBottomLeftRadius: '2px'
        };
        (_c = (_f = pagination.styles.pageButtons).firstVisibleButtonOverride) !== null && _c !== void 0 ? _c : (_f.firstVisibleButtonOverride = defFirstVisibleOverride);
        // last overrides
        const defLastVisibleOverride = {
            borderRight: '1px solid #0000004d', borderTopRightRadius: '2px', borderBottomRightRadius: '2px'
        };
        (_d = (_g = pagination.styles.pageButtons).lastVisibleButtonOverride) !== null && _d !== void 0 ? _d : (_g.lastVisibleButtonOverride = defLastVisibleOverride);
        // active style
        pagination.styles.pageButtons.activeButtonClass = pagination.styles.pageButtons.activeButtonPrecedence
            ? PageButtonElement.PRECEDENCE_ACTIVE_PAGINATION_BUTTON_CLASS : PageButtonElement.ACTIVE_PAGINATION_BUTTON_CLASS;
    }
    static processStyle(pagination, paginationInternal) {
        var _a, _b;
        var _c, _d;
        if (pagination.styles)
            Object.assign(paginationInternal.styles, pagination.styles);
        PaginationInternalUtils.processPageButtonStyles(paginationInternal);
        if (pagination.rowsPerPageSelect !== false) {
            (_a = (_c = paginationInternal.styles).rowsPerPageSelect) !== null && _a !== void 0 ? _a : (_c.rowsPerPageSelect = {});
            PaginationInternalUtils.setRowsPerPageOptionsStyle(paginationInternal.styles);
        }
        (_b = (_d = paginationInternal.styles).numberOfVisibleRows) !== null && _b !== void 0 ? _b : (_d.numberOfVisibleRows = {});
        delete pagination.styles; // deleted so that Object.assign wouldn't apply it
    }
    static processPositions(positions) {
        Object.keys(positions).forEach((componentName) => {
            const component = positions[componentName];
            if (!PaginationInternalUtils.POSITIONS.has(component.position))
                component.position = PaginationInternalUtils.DEFAULT_POSITION;
        });
    }
    static processPosition(pagination, paginationInternal) {
        if (pagination.positions)
            Object.assign(paginationInternal.positions, pagination.positions);
        PaginationInternalUtils.processPositions(paginationInternal.positions);
        delete pagination.positions; // deleted so that Object.assign wouldn't apply it
    }
    static process(at) {
        const { _pagination } = at;
        if (!at.pagination)
            return;
        const pagination = typeof at.pagination === 'boolean' ? {} : at.pagination;
        if (pagination.maxNumberOfVisiblePageButtons !== undefined && pagination.maxNumberOfVisiblePageButtons < 1) {
            pagination.maxNumberOfVisiblePageButtons = 1;
        }
        PaginationInternalUtils.processPosition(pagination, _pagination);
        PaginationInternalUtils.processStyle(pagination, _pagination);
        if (pagination.rowsPerPageSelect !== false)
            PaginationInternalUtils.processRowsPerPageOptions(at);
        Object.assign(_pagination, pagination);
        if (pagination.displayNumberOfVisibleRows !== false)
            PaginationInternalUtils.processRowsPerPage(at, pagination);
    }
    static getDefault() {
        return {
            rowsPerPage: 10,
            rowsPerPageSelect: {
                options: [10, 25, 50, 'All'],
                prefixText: 'Rows per page:',
            },
            maxNumberOfVisiblePageButtons: 8,
            displayPrevNext: true,
            displayFirstLast: true,
            displayNumberOfVisibleRows: true,
            styles: {},
            visibleEdgeButtons: [],
            numberOfActionButtons: 0,
            dropdownWidth: 24,
            positions: {
                pageButtons: {
                    position: PaginationInternalUtils.DEFAULT_POSITION,
                    order: 3,
                },
                numberOfVisibleRows: {
                    position: PaginationInternalUtils.DEFAULT_POSITION,
                    order: 2,
                },
                rowsPerPageSelect: {
                    position: PaginationInternalUtils.DEFAULT_POSITION,
                    order: 1,
                },
            },
            visibleRows: [],
            activePageNumber: 1,
            isAllRowsOptionSelected: false,
        };
    }
}
PaginationInternalUtils.DEFAULT_POSITION = 'bottom-right';
// prettier-ignore
PaginationInternalUtils.POSITIONS = new Set([
    'top-left', 'top-center', 'top-right', 'bottom-left', 'bottom-center', PaginationInternalUtils.DEFAULT_POSITION,
]);
//# sourceMappingURL=paginationInternalUtils.js.map