import { PageButtonElement } from '../../../elements/pagination/pageButtons/pageButtonElement';
import { PageButtonStyle } from '../../../elements/pagination/pageButtons/pageButtonStyle';
import { PaginationUtils } from './paginationUtils';
export class PaginationPageActionButtonUtils {
    static setButtonAsEnabled(button, pageButtonStyles) {
        PageButtonStyle.setDefault(button, pageButtonStyles, true);
        button.classList.remove(PageButtonElement.DISABLED_PAGINATION_BUTTON_CLASS);
    }
    static setButtonAsDisabled(button, pageButtonStyles) {
        PageButtonStyle.setDisabled(button, pageButtonStyles, true);
        button.classList.add(PageButtonElement.DISABLED_PAGINATION_BUTTON_CLASS);
    }
    // prettier-ignore
    static toggleRightButtons(at, buttons, halfOfActionButtons) {
        const { activePageNumber, styles } = at._pagination;
        const lastPageNumber = PaginationUtils.getLastPossiblePageNumber(at);
        const callback = activePageNumber === lastPageNumber
            ? PaginationPageActionButtonUtils.setButtonAsDisabled : PaginationPageActionButtonUtils.setButtonAsEnabled;
        const rightActionButtons = buttons.slice(buttons.length - halfOfActionButtons);
        rightActionButtons.forEach((button) => callback(button, styles.pageButtons));
    }
    // prettier-ignore
    static toggleLeftButtons(buttons, activePageNumber, halfOfActionButtons, paginationStyle) {
        const callback = activePageNumber === 1
            ? PaginationPageActionButtonUtils.setButtonAsDisabled : PaginationPageActionButtonUtils.setButtonAsEnabled;
        const leftActionButtons = buttons.slice(0, halfOfActionButtons);
        leftActionButtons.forEach((button) => callback(button, paginationStyle.pageButtons));
    }
    static toggleActionButtons(at) {
        const { activePageNumber, styles, numberOfActionButtons, buttonContainer } = at._pagination;
        const buttons = Array.from(buttonContainer.children);
        const halfOfActionButtons = numberOfActionButtons / 2;
        PaginationPageActionButtonUtils.toggleLeftButtons(buttons, activePageNumber, halfOfActionButtons, styles);
        PaginationPageActionButtonUtils.toggleRightButtons(at, buttons, halfOfActionButtons);
    }
}
//# sourceMappingURL=paginationPageActionButtonUtils.js.map