export class PaginationRowIndexes {
    static getVisibleRowRealIndex(tableBody, pagination, index) {
        const rows = Array.from(tableBody.children);
        const rowIndex = index === undefined ? pagination.visibleRows.length - 1 : index;
        const visibleRow = pagination.visibleRows[rowIndex];
        return rows.findIndex((row) => row === visibleRow);
    }
    static getVisibleRowIndex(tableBody, pagination, index) {
        const currentElement = tableBody.children[index];
        return pagination.visibleRows.findIndex((row) => row === currentElement);
    }
    static getFilteredMaxVisibleRowIndex(tableBodyElement, pagination) {
        const { rowsPerPage, visibleRows } = pagination;
        const rowIndex = PaginationRowIndexes.getVisibleRowRealIndex(tableBodyElement, pagination);
        if (visibleRows.length === rowsPerPage)
            return rowIndex;
        return rowIndex + (rowsPerPage - visibleRows.length);
    }
    static getRawMaxVisibleRowIndex(at) {
        const { _pagination, _tableBodyElementRef, content, _visiblityInternal } = at;
        const { activePageNumber, rowsPerPage, isAllRowsOptionSelected } = _pagination;
        if (isAllRowsOptionSelected) {
            return content.length + 1;
        }
        if (_visiblityInternal.filters) {
            return PaginationRowIndexes.getFilteredMaxVisibleRowIndex(_tableBodyElementRef, _pagination);
        }
        return activePageNumber * rowsPerPage;
    }
    static getMaxVisibleRowIndex(at) {
        const { dataStartsAtHeader } = at;
        let maxVisibleRowIndex = PaginationRowIndexes.getRawMaxVisibleRowIndex(at);
        if (!dataStartsAtHeader)
            maxVisibleRowIndex += 1;
        return maxVisibleRowIndex;
    }
}
//# sourceMappingURL=paginationRowIndexes.js.map