import { PageButtonElement } from '../../../elements/pagination/pageButtons/pageButtonElement';
import { RowElement } from '../../../elements/table/addNewElements/row/rowElement';
import { ElementStyle } from '../../elements/elementStyle';
// this is used for overriding first and last visible button styling
export class PaginationVisibleButtonsUtils {
    static getRightBorderWidthInStyleOverride(lastOverrideStyle) {
        if (lastOverrideStyle.borderRightWidth) {
            return Number.parseInt(lastOverrideStyle.borderRightWidth);
        }
        if (lastOverrideStyle.borderRight) {
            return Number.parseInt(lastOverrideStyle.borderRight.split(' ')[0]);
        }
        return -1;
    }
    // if the last button is active page (no action buttons displayed) and it has precedence, the override right border
    // will not take place and it will either have no right border or active style right border:
    // this is problematic as the border difference will cause the entire container to have a different width
    // which will in turn cause the pagination components to shift when the last button is clicked,
    // to prevent this we add the border style that would have been overriden
    static setBorderPaddingForLastPrecedence(buttonElement, lastOverrideStyle) {
        const overwrittenWidth = PaginationVisibleButtonsUtils.getRightBorderWidthInStyleOverride(lastOverrideStyle);
        if (isNaN(overwrittenWidth) || overwrittenWidth === 0)
            return;
        const currentBorderWidth = Number.parseInt(getComputedStyle(buttonElement).borderRightWidth);
        if (currentBorderWidth > 0) {
            // if active style border is used we add to it
            buttonElement.style.borderRightWidth = `${currentBorderWidth + overwrittenWidth}px`;
        }
        else {
            // if no right border is used then we add a transparent border
            buttonElement.style.borderRight = `${overwrittenWidth}px solid #fafafa01`;
        }
    }
    static setStyle(buttonElement, precedenceValues, isLast, edgeStyle) {
        if (!edgeStyle)
            return;
        const styleKeys = new Set(Object.keys(edgeStyle));
        const isPrecedence = buttonElement.classList.contains(PageButtonElement.PRECEDENCE_ACTIVE_PAGINATION_BUTTON_CLASS);
        if (isPrecedence)
            precedenceValues.forEach((value) => styleKeys.delete(value));
        styleKeys.forEach((key) => {
            ElementStyle.setStyle(buttonElement, key, edgeStyle[key]);
        });
        if (isLast && isPrecedence) {
            PaginationVisibleButtonsUtils.setBorderPaddingForLastPrecedence(buttonElement, edgeStyle);
        }
    }
    // prettier-ignore
    static overrideOnMouseEvent(buttonElement, pageButtonsStyles) {
        const { firstVisibleButtonOverride, lastVisibleButtonOverride } = pageButtonsStyles;
        if (buttonElement.classList.contains(PaginationVisibleButtonsUtils.FIRST_VISIBLE_CLASS)) {
            PaginationVisibleButtonsUtils.setStyle(buttonElement, PaginationVisibleButtonsUtils.FIRST_PRECEDENCE_VALUES, false, firstVisibleButtonOverride);
        }
        if (buttonElement.classList.contains(PaginationVisibleButtonsUtils.LAST_VISIBLE_CLASS)) {
            PaginationVisibleButtonsUtils.setStyle(buttonElement, PaginationVisibleButtonsUtils.LAST_PRECEDENCE_VALUES, true, lastVisibleButtonOverride);
        }
    }
    // prettier-ignore
    static unsetStateAndStyles(pagination) {
        const { styles: { pageButtons: { firstVisibleButtonOverride, lastVisibleButtonOverride } }, visibleEdgeButtons } = pagination;
        if (visibleEdgeButtons.length === 0)
            return;
        if (firstVisibleButtonOverride)
            ElementStyle.unsetStyle(visibleEdgeButtons[0], firstVisibleButtonOverride);
        visibleEdgeButtons[0].classList.remove(PaginationVisibleButtonsUtils.FIRST_VISIBLE_CLASS);
        if (lastVisibleButtonOverride)
            ElementStyle.unsetStyle(visibleEdgeButtons[1], lastVisibleButtonOverride);
        visibleEdgeButtons[1].classList.remove(PaginationVisibleButtonsUtils.LAST_VISIBLE_CLASS);
        pagination.visibleEdgeButtons = [];
    }
    // when the button display property is false - clientWidth is 0
    static isButtonVisible(buttonElement) {
        return buttonElement.clientWidth > 0 && buttonElement.style.visibility !== 'hidden';
    }
    // prettier-ignore
    static set(buttons, firstVisibleIndex, pagination) {
        const { styles: { pageButtons: { firstVisibleButtonOverride, lastVisibleButtonOverride } } } = pagination;
        const firstVisibleButton = buttons[firstVisibleIndex];
        if (!firstVisibleButton)
            return;
        if (!firstVisibleButton.classList.contains(PaginationVisibleButtonsUtils.FIRST_VISIBLE_CLASS)) {
            PaginationVisibleButtonsUtils.setStyle(firstVisibleButton, PaginationVisibleButtonsUtils.FIRST_PRECEDENCE_VALUES, false, firstVisibleButtonOverride);
            firstVisibleButton.classList.add(PaginationVisibleButtonsUtils.FIRST_VISIBLE_CLASS);
        }
        const lastVisibleIndex = buttons.findLastIndex(PaginationVisibleButtonsUtils.isButtonVisible);
        const lastVisibleButton = buttons[lastVisibleIndex];
        if (!lastVisibleButton.classList.contains(PaginationVisibleButtonsUtils.LAST_VISIBLE_CLASS)) {
            PaginationVisibleButtonsUtils.setStyle(lastVisibleButton, PaginationVisibleButtonsUtils.LAST_PRECEDENCE_VALUES, true, lastVisibleButtonOverride);
            lastVisibleButton.classList.add(PaginationVisibleButtonsUtils.LAST_VISIBLE_CLASS);
        }
        pagination.visibleEdgeButtons = [firstVisibleButton, lastVisibleButton];
    }
    static setStateAndStyles(at) {
        const { _pagination, displayAddNewRow } = at;
        const buttons = Array.from(_pagination.buttonContainer.children);
        const firstVisibleIndex = buttons.findIndex(PaginationVisibleButtonsUtils.isButtonVisible);
        if (firstVisibleIndex === -1) {
            // when triggered on initial render where buttons have yet not been generated
            setTimeout(() => {
                const firstVisibleIndex = buttons.findIndex(PaginationVisibleButtonsUtils.isButtonVisible);
                PaginationVisibleButtonsUtils.set(buttons, firstVisibleIndex, _pagination);
            });
        }
        else {
            PaginationVisibleButtonsUtils.set(buttons, firstVisibleIndex, _pagination);
        }
        if (!displayAddNewRow)
            RowElement.toggleLastRowClass(at);
    }
}
PaginationVisibleButtonsUtils.FIRST_VISIBLE_CLASS = 'pagination-first-visible-button';
PaginationVisibleButtonsUtils.LAST_VISIBLE_CLASS = 'pagination-last-visible-button';
PaginationVisibleButtonsUtils.FIRST_PRECEDENCE_VALUES = ['borderLeft', 'borderLeftWidth', 'borderLeftColor'];
PaginationVisibleButtonsUtils.LAST_PRECEDENCE_VALUES = ['borderRight', 'borderRightWidth', 'borderRightColor'];
//# sourceMappingURL=paginationVisibleButtonsUtils.js.map