import { StringDimensionUtils } from '../tableDimensions/stringDimensionUtils';
import { TableElement } from '../../elements/table/tableElement';
import { ElementStyle } from '../elements/elementStyle';
import { Browser } from '../browser/browser';
export class OverflowUtils {
    static isOverflowElement(element) {
        return (element === null || element === void 0 ? void 0 : element.id) === OverflowUtils.ID;
    }
    // a simple way to not take the border into consideration when doing table width calculation, however if there are issues
    // feel free to investigate a better way
    static unsetBorderDimensions(tableDimensions, numberDimension) {
        numberDimension.number -= tableDimensions.border.leftWidth + tableDimensions.border.rightWidth;
        TableElement.changeStaticWidthTotal(tableDimensions, -tableDimensions.border.leftWidth);
        TableElement.changeStaticWidthTotal(tableDimensions, -tableDimensions.border.rightWidth);
        tableDimensions.border.leftWidth = 0;
        tableDimensions.border.rightWidth = 0;
        tableDimensions.border.topWidth = 0;
        tableDimensions.border.bottomWidth = 0;
    }
    static processNumberDimension(tableDimensions, numberDimension) {
        OverflowUtils.unsetBorderDimensions(tableDimensions, numberDimension);
        numberDimension.number -= OverflowUtils.SCROLLBAR_WIDTH;
    }
    // prettier-ignore
    static moveBorderToOverflowContainer(overflowContainer, tableElement) {
        ElementStyle.moveStyles(tableElement, overflowContainer, 'borderRight', 'borderLeft', 'borderTop', 'borderBottom', 'borderRadius', 'borderTopLeftRadius', 'borderTopRightRadius', 'borderBottomLeftRadius', 'borderBottomRightRadius');
        tableElement.style.border = 'unset';
    }
    static adjustStyleForScrollbarWidth(overflow) {
        if (Browser.IS_SAFARI || Browser.IS_FIREFOX) {
            if (overflow.maxHeight && !overflow.maxWidth) {
                // this is used to not create a horizontal scroll
                overflow.overflowContainer.style.paddingRight = `${OverflowUtils.SCROLLBAR_WIDTH}px`;
            }
        }
    }
    static setDimensions(overflowContainer, { width, height }) {
        if (width) {
            overflowContainer.style.overflowX = 'auto';
            overflowContainer.style.maxWidth = `${width}px`;
        }
        if (height) {
            overflowContainer.style.overflowY = 'auto';
            overflowContainer.style.maxHeight = `${height}px`;
        }
    }
    // prettier-ignore
    static getDimensions(at, overflow) {
        const widthResult = StringDimensionUtils.generateNumberDimensionFromClientString(at.parentElement, overflow, 'maxWidth', true);
        widthResult.number -= at._tableDimensions.border.leftWidth + at._tableDimensions.border.rightWidth;
        if (widthResult.isPercentage)
            overflow.isWidthPercentage = true;
        // if heightResult is 0 for a %, the likelyhood is that the parent element does not have height set
        const heightResult = StringDimensionUtils.generateNumberDimensionFromClientString(at.parentElement, overflow, 'maxHeight', false);
        heightResult.number -= at._tableDimensions.border.topWidth + at._tableDimensions.border.bottomWidth;
        if (heightResult.isPercentage)
            overflow.isHeightPercentage = true;
        return { width: widthResult.number, height: heightResult.number };
    }
    static applyDimensions(at) {
        const { _overflow } = at;
        if (!_overflow)
            return;
        const dimensions = OverflowUtils.getDimensions(at, _overflow);
        OverflowUtils.setDimensions(_overflow.overflowContainer, dimensions);
        OverflowUtils.adjustStyleForScrollbarWidth(_overflow);
    }
    static setupContainer(at, tableElement) {
        const overflowContainer = document.createElement('div');
        at._overflow = { overflowContainer, ...at.overflow };
        overflowContainer.id = OverflowUtils.ID;
        OverflowUtils.moveBorderToOverflowContainer(overflowContainer, tableElement);
        overflowContainer.appendChild(tableElement);
    }
}
OverflowUtils.ID = 'overflow-container';
OverflowUtils.SCROLLBAR_WIDTH = 15;
//# sourceMappingURL=overflowUtils.js.map