import { InsertNewColumn } from '../insertRemoveStructure/insert/insertNewColumn';
import { CellDropdown } from '../../elements/dropdown/cellDropdown/cellDropdown';
import { InsertNewRow } from '../insertRemoveStructure/insert/insertNewRow';
import { FocusedCellUtils } from '../focusedElements/focusedCellUtils';
import { DataUtils } from '../insertRemoveStructure/shared/dataUtils';
import { ColumnTypesUtils } from '../columnType/columnTypesUtils';
import { CaretPosition } from '../focusedElements/caretPosition';
import { CellElementIndex } from '../elements/cellElementIndex';
import { CellElement } from '../../elements/cell/cellElement';
import { CellEvents } from '../../elements/cell/cellEvents';
import { HeaderText } from '../columnDetails/headerText';
import { FireEvents } from '../events/fireEvents';
import { EMPTY_STRING } from '../../consts/text';
import { ArrayUtils } from '../array/arrayUtils';
export class InsertMatrix {
    // prettier-ignore
    static removeDataThatIsNotEditableFromNewRows(columnsDetails, dataForNewRows, startColumnIndex) {
        const existingColumnsToCheck = columnsDetails.slice(startColumnIndex);
        existingColumnsToCheck.forEach((columnDetails, colIndex) => {
            if (!columnDetails.settings.isCellTextEditable) {
                dataForNewRows.forEach((dataRow) => { dataRow[colIndex] = EMPTY_STRING; });
            }
        });
        return dataForNewRows;
    }
    // if the data does not fill the 2D array, fill cells with empty strings
    static createRowDataArrayWithEmptyCells(arrayLength, data, dataStartIndex) {
        const newRowData = DataUtils.createEmptyStringDataArray(arrayLength);
        newRowData.splice(dataStartIndex, data.length, ...data);
        return newRowData;
    }
    // prettier-ignore
    static createNewRows(at, dataForNewRows, startColumnIndex) {
        const processedDataForNewRows = InsertMatrix.removeDataThatIsNotEditableFromNewRows(at._columnsDetails, dataForNewRows, startColumnIndex);
        processedDataForNewRows.forEach((rowData) => {
            var _a;
            const newRowData = InsertMatrix.createRowDataArrayWithEmptyCells(((_a = at.content[0]) === null || _a === void 0 ? void 0 : _a.length) || 0, rowData, startColumnIndex);
            InsertNewRow.insert(at, at.content.length, true, newRowData);
        });
    }
    static changeColumnSettings(at, columnIndex) {
        const { elements } = at._columnsDetails[columnIndex];
        FocusedCellUtils.set(at._focusedElements.cell, elements[0], 0, columnIndex);
        HeaderText.onAttemptChange(at, elements[0], columnIndex);
    }
    static processNewColumn(at) {
        const lastColumnIndex = at._columnsDetails.length - 1;
        CellEvents.setCellToDefaultIfNeeded(at, 0, lastColumnIndex, at._columnsDetails[lastColumnIndex].elements[0], false);
        InsertMatrix.changeColumnSettings(at, lastColumnIndex);
    }
    // prettier-ignore
    static createNewColumns(at, dataForNewColumnsByRow, startRowIndex) {
        const dataForNewColumnsByColumn = ArrayUtils.transpose(dataForNewColumnsByRow);
        dataForNewColumnsByColumn.forEach((columnData) => {
            const newColumnData = InsertMatrix.createRowDataArrayWithEmptyCells(at.content.length, columnData, startRowIndex);
            InsertNewColumn.insert(at, at.content[0].length, newColumnData);
            InsertMatrix.processNewColumn(at);
        });
    }
    // prettier-ignore
    static overwriteCell(at, rowElement, rowIndex, columnIndex, newCellText) {
        const { _frameComponents: { displayIndexColumn }, _columnsDetails } = at;
        const elementIndex = CellElementIndex.getViaColumnIndex(columnIndex, !!displayIndexColumn);
        const cellElement = rowElement.children[elementIndex];
        const columnDetails = _columnsDetails[columnIndex];
        if ((rowIndex === 0 && !columnDetails.settings.isHeaderTextEditable)
            || rowIndex > 0 && !columnDetails.settings.isCellTextEditable)
            return;
        // this is to allow duplicate headers to be identified
        if (rowIndex === 0)
            CellElement.setNewText(at, cellElement, newCellText, false, false);
        CellEvents.updateCell(at, newCellText, rowIndex, columnIndex, { element: cellElement, updateTableEvent: false });
        ColumnTypesUtils.updateDataElements(at, rowIndex, columnIndex, cellElement);
        if (rowIndex === 0)
            InsertMatrix.changeColumnSettings(at, columnIndex);
    }
    // prettier-ignore
    static overwriteRowData(at, row, rowIndex, columnIndex, rowElement) {
        row.forEach((cellText, rowColIndex) => {
            const relativeColumnIndex = columnIndex + rowColIndex;
            InsertMatrix.overwriteCell(at, rowElement, rowIndex, relativeColumnIndex, cellText);
        });
    }
    // prettier-ignore
    static setCaretToEndAndHighlightIfSelect(at, cellElement, columnIndex) {
        const { activeType, cellDropdown, settings: { defaultText } } = at._columnsDetails[columnIndex];
        CaretPosition.setToEndOfText(at, cellElement);
        if (activeType.cellDropdownProps) {
            CellDropdown.updateCellDropdown(cellElement, cellDropdown, at._tableDimensions.border, defaultText, true);
        }
    }
    // prettier-ignore
    static overwriteExistingCells(at, dataToOverwriteRows, startRowIndex, startColumnIndex) {
        const dataForNewColumns = [];
        dataToOverwriteRows.forEach((dataToOverwriteRow, colIndex) => {
            var _a;
            const relativeRowIndex = startRowIndex + colIndex;
            const rowElement = (_a = at._tableBodyElementRef) === null || _a === void 0 ? void 0 : _a.children[relativeRowIndex];
            const numberOfCellsToOverwrite = at.content[0].length - startColumnIndex;
            const overwriteData = dataToOverwriteRow.slice(0, numberOfCellsToOverwrite);
            InsertMatrix.overwriteRowData(at, overwriteData, relativeRowIndex, startColumnIndex, rowElement);
            const overflowData = dataToOverwriteRow.slice(numberOfCellsToOverwrite);
            dataForNewColumns.push(overflowData);
        });
        const focusedElement = at._focusedElements.cell.element; // REF-15
        setTimeout(() => InsertMatrix.setCaretToEndAndHighlightIfSelect(at, focusedElement, startColumnIndex));
        return dataForNewColumns;
    }
    // no new rows should be created if no columns that are to be overwritten/created allow text edit
    static canNewRowsBeCreated(at, matrix, startColumnIndex) {
        return at._columnsDetails
            .slice(startColumnIndex, startColumnIndex + matrix[0].length)
            .find((columnDetails) => columnDetails.settings.isCellTextEditable);
    }
    static insertColumnsInsideIfCantInsertRight(at, matrix, startColumnIndex) {
        const columnsToBeOverwritten = at._columnsDetails.slice(startColumnIndex);
        const indexOfNoRightInsertionColumn = columnsToBeOverwritten.findIndex((columnDetails) => {
            return columnDetails.settings.columnDropdown.isInsertRightAvailable === false;
        });
        // if can insert right for all proceeding, no need to augment matrix or table
        if (indexOfNoRightInsertionColumn === -1)
            return;
        if (indexOfNoRightInsertionColumn === 0) {
            // if the currently pasted on column does not allow right insertion, only overwrite the existing column's cells
            // this augments the matrix object to contain data for the first column
            matrix.forEach((row) => row.splice(1, row.length - 1));
        }
        else {
            // insert new columns before the column that has no right insertion and also overwrite that column's cells
            const numberOfColumnsToBeInserted = matrix[0].length - (indexOfNoRightInsertionColumn + 1);
            for (let i = 0; i < numberOfColumnsToBeInserted; i += 1) {
                // + i to set the columnDropdownCellOverlay on the correct index
                InsertNewColumn.insert(at, startColumnIndex + indexOfNoRightInsertionColumn + i);
            }
        }
    }
    static getNewMatrixBasedOnColumns(matrix, tableContent, startColumnIndex) {
        var _a, _b;
        const numberOfNewColumnsRequired = (((_a = matrix[0]) === null || _a === void 0 ? void 0 : _a.length) || 0) - (((_b = tableContent[0]) === null || _b === void 0 ? void 0 : _b.length) || 0) - startColumnIndex;
        if (numberOfNewColumnsRequired > 0) {
            // because imported CSV removes any existing rows after startRowIndex - use tableContent.length
            return new Array(tableContent.length).fill(new Array(numberOfNewColumnsRequired).fill(EMPTY_STRING));
        }
        return [];
    }
    // A matrix is a complete 2D array
    // prettier-ignore
    static insert(at, matrix, startRowIndex, startColumnIndex, isFullTableData) {
        const numberOfRowsToOverwrite = at.content.length - startRowIndex;
        // import ignores the isInsertRightAvailable rule
        if (!isFullTableData)
            InsertMatrix.insertColumnsInsideIfCantInsertRight(at, matrix, startColumnIndex);
        const dataToOverwriteRows = matrix.slice(0, numberOfRowsToOverwrite);
        // the reason why new columns are not created when the existing cells are overwritten is because the creation of new
        // columns allows new column data to be defined - which is gathered after traversing all dataToOverwriteRows
        const dataForNewColumnsByRow = isFullTableData
            ? InsertMatrix.getNewMatrixBasedOnColumns(matrix, at.content, startColumnIndex)
            : InsertMatrix.overwriteExistingCells(at, dataToOverwriteRows, startRowIndex, startColumnIndex);
        InsertMatrix.createNewColumns(at, dataForNewColumnsByRow, startRowIndex);
        if (!isFullTableData && !InsertMatrix.canNewRowsBeCreated(at, matrix, startColumnIndex))
            return;
        const dataForNewRows = matrix.slice(numberOfRowsToOverwrite);
        InsertMatrix.createNewRows(at, dataForNewRows, startColumnIndex);
        setTimeout(() => FireEvents.onContentUpdate(at));
    }
}
//# sourceMappingURL=insertMatrix.js.map