import { PaginationUtils } from '../outerTableComponents/pagination/paginationUtils';
import { InsertNewColumn } from '../insertRemoveStructure/insert/insertNewColumn';
import { InsertNewRow } from '../insertRemoveStructure/insert/insertNewRow';
import { RemoveColumn } from '../insertRemoveStructure/remove/removeColumn';
import { RemoveRow } from '../insertRemoveStructure/remove/removeRow';
import { DataUtils } from '../insertRemoveStructure/shared/dataUtils';
import { UpdateAllTableData } from './updateAllTableData';
export class ProgrammaticStructureUpdate {
    static processData(length, data) {
        if (!data)
            return;
        if (length > data.length)
            return data.concat(DataUtils.createEmptyStringDataArray(length - data.length));
        if (length < data.length)
            return data.slice(0, length);
        return data;
    }
    // if -1 - last row, if above last index - last row, otherwise use the given index
    static processIndex(index, isInsert, currentLength) {
        index = index > -1 ? index : currentLength;
        index = index > currentLength ? currentLength : index;
        return !isInsert && index === currentLength ? currentLength - 1 : index;
    }
    // prettier-ignore
    static updateColumn(at, isInsert, index, data) {
        var _a;
        index = ProgrammaticStructureUpdate.processIndex(index, isInsert, ((_a = at.content[0]) === null || _a === void 0 ? void 0 : _a.length) || 0);
        if (at.content.length === 0) {
            if (data)
                UpdateAllTableData.update(at, data.map((element) => [element]), 0, true);
        }
        else if (isInsert) {
            data = ProgrammaticStructureUpdate.processData(at.content.length || 0, data);
            InsertNewColumn.insert(at, index, data);
        }
        else if (at.content.length > 0) {
            RemoveColumn.remove(at, index);
        }
    }
    static updatePaginationAsync(at, preTimeoutPaginationNumber) {
        setTimeout(() => {
            var _a;
            if (at._pagination) {
                const newPaginationNumber = (_a = at._pagination) === null || _a === void 0 ? void 0 : _a.activePageNumber;
                if (preTimeoutPaginationNumber !== newPaginationNumber) {
                    PaginationUtils.displayRowsForDifferentButton(at, preTimeoutPaginationNumber);
                }
                else if (preTimeoutPaginationNumber !== 1) {
                    PaginationUtils.displayRowsForDifferentButton(at, 1);
                    PaginationUtils.displayRowsForDifferentButton(at, preTimeoutPaginationNumber);
                }
            }
        });
    }
    static updateRow(at, isInsert, index, data) {
        var _a, _b;
        index = ProgrammaticStructureUpdate.processIndex(index, isInsert, at.content.length);
        if (at.content.length === 0) {
            // updating all table as first row needs to have columns added
            if (data)
                UpdateAllTableData.update(at, [data], 0, true);
        }
        else if (isInsert) {
            const activePaginationNumber = (_a = at._pagination) === null || _a === void 0 ? void 0 : _a.activePageNumber;
            data = ProgrammaticStructureUpdate.processData(((_b = at.content[0]) === null || _b === void 0 ? void 0 : _b.length) || 0, data);
            InsertNewRow.insert(at, index, true, data);
            setTimeout(() => ProgrammaticStructureUpdate.updatePaginationAsync(at, activePaginationNumber));
        }
        else {
            RemoveRow.remove(at, index);
        }
    }
    static update(at, update) {
        const { structure, isInsert, index, data } = update;
        if (typeof isInsert !== 'boolean' || typeof index !== 'number')
            return;
        if (structure === 'row') {
            ProgrammaticStructureUpdate.updateRow(at, isInsert, index, data);
        }
        else if (structure === 'column') {
            ProgrammaticStructureUpdate.updateColumn(at, isInsert, index, data);
        }
    }
}
//# sourceMappingURL=programmaticStructureUpdate.js.map