import { AddNewRowElement } from '../../elements/table/addNewElements/row/addNewRowElement';
import { UpdateRowElement } from '../insertRemoveStructure/update/updateRowElement';
import { CellHighlightUtils } from '../color/cellHighlightUtils';
import { ElementStyle } from '../elements/elementStyle';
import { DragRow } from '../moveStructure/drag/dragRow';
export class RowHoverEvents {
    static canStyleBeApplied(rowHoverStyles, rowElement, rowIndex) {
        return ((rowIndex > 0 || rowHoverStyles.header) &&
            (!AddNewRowElement.isAddNewRowRow(rowElement) || rowHoverStyles.addNewRowButton));
    }
    static getRemoveColorFunc(etc, rowElement, rowIndex, defaultStyle) {
        const rowHoverStyles = etc.rowHoverStyles;
        if ((rowHoverStyles === null || rowHoverStyles === void 0 ? void 0 : rowHoverStyles.style) && RowHoverEvents.canStyleBeApplied(rowHoverStyles, rowElement, rowIndex)) {
            return () => {
                ElementStyle.unsetStyle(rowElement, rowHoverStyles.style);
                Object.assign(rowElement.style, defaultStyle);
            };
        }
        return undefined;
    }
    static addMouseLeaveEvent(etc, rowElement, rowIndex, defaultStyle) {
        const removeStyleFunc = RowHoverEvents.getRemoveColorFunc(etc, rowElement, rowIndex, defaultStyle);
        const unsetHeightFunc = UpdateRowElement.getUnsetHeightFunc(rowElement, rowIndex);
        rowElement.onmouseleave = () => {
            removeStyleFunc === null || removeStyleFunc === void 0 ? void 0 : removeStyleFunc();
            unsetHeightFunc === null || unsetHeightFunc === void 0 ? void 0 : unsetHeightFunc();
        };
    }
    // prettier-ignore
    static addMouseEnterEvent(rowElement, rowIndex, rowHoverStyles) {
        const applyStyleFunc = (rowHoverStyles === null || rowHoverStyles === void 0 ? void 0 : rowHoverStyles.style) && RowHoverEvents.canStyleBeApplied(rowHoverStyles, rowElement, rowIndex)
            ? () => Object.assign(rowElement.style, rowHoverStyles === null || rowHoverStyles === void 0 ? void 0 : rowHoverStyles.style) : undefined;
        rowElement.onmouseenter = () => {
            if (!DragRow.ROW)
                applyStyleFunc === null || applyStyleFunc === void 0 ? void 0 : applyStyleFunc();
        };
    }
    static addEvents(etc, rowElement, rowIndex, defaultStyle) {
        RowHoverEvents.addMouseEnterEvent(rowElement, rowIndex, etc.rowHoverStyles);
        RowHoverEvents.addMouseLeaveEvent(etc, rowElement, rowIndex, defaultStyle);
    }
    static process(rowHoverStyles, defaultCellHoverColors) {
        var _a, _b;
        if (rowHoverStyles === null || rowHoverStyles === void 0 ? void 0 : rowHoverStyles.style) {
            (_a = rowHoverStyles.header) !== null && _a !== void 0 ? _a : (rowHoverStyles.header = true);
            (_b = rowHoverStyles.addNewRowButton) !== null && _b !== void 0 ? _b : (rowHoverStyles.addNewRowButton = true);
            CellHighlightUtils.unsetDefaultHoverProperties(defaultCellHoverColors);
        }
    }
}
//# sourceMappingURL=rowHoverEvents.js.map