import { TableBorderDimensionsUtils } from '../../elements/table/tableBorderDimensionsUtils';
import { StringDimensionUtils } from './stringDimensionUtils';
import { IndexColumn } from '../../elements/indexColumn/indexColumn';
import { UNSET_NUMBER_IDENTIFIER } from '../../consts/unsetNumber';
import { OverflowUtils } from '../overflow/overflowUtils';
export class TableDimensionsUtils {
    // REF-19
    static setIsColumnIndexCellTextWrapped(tableDimensions, displayIndexColumn) {
        if (displayIndexColumn) {
            if (typeof displayIndexColumn === 'object' && displayIndexColumn.wrapIndexCellText) {
                tableDimensions.isColumnIndexCellTextWrapped = true;
            }
            else if (tableDimensions.isColumnIndexCellTextWrapped === undefined) {
                tableDimensions.isColumnIndexCellTextWrapped = false;
            }
        }
    }
    static setPreserveNarrowColumnsProp(at, tableDimensions) {
        // the reason why preserNarrowColumns is stored inside an object is because we temporarily need to overwrite it
        // when resizing the table and we do not want to re-render
        tableDimensions.preserveNarrowColumns = at.preserveNarrowColumns;
    }
    // prettier-ignore
    static setDimension(at, key) {
        const { tableStyle, _tableDimensions, _tableElementRef, parentElement } = at;
        if (!_tableElementRef || !parentElement)
            return;
        const numberDimension = StringDimensionUtils.generateNumberDimensionFromClientString(parentElement, tableStyle, key, true, TableDimensionsUtils.MINIMAL_TABLE_WIDTH);
        if (numberDimension.number > 0) {
            if (at.overflow)
                OverflowUtils.processNumberDimension(_tableDimensions, numberDimension);
            _tableDimensions[key] = numberDimension.number;
            _tableDimensions.isPercentage = numberDimension.isPercentage;
        }
    }
    // CAUTION-3
    // prettier-ignore
    static setTableDimensions(at) {
        const { tableStyle, _tableDimensions, _frameComponents: { displayIndexColumn } } = at;
        // width and maxWidth are mutually exclusive and if both are present width is the only one that is used
        if (tableStyle.width !== undefined) {
            TableDimensionsUtils.setDimension(at, 'width');
        }
        else if (tableStyle.maxWidth !== undefined) {
            TableDimensionsUtils.setDimension(at, 'maxWidth');
        }
        // else the table automatically holds an unlimited size via table-controlled-width class (dynamic table)
        TableDimensionsUtils.setPreserveNarrowColumnsProp(at, _tableDimensions);
        TableDimensionsUtils.setIsColumnIndexCellTextWrapped(_tableDimensions, displayIndexColumn);
    }
    static hasSetTableWidthBeenBreached(at) {
        const { width, maxWidth } = at._tableDimensions;
        const tableOffset = at.offsetWidth;
        const setWidth = width || maxWidth;
        if (setWidth) {
            // tableOffset is usually rounded, hence using Math.ceil on setWidth to correctly compare them
            return Math.ceil(setWidth) < tableOffset;
        }
        return false;
    }
    static record(at) {
        at._tableDimensions.recordedParentWidth = at.parentElement.offsetWidth;
        at._tableDimensions.recordedParentHeight = at.parentElement.offsetHeight;
        at._tableDimensions.recordedWindowWidth = window.innerWidth;
        at._tableDimensions.recordedWindowHeight = window.innerHeight;
    }
    static getDefault() {
        return {
            recordedParentWidth: 0,
            recordedParentHeight: 0,
            recordedWindowWidth: 0,
            recordedWindowHeight: 0,
            border: TableBorderDimensionsUtils.generateDefault(),
            staticWidth: UNSET_NUMBER_IDENTIFIER,
            newColumnWidth: 140,
            indexColumnWidth: IndexColumn.DEFAULT_WIDTH,
        };
    }
}
TableDimensionsUtils.MINIMAL_TABLE_WIDTH = 70;
//# sourceMappingURL=tableDimensionsUtils.js.map